{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE ExplicitForAll #-}
{-# LANGUAGE MultiWayIf #-}
{-# LANGUAGE DeriveGeneric #-}

-- | Contains the different functions to run the operation postWebhookEndpoints
module StripeAPI.Operations.PostWebhookEndpoints where

import qualified Prelude as GHC.Integer.Type
import qualified Prelude as GHC.Maybe
import qualified Control.Monad.Trans.Reader
import qualified Data.Aeson
import qualified Data.Aeson as Data.Aeson.Types
import qualified Data.Aeson as Data.Aeson.Types.FromJSON
import qualified Data.Aeson as Data.Aeson.Types.ToJSON
import qualified Data.Aeson as Data.Aeson.Types.Internal
import qualified Data.ByteString.Char8
import qualified Data.ByteString.Char8 as Data.ByteString.Internal
import qualified Data.Either
import qualified Data.Functor
import qualified Data.Scientific
import qualified Data.Text
import qualified Data.Text.Internal
import qualified Data.Time.Calendar as Data.Time.Calendar.Days
import qualified Data.Time.LocalTime as Data.Time.LocalTime.Internal.ZonedTime
import qualified GHC.Base
import qualified GHC.Classes
import qualified GHC.Generics
import qualified GHC.Int
import qualified GHC.Show
import qualified GHC.Types
import qualified Network.HTTP.Client
import qualified Network.HTTP.Client as Network.HTTP.Client.Request
import qualified Network.HTTP.Client as Network.HTTP.Client.Types
import qualified Network.HTTP.Simple
import qualified Network.HTTP.Types
import qualified Network.HTTP.Types as Network.HTTP.Types.Status
import qualified Network.HTTP.Types as Network.HTTP.Types.URI
import qualified StripeAPI.Common
import StripeAPI.Types

-- | > POST /v1/webhook_endpoints
-- 
-- \<p>A webhook endpoint must have a \<code>url\<\/code> and a list of \<code>enabled_events\<\/code>. You may optionally specify the Boolean \<code>connect\<\/code> parameter. If set to true, then a Connect webhook endpoint that notifies the specified \<code>url\<\/code> about events from all connected accounts is created; otherwise an account webhook endpoint that notifies the specified \<code>url\<\/code> only about events from your account is created. You can also create webhook endpoints in the \<a href=\"https:\/\/dashboard.stripe.com\/account\/webhooks\">webhooks settings\<\/a> section of the Dashboard.\<\/p>
postWebhookEndpoints :: forall m s . (StripeAPI.Common.MonadHTTP m, StripeAPI.Common.SecurityScheme s) => StripeAPI.Common.Configuration s  -- ^ The configuration to use in the request
  -> PostWebhookEndpointsRequestBody                                                                                                  -- ^ The request body to send
  -> m (Data.Either.Either Network.HTTP.Client.Types.HttpException (Network.HTTP.Client.Types.Response PostWebhookEndpointsResponse)) -- ^ Monad containing the result of the operation
postWebhookEndpoints config
                     body = GHC.Base.fmap (GHC.Base.fmap (\response_0 -> GHC.Base.fmap (Data.Either.either PostWebhookEndpointsResponseError GHC.Base.id GHC.Base.. (\response body -> if | (\status_1 -> Network.HTTP.Types.Status.statusCode status_1 GHC.Classes.== 200) (Network.HTTP.Client.Types.responseStatus response) -> PostWebhookEndpointsResponse200 Data.Functor.<$> (Data.Aeson.eitherDecodeStrict body :: Data.Either.Either GHC.Base.String
                                                                                                                                                                                                                                                                                                                                                                                                                                              WebhookEndpoint)
                                                                                                                                                                                          | GHC.Base.const GHC.Types.True (Network.HTTP.Client.Types.responseStatus response) -> PostWebhookEndpointsResponseDefault Data.Functor.<$> (Data.Aeson.eitherDecodeStrict body :: Data.Either.Either GHC.Base.String
                                                                                                                                                                                                                                                                                                                                                                                                Error)
                                                                                                                                                                                          | GHC.Base.otherwise -> Data.Either.Left "Missing default response type") response_0) response_0)) (StripeAPI.Common.doBodyCallWithConfiguration config (Data.Text.toUpper (Data.Text.pack "POST")) (Data.Text.pack "/v1/webhook_endpoints") [] body StripeAPI.Common.RequestBodyEncodingFormData)
-- | > POST /v1/webhook_endpoints
-- 
-- The same as 'postWebhookEndpoints' but returns the raw 'Data.ByteString.Char8.ByteString'
postWebhookEndpointsRaw :: forall m s . (StripeAPI.Common.MonadHTTP m,
                                         StripeAPI.Common.SecurityScheme s) =>
                           StripeAPI.Common.Configuration s ->
                           PostWebhookEndpointsRequestBody ->
                           m (Data.Either.Either Network.HTTP.Client.Types.HttpException
                                                 (Network.HTTP.Client.Types.Response Data.ByteString.Internal.ByteString))
postWebhookEndpointsRaw config
                        body = GHC.Base.id (StripeAPI.Common.doBodyCallWithConfiguration config (Data.Text.toUpper (Data.Text.pack "POST")) (Data.Text.pack "/v1/webhook_endpoints") [] body StripeAPI.Common.RequestBodyEncodingFormData)
-- | > POST /v1/webhook_endpoints
-- 
-- Monadic version of 'postWebhookEndpoints' (use with 'StripeAPI.Common.runWithConfiguration')
postWebhookEndpointsM :: forall m s . (StripeAPI.Common.MonadHTTP m,
                                       StripeAPI.Common.SecurityScheme s) =>
                         PostWebhookEndpointsRequestBody ->
                         Control.Monad.Trans.Reader.ReaderT (StripeAPI.Common.Configuration s)
                                                            m
                                                            (Data.Either.Either Network.HTTP.Client.Types.HttpException
                                                                                (Network.HTTP.Client.Types.Response PostWebhookEndpointsResponse))
postWebhookEndpointsM body = GHC.Base.fmap (GHC.Base.fmap (\response_2 -> GHC.Base.fmap (Data.Either.either PostWebhookEndpointsResponseError GHC.Base.id GHC.Base.. (\response body -> if | (\status_3 -> Network.HTTP.Types.Status.statusCode status_3 GHC.Classes.== 200) (Network.HTTP.Client.Types.responseStatus response) -> PostWebhookEndpointsResponse200 Data.Functor.<$> (Data.Aeson.eitherDecodeStrict body :: Data.Either.Either GHC.Base.String
                                                                                                                                                                                                                                                                                                                                                                                                                                               WebhookEndpoint)
                                                                                                                                                                                           | GHC.Base.const GHC.Types.True (Network.HTTP.Client.Types.responseStatus response) -> PostWebhookEndpointsResponseDefault Data.Functor.<$> (Data.Aeson.eitherDecodeStrict body :: Data.Either.Either GHC.Base.String
                                                                                                                                                                                                                                                                                                                                                                                                 Error)
                                                                                                                                                                                           | GHC.Base.otherwise -> Data.Either.Left "Missing default response type") response_2) response_2)) (StripeAPI.Common.doBodyCallWithConfigurationM (Data.Text.toUpper (Data.Text.pack "POST")) (Data.Text.pack "/v1/webhook_endpoints") [] body StripeAPI.Common.RequestBodyEncodingFormData)
-- | > POST /v1/webhook_endpoints
-- 
-- Monadic version of 'postWebhookEndpointsRaw' (use with 'StripeAPI.Common.runWithConfiguration')
postWebhookEndpointsRawM :: forall m s . (StripeAPI.Common.MonadHTTP m,
                                          StripeAPI.Common.SecurityScheme s) =>
                            PostWebhookEndpointsRequestBody ->
                            Control.Monad.Trans.Reader.ReaderT (StripeAPI.Common.Configuration s)
                                                               m
                                                               (Data.Either.Either Network.HTTP.Client.Types.HttpException
                                                                                   (Network.HTTP.Client.Types.Response Data.ByteString.Internal.ByteString))
postWebhookEndpointsRawM body = GHC.Base.id (StripeAPI.Common.doBodyCallWithConfigurationM (Data.Text.toUpper (Data.Text.pack "POST")) (Data.Text.pack "/v1/webhook_endpoints") [] body StripeAPI.Common.RequestBodyEncodingFormData)
-- | Defines the data type for the schema postWebhookEndpointsRequestBody
-- 
-- 
data PostWebhookEndpointsRequestBody = PostWebhookEndpointsRequestBody {
  -- | api_version: Events sent to this endpoint will be generated with this Stripe Version instead of your account\'s default Stripe Version.
  -- 
  -- Constraints:
  -- 
  -- * Maximum length of 5000
  postWebhookEndpointsRequestBodyApiVersion :: (GHC.Maybe.Maybe PostWebhookEndpointsRequestBodyApiVersion')
  -- | connect: Whether this endpoint should receive events from connected accounts (\`true\`), or from your account (\`false\`). Defaults to \`false\`.
  , postWebhookEndpointsRequestBodyConnect :: (GHC.Maybe.Maybe GHC.Types.Bool)
  -- | enabled_events: The list of events to enable for this endpoint. You may specify \`[\'*\']\` to enable all events, except those that require explicit selection.
  , postWebhookEndpointsRequestBodyEnabledEvents :: ([] PostWebhookEndpointsRequestBodyEnabledEvents')
  -- | expand: Specifies which fields in the response should be expanded.
  , postWebhookEndpointsRequestBodyExpand :: (GHC.Maybe.Maybe ([] GHC.Base.String))
  -- | url: The URL of the webhook endpoint.
  , postWebhookEndpointsRequestBodyUrl :: GHC.Base.String
  } deriving (GHC.Show.Show
  , GHC.Classes.Eq)
instance Data.Aeson.ToJSON PostWebhookEndpointsRequestBody
    where toJSON obj = Data.Aeson.object ((Data.Aeson..=) "api_version" (postWebhookEndpointsRequestBodyApiVersion obj) : (Data.Aeson..=) "connect" (postWebhookEndpointsRequestBodyConnect obj) : (Data.Aeson..=) "enabled_events" (postWebhookEndpointsRequestBodyEnabledEvents obj) : (Data.Aeson..=) "expand" (postWebhookEndpointsRequestBodyExpand obj) : (Data.Aeson..=) "url" (postWebhookEndpointsRequestBodyUrl obj) : [])
          toEncoding obj = Data.Aeson.pairs ((Data.Aeson..=) "api_version" (postWebhookEndpointsRequestBodyApiVersion obj) GHC.Base.<> ((Data.Aeson..=) "connect" (postWebhookEndpointsRequestBodyConnect obj) GHC.Base.<> ((Data.Aeson..=) "enabled_events" (postWebhookEndpointsRequestBodyEnabledEvents obj) GHC.Base.<> ((Data.Aeson..=) "expand" (postWebhookEndpointsRequestBodyExpand obj) GHC.Base.<> (Data.Aeson..=) "url" (postWebhookEndpointsRequestBodyUrl obj)))))
instance Data.Aeson.Types.FromJSON.FromJSON PostWebhookEndpointsRequestBody
    where parseJSON = Data.Aeson.Types.FromJSON.withObject "PostWebhookEndpointsRequestBody" (\obj -> ((((GHC.Base.pure PostWebhookEndpointsRequestBody GHC.Base.<*> (obj Data.Aeson.Types.FromJSON..:? "api_version")) GHC.Base.<*> (obj Data.Aeson.Types.FromJSON..:? "connect")) GHC.Base.<*> (obj Data.Aeson.Types.FromJSON..: "enabled_events")) GHC.Base.<*> (obj Data.Aeson.Types.FromJSON..:? "expand")) GHC.Base.<*> (obj Data.Aeson.Types.FromJSON..: "url"))
-- | Defines the enum schema postWebhookEndpointsRequestBodyApi_version\'
-- 
-- Events sent to this endpoint will be generated with this Stripe Version instead of your account\'s default Stripe Version.
data PostWebhookEndpointsRequestBodyApiVersion'
    = PostWebhookEndpointsRequestBodyApiVersion'EnumOther Data.Aeson.Types.Internal.Value
    | PostWebhookEndpointsRequestBodyApiVersion'EnumTyped GHC.Base.String
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2011_01_01
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2011_06_21
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2011_06_28
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2011_08_01
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2011_09_15
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2011_11_17
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_02_23
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_03_25
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_06_18
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_06_28
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_07_09
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_09_24
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_10_26
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_11_07
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2013_02_11
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2013_02_13
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2013_07_05
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2013_08_12
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2013_08_13
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2013_10_29
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2013_12_03
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_01_31
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_03_13
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_03_28
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_05_19
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_06_13
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_06_17
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_07_22
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_07_26
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_08_04
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_08_20
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_09_08
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_10_07
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_11_05
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_11_20
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_12_08
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_12_17
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_12_22
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_01_11
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_01_26
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_02_10
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_02_16
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_02_18
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_03_24
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_04_07
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_06_15
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_07_07
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_07_13
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_07_28
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_08_07
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_08_19
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_09_03
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_09_08
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_09_23
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_10_01
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_10_12
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_10_16
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_02_03
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_02_19
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_02_22
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_02_23
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_02_29
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_03_07
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_06_15
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_07_06
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_10_19
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2017_01_27
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2017_02_14
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2017_04_06
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2017_05_25
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2017_06_05
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2017_08_15
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2017_12_14
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_01_23
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_02_05
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_02_06
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_02_28
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_05_21
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_07_27
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_08_23
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_09_06
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_09_24
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_10_31
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_11_08
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_02_11
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_02_19
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_03_14
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_05_16
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_08_14
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_09_09
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_10_08
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_10_17
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_11_05
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_12_03
    | PostWebhookEndpointsRequestBodyApiVersion'EnumString_2020_03_02
    deriving (GHC.Show.Show, GHC.Classes.Eq)
instance Data.Aeson.ToJSON PostWebhookEndpointsRequestBodyApiVersion'
    where toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumOther patternName) = Data.Aeson.Types.ToJSON.toJSON patternName
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumTyped patternName) = Data.Aeson.Types.ToJSON.toJSON patternName
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2011_01_01) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2011-01-01"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2011_06_21) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2011-06-21"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2011_06_28) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2011-06-28"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2011_08_01) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2011-08-01"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2011_09_15) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2011-09-15"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2011_11_17) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2011-11-17"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_02_23) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2012-02-23"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_03_25) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2012-03-25"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_06_18) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2012-06-18"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_06_28) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2012-06-28"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_07_09) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2012-07-09"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_09_24) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2012-09-24"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_10_26) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2012-10-26"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_11_07) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2012-11-07"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2013_02_11) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2013-02-11"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2013_02_13) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2013-02-13"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2013_07_05) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2013-07-05"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2013_08_12) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2013-08-12"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2013_08_13) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2013-08-13"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2013_10_29) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2013-10-29"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2013_12_03) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2013-12-03"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_01_31) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-01-31"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_03_13) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-03-13"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_03_28) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-03-28"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_05_19) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-05-19"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_06_13) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-06-13"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_06_17) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-06-17"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_07_22) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-07-22"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_07_26) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-07-26"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_08_04) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-08-04"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_08_20) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-08-20"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_09_08) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-09-08"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_10_07) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-10-07"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_11_05) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-11-05"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_11_20) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-11-20"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_12_08) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-12-08"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_12_17) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-12-17"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_12_22) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-12-22"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_01_11) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-01-11"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_01_26) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-01-26"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_02_10) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-02-10"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_02_16) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-02-16"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_02_18) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-02-18"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_03_24) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-03-24"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_04_07) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-04-07"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_06_15) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-06-15"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_07_07) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-07-07"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_07_13) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-07-13"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_07_28) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-07-28"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_08_07) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-08-07"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_08_19) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-08-19"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_09_03) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-09-03"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_09_08) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-09-08"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_09_23) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-09-23"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_10_01) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-10-01"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_10_12) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-10-12"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_10_16) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-10-16"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_02_03) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2016-02-03"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_02_19) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2016-02-19"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_02_22) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2016-02-22"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_02_23) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2016-02-23"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_02_29) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2016-02-29"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_03_07) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2016-03-07"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_06_15) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2016-06-15"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_07_06) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2016-07-06"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_10_19) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2016-10-19"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2017_01_27) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2017-01-27"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2017_02_14) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2017-02-14"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2017_04_06) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2017-04-06"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2017_05_25) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2017-05-25"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2017_06_05) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2017-06-05"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2017_08_15) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2017-08-15"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2017_12_14) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2017-12-14"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_01_23) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2018-01-23"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_02_05) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2018-02-05"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_02_06) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2018-02-06"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_02_28) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2018-02-28"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_05_21) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2018-05-21"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_07_27) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2018-07-27"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_08_23) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2018-08-23"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_09_06) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2018-09-06"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_09_24) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2018-09-24"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_10_31) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2018-10-31"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_11_08) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2018-11-08"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_02_11) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2019-02-11"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_02_19) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2019-02-19"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_03_14) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2019-03-14"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_05_16) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2019-05-16"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_08_14) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2019-08-14"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_09_09) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2019-09-09"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_10_08) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2019-10-08"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_10_17) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2019-10-17"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_11_05) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2019-11-05"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_12_03) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2019-12-03"
          toJSON (PostWebhookEndpointsRequestBodyApiVersion'EnumString_2020_03_02) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2020-03-02"
instance Data.Aeson.FromJSON PostWebhookEndpointsRequestBodyApiVersion'
    where parseJSON val = GHC.Base.pure (if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2011-01-01")
                                          then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2011_01_01
                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2011-06-21")
                                                then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2011_06_21
                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2011-06-28")
                                                      then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2011_06_28
                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2011-08-01")
                                                            then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2011_08_01
                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2011-09-15")
                                                                  then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2011_09_15
                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2011-11-17")
                                                                        then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2011_11_17
                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2012-02-23")
                                                                              then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_02_23
                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2012-03-25")
                                                                                    then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_03_25
                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2012-06-18")
                                                                                          then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_06_18
                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2012-06-28")
                                                                                                then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_06_28
                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2012-07-09")
                                                                                                      then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_07_09
                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2012-09-24")
                                                                                                            then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_09_24
                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2012-10-26")
                                                                                                                  then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_10_26
                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2012-11-07")
                                                                                                                        then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2012_11_07
                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2013-02-11")
                                                                                                                              then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2013_02_11
                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2013-02-13")
                                                                                                                                    then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2013_02_13
                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2013-07-05")
                                                                                                                                          then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2013_07_05
                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2013-08-12")
                                                                                                                                                then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2013_08_12
                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2013-08-13")
                                                                                                                                                      then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2013_08_13
                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2013-10-29")
                                                                                                                                                            then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2013_10_29
                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2013-12-03")
                                                                                                                                                                  then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2013_12_03
                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-01-31")
                                                                                                                                                                        then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_01_31
                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-03-13")
                                                                                                                                                                              then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_03_13
                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-03-28")
                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_03_28
                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-05-19")
                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_05_19
                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-06-13")
                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_06_13
                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-06-17")
                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_06_17
                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-07-22")
                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_07_22
                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-07-26")
                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_07_26
                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-08-04")
                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_08_04
                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-08-20")
                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_08_20
                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-09-08")
                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_09_08
                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-10-07")
                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_10_07
                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-11-05")
                                                                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_11_05
                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-11-20")
                                                                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_11_20
                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-12-08")
                                                                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_12_08
                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-12-17")
                                                                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_12_17
                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2014-12-22")
                                                                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2014_12_22
                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-01-11")
                                                                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_01_11
                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-01-26")
                                                                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_01_26
                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-02-10")
                                                                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_02_10
                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-02-16")
                                                                                                                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_02_16
                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-02-18")
                                                                                                                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_02_18
                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-03-24")
                                                                                                                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_03_24
                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-04-07")
                                                                                                                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_04_07
                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-06-15")
                                                                                                                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_06_15
                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-07-07")
                                                                                                                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_07_07
                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-07-13")
                                                                                                                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_07_13
                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-07-28")
                                                                                                                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_07_28
                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-08-07")
                                                                                                                                                                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_08_07
                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-08-19")
                                                                                                                                                                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_08_19
                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-09-03")
                                                                                                                                                                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_09_03
                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-09-08")
                                                                                                                                                                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_09_08
                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-09-23")
                                                                                                                                                                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_09_23
                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-10-01")
                                                                                                                                                                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_10_01
                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-10-12")
                                                                                                                                                                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_10_12
                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2015-10-16")
                                                                                                                                                                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2015_10_16
                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2016-02-03")
                                                                                                                                                                                                                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_02_03
                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2016-02-19")
                                                                                                                                                                                                                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_02_19
                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2016-02-22")
                                                                                                                                                                                                                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_02_22
                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2016-02-23")
                                                                                                                                                                                                                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_02_23
                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2016-02-29")
                                                                                                                                                                                                                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_02_29
                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2016-03-07")
                                                                                                                                                                                                                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_03_07
                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2016-06-15")
                                                                                                                                                                                                                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_06_15
                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2016-07-06")
                                                                                                                                                                                                                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_07_06
                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2016-10-19")
                                                                                                                                                                                                                                                                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2016_10_19
                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2017-01-27")
                                                                                                                                                                                                                                                                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2017_01_27
                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2017-02-14")
                                                                                                                                                                                                                                                                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2017_02_14
                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2017-04-06")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2017_04_06
                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2017-05-25")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2017_05_25
                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2017-06-05")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2017_06_05
                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2017-08-15")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2017_08_15
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2017-12-14")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2017_12_14
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2018-01-23")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_01_23
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2018-02-05")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_02_05
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2018-02-06")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_02_06
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2018-02-28")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_02_28
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2018-05-21")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_05_21
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2018-07-27")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_07_27
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2018-08-23")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_08_23
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2018-09-06")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_09_06
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2018-09-24")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_09_24
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2018-10-31")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_10_31
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2018-11-08")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2018_11_08
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2019-02-11")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_02_11
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2019-02-19")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_02_19
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2019-03-14")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_03_14
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2019-05-16")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_05_16
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2019-08-14")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_08_14
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2019-09-09")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_09_09
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2019-10-08")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_10_08
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2019-10-17")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_10_17
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2019-11-05")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_11_05
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2019-12-03")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2019_12_03
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "2020-03-02")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyApiVersion'EnumString_2020_03_02
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else PostWebhookEndpointsRequestBodyApiVersion'EnumOther val)
-- | Defines the enum schema postWebhookEndpointsRequestBodyEnabled_events\'
-- 
-- 
data PostWebhookEndpointsRequestBodyEnabledEvents'
    = PostWebhookEndpointsRequestBodyEnabledEvents'EnumOther Data.Aeson.Types.Internal.Value
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumTyped GHC.Base.String
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumString__
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringAccount'application'authorized
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringAccount'application'deauthorized
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringAccount'externalAccount'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringAccount'externalAccount'deleted
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringAccount'externalAccount'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringAccount'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringApplicationFee'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringApplicationFee'refund'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringApplicationFee'refunded
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringBalance'available
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCapability'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'captured
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'dispute'closed
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'dispute'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'dispute'fundsReinstated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'dispute'fundsWithdrawn
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'dispute'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'expired
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'failed
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'pending
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'refund'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'refunded
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'succeeded
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCheckout'session'completed
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCoupon'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCoupon'deleted
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCoupon'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCreditNote'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCreditNote'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCreditNote'voided
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'deleted
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'discount'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'discount'deleted
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'discount'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'source'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'source'deleted
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'source'expiring
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'source'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'subscription'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'subscription'deleted
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'subscription'pendingUpdateApplied
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'subscription'pendingUpdateExpired
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'subscription'trialWillEnd
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'subscription'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'taxId'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'taxId'deleted
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'taxId'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringFile'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'deleted
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'finalized
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'markedUncollectible
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'paymentActionRequired
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'paymentFailed
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'paymentSucceeded
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'sent
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'upcoming
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'voided
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoiceitem'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoiceitem'deleted
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoiceitem'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingAuthorization'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingAuthorization'request
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingAuthorization'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingCard'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingCard'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingCardholder'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingCardholder'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingDispute'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingDispute'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingSettlement'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingSettlement'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingTransaction'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingTransaction'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringMandate'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringOrder'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringOrder'paymentFailed
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringOrder'paymentSucceeded
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringOrder'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringOrderReturn'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentIntent'amountCapturableUpdated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentIntent'canceled
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentIntent'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentIntent'paymentFailed
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentIntent'processing
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentIntent'succeeded
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentMethod'attached
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentMethod'cardAutomaticallyUpdated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentMethod'detached
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentMethod'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPayout'canceled
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPayout'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPayout'failed
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPayout'paid
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPayout'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPerson'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPerson'deleted
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPerson'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPlan'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPlan'deleted
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPlan'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringProduct'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringProduct'deleted
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringProduct'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringRadar'earlyFraudWarning'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringRadar'earlyFraudWarning'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringRecipient'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringRecipient'deleted
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringRecipient'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringReporting'reportRun'failed
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringReporting'reportRun'succeeded
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringReporting'reportType'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringReview'closed
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringReview'opened
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSetupIntent'canceled
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSetupIntent'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSetupIntent'setupFailed
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSetupIntent'succeeded
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSigma'scheduledQueryRun'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSku'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSku'deleted
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSku'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSource'canceled
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSource'chargeable
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSource'failed
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSource'mandateNotification
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSource'refundAttributesRequired
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSource'transaction'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSource'transaction'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSubscriptionSchedule'aborted
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSubscriptionSchedule'canceled
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSubscriptionSchedule'completed
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSubscriptionSchedule'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSubscriptionSchedule'expiring
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSubscriptionSchedule'released
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSubscriptionSchedule'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTaxRate'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTaxRate'updated
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTopup'canceled
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTopup'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTopup'failed
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTopup'reversed
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTopup'succeeded
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTransfer'created
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTransfer'failed
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTransfer'paid
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTransfer'reversed
    | PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTransfer'updated
    deriving (GHC.Show.Show, GHC.Classes.Eq)
instance Data.Aeson.ToJSON PostWebhookEndpointsRequestBodyEnabledEvents'
    where toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumOther patternName) = Data.Aeson.Types.ToJSON.toJSON patternName
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumTyped patternName) = Data.Aeson.Types.ToJSON.toJSON patternName
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumString__) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "*"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringAccount'application'authorized) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "account.application.authorized"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringAccount'application'deauthorized) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "account.application.deauthorized"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringAccount'externalAccount'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "account.external_account.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringAccount'externalAccount'deleted) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "account.external_account.deleted"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringAccount'externalAccount'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "account.external_account.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringAccount'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "account.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringApplicationFee'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "application_fee.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringApplicationFee'refund'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "application_fee.refund.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringApplicationFee'refunded) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "application_fee.refunded"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringBalance'available) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "balance.available"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCapability'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "capability.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'captured) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.captured"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'dispute'closed) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.dispute.closed"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'dispute'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.dispute.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'dispute'fundsReinstated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.dispute.funds_reinstated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'dispute'fundsWithdrawn) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.dispute.funds_withdrawn"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'dispute'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.dispute.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'expired) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.expired"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'failed) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.failed"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'pending) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.pending"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'refund'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.refund.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'refunded) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.refunded"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'succeeded) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.succeeded"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCheckout'session'completed) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "checkout.session.completed"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCoupon'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "coupon.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCoupon'deleted) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "coupon.deleted"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCoupon'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "coupon.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCreditNote'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "credit_note.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCreditNote'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "credit_note.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCreditNote'voided) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "credit_note.voided"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'deleted) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.deleted"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'discount'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.discount.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'discount'deleted) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.discount.deleted"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'discount'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.discount.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'source'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.source.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'source'deleted) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.source.deleted"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'source'expiring) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.source.expiring"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'source'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.source.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'subscription'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.subscription.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'subscription'deleted) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.subscription.deleted"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'subscription'pendingUpdateApplied) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.subscription.pending_update_applied"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'subscription'pendingUpdateExpired) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.subscription.pending_update_expired"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'subscription'trialWillEnd) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.subscription.trial_will_end"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'subscription'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.subscription.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'taxId'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.tax_id.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'taxId'deleted) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.tax_id.deleted"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'taxId'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.tax_id.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringFile'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "file.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoice.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'deleted) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoice.deleted"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'finalized) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoice.finalized"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'markedUncollectible) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoice.marked_uncollectible"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'paymentActionRequired) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoice.payment_action_required"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'paymentFailed) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoice.payment_failed"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'paymentSucceeded) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoice.payment_succeeded"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'sent) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoice.sent"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'upcoming) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoice.upcoming"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoice.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'voided) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoice.voided"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoiceitem'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoiceitem.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoiceitem'deleted) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoiceitem.deleted"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoiceitem'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoiceitem.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingAuthorization'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_authorization.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingAuthorization'request) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_authorization.request"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingAuthorization'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_authorization.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingCard'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_card.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingCard'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_card.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingCardholder'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_cardholder.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingCardholder'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_cardholder.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingDispute'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_dispute.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingDispute'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_dispute.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingSettlement'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_settlement.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingSettlement'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_settlement.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingTransaction'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_transaction.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingTransaction'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_transaction.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringMandate'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mandate.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringOrder'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "order.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringOrder'paymentFailed) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "order.payment_failed"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringOrder'paymentSucceeded) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "order.payment_succeeded"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringOrder'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "order.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringOrderReturn'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "order_return.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentIntent'amountCapturableUpdated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payment_intent.amount_capturable_updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentIntent'canceled) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payment_intent.canceled"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentIntent'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payment_intent.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentIntent'paymentFailed) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payment_intent.payment_failed"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentIntent'processing) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payment_intent.processing"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentIntent'succeeded) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payment_intent.succeeded"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentMethod'attached) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payment_method.attached"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentMethod'cardAutomaticallyUpdated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payment_method.card_automatically_updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentMethod'detached) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payment_method.detached"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentMethod'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payment_method.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPayout'canceled) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payout.canceled"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPayout'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payout.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPayout'failed) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payout.failed"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPayout'paid) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payout.paid"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPayout'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payout.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPerson'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "person.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPerson'deleted) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "person.deleted"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPerson'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "person.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPlan'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "plan.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPlan'deleted) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "plan.deleted"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPlan'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "plan.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringProduct'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "product.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringProduct'deleted) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "product.deleted"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringProduct'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "product.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringRadar'earlyFraudWarning'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "radar.early_fraud_warning.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringRadar'earlyFraudWarning'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "radar.early_fraud_warning.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringRecipient'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "recipient.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringRecipient'deleted) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "recipient.deleted"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringRecipient'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "recipient.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringReporting'reportRun'failed) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "reporting.report_run.failed"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringReporting'reportRun'succeeded) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "reporting.report_run.succeeded"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringReporting'reportType'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "reporting.report_type.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringReview'closed) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "review.closed"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringReview'opened) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "review.opened"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSetupIntent'canceled) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "setup_intent.canceled"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSetupIntent'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "setup_intent.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSetupIntent'setupFailed) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "setup_intent.setup_failed"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSetupIntent'succeeded) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "setup_intent.succeeded"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSigma'scheduledQueryRun'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sigma.scheduled_query_run.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSku'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sku.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSku'deleted) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sku.deleted"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSku'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sku.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSource'canceled) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "source.canceled"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSource'chargeable) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "source.chargeable"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSource'failed) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "source.failed"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSource'mandateNotification) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "source.mandate_notification"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSource'refundAttributesRequired) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "source.refund_attributes_required"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSource'transaction'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "source.transaction.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSource'transaction'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "source.transaction.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSubscriptionSchedule'aborted) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "subscription_schedule.aborted"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSubscriptionSchedule'canceled) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "subscription_schedule.canceled"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSubscriptionSchedule'completed) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "subscription_schedule.completed"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSubscriptionSchedule'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "subscription_schedule.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSubscriptionSchedule'expiring) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "subscription_schedule.expiring"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSubscriptionSchedule'released) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "subscription_schedule.released"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSubscriptionSchedule'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "subscription_schedule.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTaxRate'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tax_rate.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTaxRate'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tax_rate.updated"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTopup'canceled) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "topup.canceled"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTopup'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "topup.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTopup'failed) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "topup.failed"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTopup'reversed) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "topup.reversed"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTopup'succeeded) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "topup.succeeded"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTransfer'created) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "transfer.created"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTransfer'failed) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "transfer.failed"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTransfer'paid) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "transfer.paid"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTransfer'reversed) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "transfer.reversed"
          toJSON (PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTransfer'updated) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "transfer.updated"
instance Data.Aeson.FromJSON PostWebhookEndpointsRequestBodyEnabledEvents'
    where parseJSON val = GHC.Base.pure (if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "*")
                                          then PostWebhookEndpointsRequestBodyEnabledEvents'EnumString__
                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "account.application.authorized")
                                                then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringAccount'application'authorized
                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "account.application.deauthorized")
                                                      then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringAccount'application'deauthorized
                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "account.external_account.created")
                                                            then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringAccount'externalAccount'created
                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "account.external_account.deleted")
                                                                  then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringAccount'externalAccount'deleted
                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "account.external_account.updated")
                                                                        then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringAccount'externalAccount'updated
                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "account.updated")
                                                                              then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringAccount'updated
                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "application_fee.created")
                                                                                    then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringApplicationFee'created
                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "application_fee.refund.updated")
                                                                                          then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringApplicationFee'refund'updated
                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "application_fee.refunded")
                                                                                                then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringApplicationFee'refunded
                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "balance.available")
                                                                                                      then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringBalance'available
                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "capability.updated")
                                                                                                            then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCapability'updated
                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.captured")
                                                                                                                  then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'captured
                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.dispute.closed")
                                                                                                                        then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'dispute'closed
                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.dispute.created")
                                                                                                                              then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'dispute'created
                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.dispute.funds_reinstated")
                                                                                                                                    then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'dispute'fundsReinstated
                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.dispute.funds_withdrawn")
                                                                                                                                          then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'dispute'fundsWithdrawn
                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.dispute.updated")
                                                                                                                                                then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'dispute'updated
                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.expired")
                                                                                                                                                      then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'expired
                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.failed")
                                                                                                                                                            then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'failed
                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.pending")
                                                                                                                                                                  then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'pending
                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.refund.updated")
                                                                                                                                                                        then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'refund'updated
                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.refunded")
                                                                                                                                                                              then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'refunded
                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.succeeded")
                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'succeeded
                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charge.updated")
                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCharge'updated
                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "checkout.session.completed")
                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCheckout'session'completed
                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "coupon.created")
                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCoupon'created
                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "coupon.deleted")
                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCoupon'deleted
                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "coupon.updated")
                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCoupon'updated
                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "credit_note.created")
                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCreditNote'created
                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "credit_note.updated")
                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCreditNote'updated
                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "credit_note.voided")
                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCreditNote'voided
                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.created")
                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'created
                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.deleted")
                                                                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'deleted
                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.discount.created")
                                                                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'discount'created
                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.discount.deleted")
                                                                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'discount'deleted
                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.discount.updated")
                                                                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'discount'updated
                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.source.created")
                                                                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'source'created
                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.source.deleted")
                                                                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'source'deleted
                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.source.expiring")
                                                                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'source'expiring
                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.source.updated")
                                                                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'source'updated
                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.subscription.created")
                                                                                                                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'subscription'created
                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.subscription.deleted")
                                                                                                                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'subscription'deleted
                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.subscription.pending_update_applied")
                                                                                                                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'subscription'pendingUpdateApplied
                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.subscription.pending_update_expired")
                                                                                                                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'subscription'pendingUpdateExpired
                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.subscription.trial_will_end")
                                                                                                                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'subscription'trialWillEnd
                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.subscription.updated")
                                                                                                                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'subscription'updated
                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.tax_id.created")
                                                                                                                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'taxId'created
                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.tax_id.deleted")
                                                                                                                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'taxId'deleted
                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.tax_id.updated")
                                                                                                                                                                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'taxId'updated
                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "customer.updated")
                                                                                                                                                                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringCustomer'updated
                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "file.created")
                                                                                                                                                                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringFile'created
                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoice.created")
                                                                                                                                                                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'created
                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoice.deleted")
                                                                                                                                                                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'deleted
                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoice.finalized")
                                                                                                                                                                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'finalized
                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoice.marked_uncollectible")
                                                                                                                                                                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'markedUncollectible
                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoice.payment_action_required")
                                                                                                                                                                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'paymentActionRequired
                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoice.payment_failed")
                                                                                                                                                                                                                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'paymentFailed
                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoice.payment_succeeded")
                                                                                                                                                                                                                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'paymentSucceeded
                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoice.sent")
                                                                                                                                                                                                                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'sent
                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoice.upcoming")
                                                                                                                                                                                                                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'upcoming
                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoice.updated")
                                                                                                                                                                                                                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'updated
                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoice.voided")
                                                                                                                                                                                                                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoice'voided
                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoiceitem.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoiceitem'created
                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoiceitem.deleted")
                                                                                                                                                                                                                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoiceitem'deleted
                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "invoiceitem.updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringInvoiceitem'updated
                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_authorization.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingAuthorization'created
                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_authorization.request")
                                                                                                                                                                                                                                                                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingAuthorization'request
                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_authorization.updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingAuthorization'updated
                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_card.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingCard'created
                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_card.updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingCard'updated
                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_cardholder.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingCardholder'created
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_cardholder.updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingCardholder'updated
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_dispute.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingDispute'created
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_dispute.updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingDispute'updated
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_settlement.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingSettlement'created
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_settlement.updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingSettlement'updated
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_transaction.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingTransaction'created
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "issuing_transaction.updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringIssuingTransaction'updated
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mandate.updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringMandate'updated
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "order.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringOrder'created
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "order.payment_failed")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringOrder'paymentFailed
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "order.payment_succeeded")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringOrder'paymentSucceeded
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "order.updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringOrder'updated
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "order_return.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringOrderReturn'created
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payment_intent.amount_capturable_updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentIntent'amountCapturableUpdated
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payment_intent.canceled")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentIntent'canceled
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payment_intent.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentIntent'created
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payment_intent.payment_failed")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentIntent'paymentFailed
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payment_intent.processing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentIntent'processing
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payment_intent.succeeded")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentIntent'succeeded
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payment_method.attached")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentMethod'attached
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payment_method.card_automatically_updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentMethod'cardAutomaticallyUpdated
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payment_method.detached")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentMethod'detached
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payment_method.updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPaymentMethod'updated
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payout.canceled")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPayout'canceled
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payout.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPayout'created
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payout.failed")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPayout'failed
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payout.paid")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPayout'paid
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "payout.updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPayout'updated
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "person.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPerson'created
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "person.deleted")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPerson'deleted
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "person.updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPerson'updated
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "plan.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPlan'created
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "plan.deleted")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPlan'deleted
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "plan.updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringPlan'updated
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "product.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringProduct'created
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "product.deleted")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringProduct'deleted
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "product.updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringProduct'updated
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "radar.early_fraud_warning.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringRadar'earlyFraudWarning'created
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "radar.early_fraud_warning.updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringRadar'earlyFraudWarning'updated
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "recipient.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringRecipient'created
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "recipient.deleted")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringRecipient'deleted
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "recipient.updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringRecipient'updated
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "reporting.report_run.failed")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringReporting'reportRun'failed
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "reporting.report_run.succeeded")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringReporting'reportRun'succeeded
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "reporting.report_type.updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringReporting'reportType'updated
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "review.closed")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringReview'closed
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "review.opened")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringReview'opened
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "setup_intent.canceled")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSetupIntent'canceled
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "setup_intent.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSetupIntent'created
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "setup_intent.setup_failed")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSetupIntent'setupFailed
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "setup_intent.succeeded")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSetupIntent'succeeded
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sigma.scheduled_query_run.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSigma'scheduledQueryRun'created
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sku.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSku'created
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sku.deleted")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSku'deleted
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sku.updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSku'updated
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "source.canceled")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSource'canceled
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "source.chargeable")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSource'chargeable
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "source.failed")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSource'failed
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "source.mandate_notification")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSource'mandateNotification
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "source.refund_attributes_required")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSource'refundAttributesRequired
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "source.transaction.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSource'transaction'created
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "source.transaction.updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSource'transaction'updated
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "subscription_schedule.aborted")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSubscriptionSchedule'aborted
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "subscription_schedule.canceled")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSubscriptionSchedule'canceled
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "subscription_schedule.completed")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSubscriptionSchedule'completed
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "subscription_schedule.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSubscriptionSchedule'created
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "subscription_schedule.expiring")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSubscriptionSchedule'expiring
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "subscription_schedule.released")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSubscriptionSchedule'released
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "subscription_schedule.updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringSubscriptionSchedule'updated
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tax_rate.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTaxRate'created
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tax_rate.updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTaxRate'updated
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "topup.canceled")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTopup'canceled
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "topup.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTopup'created
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "topup.failed")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTopup'failed
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "topup.reversed")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTopup'reversed
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "topup.succeeded")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTopup'succeeded
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "transfer.created")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTransfer'created
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "transfer.failed")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTransfer'failed
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "transfer.paid")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTransfer'paid
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "transfer.reversed")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTransfer'reversed
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "transfer.updated")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then PostWebhookEndpointsRequestBodyEnabledEvents'EnumStringTransfer'updated
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else PostWebhookEndpointsRequestBodyEnabledEvents'EnumOther val)
-- | Represents a response of the operation 'postWebhookEndpoints'.
-- 
-- The response constructor is chosen by the status code of the response. If no case matches (no specific case for the response code, no range case, no default case), 'PostWebhookEndpointsResponseError' is used.
data PostWebhookEndpointsResponse =                   
   PostWebhookEndpointsResponseError GHC.Base.String  -- ^ Means either no matching case available or a parse error
  | PostWebhookEndpointsResponse200 WebhookEndpoint   -- ^ Successful response.
  | PostWebhookEndpointsResponseDefault Error         -- ^ Error response.
  deriving (GHC.Show.Show, GHC.Classes.Eq)
