{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveGeneric #-}

-- | Contains the types generated from the schema IssuingCardAuthorizationControls
module StripeAPI.Types.IssuingCardAuthorizationControls where

import qualified Prelude as GHC.Integer.Type
import qualified Prelude as GHC.Maybe
import qualified Data.Aeson
import qualified Data.Aeson as Data.Aeson.Types
import qualified Data.Aeson as Data.Aeson.Types.FromJSON
import qualified Data.Aeson as Data.Aeson.Types.ToJSON
import qualified Data.Aeson as Data.Aeson.Types.Internal
import qualified Data.ByteString.Char8
import qualified Data.ByteString.Char8 as Data.ByteString.Internal
import qualified Data.Functor
import qualified Data.Scientific
import qualified Data.Text
import qualified Data.Text.Internal
import qualified Data.Time.Calendar as Data.Time.Calendar.Days
import qualified Data.Time.LocalTime as Data.Time.LocalTime.Internal.ZonedTime
import qualified GHC.Base
import qualified GHC.Classes
import qualified GHC.Generics
import qualified GHC.Int
import qualified GHC.Show
import qualified GHC.Types
import qualified StripeAPI.Common
import StripeAPI.Types.IssuingCardSpendingLimit

-- | Defines the data type for the schema issuing_card_authorization_controls
-- 
-- 
data IssuingCardAuthorizationControls = IssuingCardAuthorizationControls {
  -- | allowed_categories: Array of strings containing [categories](https:\/\/stripe.com\/docs\/api\#issuing_authorization_object-merchant_data-category) of authorizations permitted on this card.
  issuingCardAuthorizationControlsAllowedCategories :: (GHC.Maybe.Maybe ([] IssuingCardAuthorizationControlsAllowedCategories'))
  -- | blocked_categories: Array of strings containing [categories](https:\/\/stripe.com\/docs\/api\#issuing_authorization_object-merchant_data-category) of authorizations to always decline on this card.
  , issuingCardAuthorizationControlsBlockedCategories :: (GHC.Maybe.Maybe ([] IssuingCardAuthorizationControlsBlockedCategories'))
  -- | currency: The currency of the card. See [max_amount](https:\/\/stripe.com\/docs\/api\#issuing_card_object-authorization_controls-max_amount)
  , issuingCardAuthorizationControlsCurrency :: (GHC.Maybe.Maybe GHC.Base.String)
  -- | max_approvals: Maximum count of approved authorizations on this card. Counts all authorizations retroactively.
  , issuingCardAuthorizationControlsMaxApprovals :: (GHC.Maybe.Maybe GHC.Integer.Type.Integer)
  -- | spending_limits: Limit the spending with rules based on time intervals and categories.
  , issuingCardAuthorizationControlsSpendingLimits :: (GHC.Maybe.Maybe ([] IssuingCardSpendingLimit))
  -- | spending_limits_currency: Currency for the amounts within spending_limits. Locked to the currency of the card.
  , issuingCardAuthorizationControlsSpendingLimitsCurrency :: (GHC.Maybe.Maybe GHC.Base.String)
  } deriving (GHC.Show.Show
  , GHC.Classes.Eq)
instance Data.Aeson.ToJSON IssuingCardAuthorizationControls
    where toJSON obj = Data.Aeson.object ((Data.Aeson..=) "allowed_categories" (issuingCardAuthorizationControlsAllowedCategories obj) : (Data.Aeson..=) "blocked_categories" (issuingCardAuthorizationControlsBlockedCategories obj) : (Data.Aeson..=) "currency" (issuingCardAuthorizationControlsCurrency obj) : (Data.Aeson..=) "max_approvals" (issuingCardAuthorizationControlsMaxApprovals obj) : (Data.Aeson..=) "spending_limits" (issuingCardAuthorizationControlsSpendingLimits obj) : (Data.Aeson..=) "spending_limits_currency" (issuingCardAuthorizationControlsSpendingLimitsCurrency obj) : [])
          toEncoding obj = Data.Aeson.pairs ((Data.Aeson..=) "allowed_categories" (issuingCardAuthorizationControlsAllowedCategories obj) GHC.Base.<> ((Data.Aeson..=) "blocked_categories" (issuingCardAuthorizationControlsBlockedCategories obj) GHC.Base.<> ((Data.Aeson..=) "currency" (issuingCardAuthorizationControlsCurrency obj) GHC.Base.<> ((Data.Aeson..=) "max_approvals" (issuingCardAuthorizationControlsMaxApprovals obj) GHC.Base.<> ((Data.Aeson..=) "spending_limits" (issuingCardAuthorizationControlsSpendingLimits obj) GHC.Base.<> (Data.Aeson..=) "spending_limits_currency" (issuingCardAuthorizationControlsSpendingLimitsCurrency obj))))))
instance Data.Aeson.Types.FromJSON.FromJSON IssuingCardAuthorizationControls
    where parseJSON = Data.Aeson.Types.FromJSON.withObject "IssuingCardAuthorizationControls" (\obj -> (((((GHC.Base.pure IssuingCardAuthorizationControls GHC.Base.<*> (obj Data.Aeson.Types.FromJSON..:? "allowed_categories")) GHC.Base.<*> (obj Data.Aeson.Types.FromJSON..:? "blocked_categories")) GHC.Base.<*> (obj Data.Aeson.Types.FromJSON..:? "currency")) GHC.Base.<*> (obj Data.Aeson.Types.FromJSON..:? "max_approvals")) GHC.Base.<*> (obj Data.Aeson.Types.FromJSON..:? "spending_limits")) GHC.Base.<*> (obj Data.Aeson.Types.FromJSON..:? "spending_limits_currency"))
-- | Defines the enum schema issuing_card_authorization_controlsAllowed_categories\'
-- 
-- 
data IssuingCardAuthorizationControlsAllowedCategories'
    = IssuingCardAuthorizationControlsAllowedCategories'EnumOther Data.Aeson.Types.Internal.Value
    | IssuingCardAuthorizationControlsAllowedCategories'EnumTyped GHC.Base.String
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringAcRefrigerationRepair
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringAccountingBookkeepingServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringAdvertisingServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringAgriculturalCooperative
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringAirlinesAirCarriers
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringAirportsFlyingFields
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringAmbulanceServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringAmusementParksCarnivals
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringAntiqueReproductions
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringAntiqueShops
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringAquariums
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringArchitecturalSurveyingServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringArtDealersAndGalleries
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringArtistsSupplyAndCraftShops
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutoAndHomeSupplyStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutoBodyRepairShops
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutoPaintShops
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutoServiceShops
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutomatedCashDisburse
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutomatedFuelDispensers
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutomobileAssociations
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutomotivePartsAndAccessoriesStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutomotiveTireStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringBailAndBondPayments
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringBakeries
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringBandsOrchestras
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringBarberAndBeautyShops
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringBettingCasinoGambling
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringBicycleShops
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringBilliardPoolEstablishments
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringBoatDealers
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringBoatRentalsAndLeases
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringBookStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringBooksPeriodicalsAndNewspapers
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringBowlingAlleys
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringBusLines
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringBusinessSecretarialSchools
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringBuyingShoppingServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCableSatelliteAndOtherPayTelevisionAndRadio
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCameraAndPhotographicSupplyStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCandyNutAndConfectioneryStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCarAndTruckDealersNewUsed
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCarAndTruckDealersUsedOnly
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCarRentalAgencies
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCarWashes
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCarpentryServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCarpetUpholsteryCleaning
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCaterers
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCharitableAndSocialServiceOrganizationsFundraising
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringChemicalsAndAlliedProducts
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringChildCareServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringChildrensAndInfantsWearStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringChiropodistsPodiatrists
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringChiropractors
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCigarStoresAndStands
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCivicSocialFraternalAssociations
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCleaningAndMaintenance
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringClothingRental
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCollegesUniversities
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCommercialEquipment
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCommercialFootwear
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCommercialPhotographyArtAndGraphics
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCommuterTransportAndFerries
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringComputerNetworkServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringComputerProgramming
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringComputerRepair
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringComputerSoftwareStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringComputersPeripheralsAndSoftware
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringConcreteWorkServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringConstructionMaterials
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringConsultingPublicRelations
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCorrespondenceSchools
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCosmeticStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCounselingServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCountryClubs
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCourierServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCourtCosts
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCreditReportingAgencies
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringCruiseLines
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDairyProductsStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDanceHallStudiosSchools
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDatingEscortServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDentistsOrthodontists
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDepartmentStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDetectiveAgencies
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsApplications
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsGames
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsLargeVolume
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsMedia
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingCatalogMerchant
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingCombinationCatalogAndRetailMerchant
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingInboundTelemarketing
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingInsuranceServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingOther
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingOutboundTelemarketing
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingSubscription
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingTravel
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDiscountStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDoctors
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDoorToDoorSales
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDraperyWindowCoveringAndUpholsteryStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDrinkingPlaces
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDrugStoresAndPharmacies
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDrugsDrugProprietariesAndDruggistSundries
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDryCleaners
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDurableGoods
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringDutyFreeStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringEatingPlacesRestaurants
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringEducationalServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringElectricRazorStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringElectricalPartsAndEquipment
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringElectricalServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringElectronicsRepairShops
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringElectronicsStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringElementarySecondarySchools
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringEmploymentTempAgencies
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringEquipmentRental
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringExterminatingServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringFamilyClothingStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringFastFoodRestaurants
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringFinancialInstitutions
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringFinesGovernmentAdministrativeEntities
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringFireplaceFireplaceScreensAndAccessoriesStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringFloorCoveringStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringFlorists
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringFloristsSuppliesNurseryStockAndFlowers
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringFreezerAndLockerMeatProvisioners
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringFuelDealersNonAutomotive
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringFuneralServicesCrematories
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringFurnitureHomeFurnishingsAndEquipmentStoresExceptAppliances
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringFurnitureRepairRefinishing
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringFurriersAndFurShops
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringGeneralServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringGiftCardNoveltyAndSouvenirShops
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringGlassPaintAndWallpaperStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringGlasswareCrystalStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringGolfCoursesPublic
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringGovernmentServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringGroceryStoresSupermarkets
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringHardwareEquipmentAndSupplies
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringHardwareStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringHealthAndBeautySpas
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringHearingAidsSalesAndSupplies
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringHeatingPlumbingAC
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringHobbyToyAndGameShops
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringHomeSupplyWarehouseStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringHospitals
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringHotelsMotelsAndResorts
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringHouseholdApplianceStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringIndustrialSupplies
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringInformationRetrievalServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringInsuranceDefault
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringInsuranceUnderwritingPremiums
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringIntraCompanyPurchases
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringJewelryStoresWatchesClocksAndSilverwareStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringLandscapingServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringLaundries
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringLaundryCleaningServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringLegalServicesAttorneys
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringLuggageAndLeatherGoodsStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringLumberBuildingMaterialsStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringManualCashDisburse
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMarinasServiceAndSupplies
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMasonryStoneworkAndPlaster
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMassageParlors
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMedicalAndDentalLabs
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMedicalDentalOphthalmicAndHospitalEquipmentAndSupplies
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMedicalServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMembershipOrganizations
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMensAndBoysClothingAndAccessoriesStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMensWomensClothingStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMetalServiceCenters
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneous
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousApparelAndAccessoryShops
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousAutoDealers
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousBusinessServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousFoodStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousGeneralMerchandise
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousGeneralServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousHomeFurnishingSpecialtyStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousPublishingAndPrinting
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousRecreationServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousRepairShops
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousSpecialtyRetail
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMobileHomeDealers
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMotionPictureTheaters
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMotorFreightCarriersAndTrucking
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMotorHomesDealers
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMotorVehicleSuppliesAndNewParts
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMotorcycleShopsAndDealers
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMotorcycleShopsDealers
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringMusicStoresMusicalInstrumentsPianosAndSheetMusic
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringNewsDealersAndNewsstands
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringNonFiMoneyOrders
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringNonFiStoredValueCardPurchaseLoad
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringNondurableGoods
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringNurseriesLawnAndGardenSupplyStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringNursingPersonalCare
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringOfficeAndCommercialFurniture
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringOpticiansEyeglasses
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringOptometristsOphthalmologist
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringOrthopedicGoodsProstheticDevices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringOsteopaths
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringPackageStoresBeerWineAndLiquor
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringPaintsVarnishesAndSupplies
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringParkingLotsGarages
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringPassengerRailways
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringPawnShops
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringPetShopsPetFoodAndSupplies
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringPetroleumAndPetroleumProducts
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringPhotoDeveloping
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringPhotographicPhotocopyMicrofilmEquipmentAndSupplies
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringPhotographicStudios
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringPictureVideoProduction
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringPieceGoodsNotionsAndOtherDryGoods
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringPlumbingHeatingEquipmentAndSupplies
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringPoliticalOrganizations
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringPostalServicesGovernmentOnly
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringPreciousStonesAndMetalsWatchesAndJewelry
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringProfessionalServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringPublicWarehousingAndStorage
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringQuickCopyReproAndBlueprint
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringRailroads
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringRealEstateAgentsAndManagersRentals
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringRecordStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringRecreationalVehicleRentals
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringReligiousGoodsStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringReligiousOrganizations
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringRoofingSidingSheetMetal
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringSecretarialSupportServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringSecurityBrokersDealers
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringServiceStations
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringSewingNeedleworkFabricAndPieceGoodsStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringShoeRepairHatCleaning
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringShoeStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringSmallApplianceRepair
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringSnowmobileDealers
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringSpecialTradeServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringSpecialtyCleaning
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringSportingGoodsStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringSportingRecreationCamps
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringSportsAndRidingApparelStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringSportsClubsFields
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringStampAndCoinStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringStationaryOfficeSuppliesPrintingAndWritingPaper
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringStationeryStoresOfficeAndSchoolSupplyStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringSwimmingPoolsSales
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringTUiTravelGermany
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringTailorsAlterations
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringTaxPaymentsGovernmentAgencies
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringTaxPreparationServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringTaxicabsLimousines
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringTelecommunicationEquipmentAndTelephoneSales
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringTelecommunicationServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringTelegraphServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringTentAndAwningShops
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringTestingLaboratories
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringTheatricalTicketAgencies
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringTimeshares
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringTireRetreadingAndRepair
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringTollsBridgeFees
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringTouristAttractionsAndExhibits
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringTowingServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringTrailerParksCampgrounds
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringTransportationServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringTravelAgenciesTourOperators
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringTruckStopIteration
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringTruckUtilityTrailerRentals
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringTypesettingPlateMakingAndRelatedServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringTypewriterStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringUSFederalGovernmentAgenciesOrDepartments
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringUniformsCommercialClothing
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringUsedMerchandiseAndSecondhandStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringUtilities
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringVarietyStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringVeterinaryServices
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringVideoAmusementGameSupplies
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringVideoGameArcades
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringVideoTapeRentalStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringVocationalTradeSchools
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringWatchJewelryRepair
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringWeldingRepair
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringWholesaleClubs
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringWigAndToupeeStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringWiresMoneyOrders
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringWomensAccessoryAndSpecialtyShops
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringWomensReadyToWearStores
    | IssuingCardAuthorizationControlsAllowedCategories'EnumStringWreckingAndSalvageYards
    deriving (GHC.Show.Show, GHC.Classes.Eq)
instance Data.Aeson.ToJSON IssuingCardAuthorizationControlsAllowedCategories'
    where toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumOther patternName) = Data.Aeson.Types.ToJSON.toJSON patternName
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumTyped patternName) = Data.Aeson.Types.ToJSON.toJSON patternName
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringAcRefrigerationRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "ac_refrigeration_repair"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringAccountingBookkeepingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "accounting_bookkeeping_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringAdvertisingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "advertising_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringAgriculturalCooperative) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "agricultural_cooperative"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringAirlinesAirCarriers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "airlines_air_carriers"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringAirportsFlyingFields) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "airports_flying_fields"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringAmbulanceServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "ambulance_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringAmusementParksCarnivals) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "amusement_parks_carnivals"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringAntiqueReproductions) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "antique_reproductions"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringAntiqueShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "antique_shops"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringAquariums) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "aquariums"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringArchitecturalSurveyingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "architectural_surveying_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringArtDealersAndGalleries) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "art_dealers_and_galleries"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringArtistsSupplyAndCraftShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "artists_supply_and_craft_shops"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutoAndHomeSupplyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_and_home_supply_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutoBodyRepairShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_body_repair_shops"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutoPaintShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_paint_shops"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutoServiceShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_service_shops"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutomatedCashDisburse) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automated_cash_disburse"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutomatedFuelDispensers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automated_fuel_dispensers"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutomobileAssociations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automobile_associations"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutomotivePartsAndAccessoriesStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automotive_parts_and_accessories_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutomotiveTireStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automotive_tire_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringBailAndBondPayments) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bail_and_bond_payments"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringBakeries) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bakeries"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringBandsOrchestras) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bands_orchestras"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringBarberAndBeautyShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "barber_and_beauty_shops"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringBettingCasinoGambling) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "betting_casino_gambling"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringBicycleShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bicycle_shops"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringBilliardPoolEstablishments) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "billiard_pool_establishments"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringBoatDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "boat_dealers"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringBoatRentalsAndLeases) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "boat_rentals_and_leases"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringBookStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "book_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringBooksPeriodicalsAndNewspapers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "books_periodicals_and_newspapers"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringBowlingAlleys) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bowling_alleys"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringBusLines) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bus_lines"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringBusinessSecretarialSchools) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "business_secretarial_schools"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringBuyingShoppingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "buying_shopping_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCableSatelliteAndOtherPayTelevisionAndRadio) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cable_satellite_and_other_pay_television_and_radio"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCameraAndPhotographicSupplyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "camera_and_photographic_supply_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCandyNutAndConfectioneryStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "candy_nut_and_confectionery_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCarAndTruckDealersNewUsed) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_and_truck_dealers_new_used"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCarAndTruckDealersUsedOnly) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_and_truck_dealers_used_only"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCarRentalAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_rental_agencies"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCarWashes) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_washes"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCarpentryServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "carpentry_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCarpetUpholsteryCleaning) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "carpet_upholstery_cleaning"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCaterers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "caterers"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCharitableAndSocialServiceOrganizationsFundraising) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charitable_and_social_service_organizations_fundraising"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringChemicalsAndAlliedProducts) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chemicals_and_allied_products"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringChildCareServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "child_care_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringChildrensAndInfantsWearStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "childrens_and_infants_wear_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringChiropodistsPodiatrists) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chiropodists_podiatrists"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringChiropractors) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chiropractors"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCigarStoresAndStands) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cigar_stores_and_stands"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCivicSocialFraternalAssociations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "civic_social_fraternal_associations"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCleaningAndMaintenance) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cleaning_and_maintenance"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringClothingRental) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "clothing_rental"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCollegesUniversities) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "colleges_universities"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCommercialEquipment) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_equipment"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCommercialFootwear) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_footwear"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCommercialPhotographyArtAndGraphics) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_photography_art_and_graphics"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCommuterTransportAndFerries) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commuter_transport_and_ferries"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringComputerNetworkServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_network_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringComputerProgramming) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_programming"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringComputerRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_repair"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringComputerSoftwareStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_software_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringComputersPeripheralsAndSoftware) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computers_peripherals_and_software"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringConcreteWorkServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "concrete_work_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringConstructionMaterials) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "construction_materials"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringConsultingPublicRelations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "consulting_public_relations"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCorrespondenceSchools) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "correspondence_schools"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCosmeticStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cosmetic_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCounselingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "counseling_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCountryClubs) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "country_clubs"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCourierServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "courier_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCourtCosts) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "court_costs"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCreditReportingAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "credit_reporting_agencies"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringCruiseLines) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cruise_lines"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDairyProductsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dairy_products_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDanceHallStudiosSchools) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dance_hall_studios_schools"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDatingEscortServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dating_escort_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDentistsOrthodontists) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dentists_orthodontists"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDepartmentStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "department_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDetectiveAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "detective_agencies"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsApplications) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_applications"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsGames) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_games"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsLargeVolume) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_large_volume"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsMedia) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_media"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingCatalogMerchant) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_catalog_merchant"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingCombinationCatalogAndRetailMerchant) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_combination_catalog_and_retail_merchant"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingInboundTelemarketing) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_inbound_telemarketing"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingInsuranceServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_insurance_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingOther) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_other"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingOutboundTelemarketing) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_outbound_telemarketing"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingSubscription) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_subscription"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingTravel) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_travel"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDiscountStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "discount_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDoctors) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "doctors"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDoorToDoorSales) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "door_to_door_sales"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDraperyWindowCoveringAndUpholsteryStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drapery_window_covering_and_upholstery_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDrinkingPlaces) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drinking_places"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDrugStoresAndPharmacies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drug_stores_and_pharmacies"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDrugsDrugProprietariesAndDruggistSundries) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drugs_drug_proprietaries_and_druggist_sundries"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDryCleaners) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dry_cleaners"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDurableGoods) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "durable_goods"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringDutyFreeStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "duty_free_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringEatingPlacesRestaurants) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "eating_places_restaurants"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringEducationalServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "educational_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringElectricRazorStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electric_razor_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringElectricalPartsAndEquipment) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electrical_parts_and_equipment"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringElectricalServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electrical_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringElectronicsRepairShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electronics_repair_shops"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringElectronicsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electronics_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringElementarySecondarySchools) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "elementary_secondary_schools"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringEmploymentTempAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "employment_temp_agencies"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringEquipmentRental) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "equipment_rental"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringExterminatingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "exterminating_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringFamilyClothingStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "family_clothing_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringFastFoodRestaurants) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fast_food_restaurants"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringFinancialInstitutions) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "financial_institutions"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringFinesGovernmentAdministrativeEntities) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fines_government_administrative_entities"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringFireplaceFireplaceScreensAndAccessoriesStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fireplace_fireplace_screens_and_accessories_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringFloorCoveringStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "floor_covering_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringFlorists) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "florists"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringFloristsSuppliesNurseryStockAndFlowers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "florists_supplies_nursery_stock_and_flowers"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringFreezerAndLockerMeatProvisioners) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "freezer_and_locker_meat_provisioners"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringFuelDealersNonAutomotive) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fuel_dealers_non_automotive"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringFuneralServicesCrematories) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "funeral_services_crematories"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringFurnitureHomeFurnishingsAndEquipmentStoresExceptAppliances) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furniture_home_furnishings_and_equipment_stores_except_appliances"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringFurnitureRepairRefinishing) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furniture_repair_refinishing"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringFurriersAndFurShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furriers_and_fur_shops"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringGeneralServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "general_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringGiftCardNoveltyAndSouvenirShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "gift_card_novelty_and_souvenir_shops"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringGlassPaintAndWallpaperStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "glass_paint_and_wallpaper_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringGlasswareCrystalStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "glassware_crystal_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringGolfCoursesPublic) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "golf_courses_public"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringGovernmentServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "government_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringGroceryStoresSupermarkets) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "grocery_stores_supermarkets"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringHardwareEquipmentAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hardware_equipment_and_supplies"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringHardwareStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hardware_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringHealthAndBeautySpas) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "health_and_beauty_spas"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringHearingAidsSalesAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hearing_aids_sales_and_supplies"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringHeatingPlumbingAC) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "heating_plumbing_a_c"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringHobbyToyAndGameShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hobby_toy_and_game_shops"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringHomeSupplyWarehouseStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "home_supply_warehouse_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringHospitals) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hospitals"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringHotelsMotelsAndResorts) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hotels_motels_and_resorts"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringHouseholdApplianceStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "household_appliance_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringIndustrialSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "industrial_supplies"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringInformationRetrievalServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "information_retrieval_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringInsuranceDefault) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "insurance_default"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringInsuranceUnderwritingPremiums) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "insurance_underwriting_premiums"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringIntraCompanyPurchases) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "intra_company_purchases"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringJewelryStoresWatchesClocksAndSilverwareStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "jewelry_stores_watches_clocks_and_silverware_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringLandscapingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "landscaping_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringLaundries) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "laundries"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringLaundryCleaningServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "laundry_cleaning_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringLegalServicesAttorneys) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "legal_services_attorneys"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringLuggageAndLeatherGoodsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "luggage_and_leather_goods_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringLumberBuildingMaterialsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "lumber_building_materials_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringManualCashDisburse) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "manual_cash_disburse"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMarinasServiceAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "marinas_service_and_supplies"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMasonryStoneworkAndPlaster) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "masonry_stonework_and_plaster"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMassageParlors) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "massage_parlors"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMedicalAndDentalLabs) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_and_dental_labs"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMedicalDentalOphthalmicAndHospitalEquipmentAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_dental_ophthalmic_and_hospital_equipment_and_supplies"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMedicalServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMembershipOrganizations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "membership_organizations"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMensAndBoysClothingAndAccessoriesStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mens_and_boys_clothing_and_accessories_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMensWomensClothingStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mens_womens_clothing_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMetalServiceCenters) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "metal_service_centers"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneous) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousApparelAndAccessoryShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_apparel_and_accessory_shops"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousAutoDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_auto_dealers"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousBusinessServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_business_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousFoodStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_food_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousGeneralMerchandise) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_general_merchandise"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousGeneralServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_general_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousHomeFurnishingSpecialtyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_home_furnishing_specialty_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousPublishingAndPrinting) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_publishing_and_printing"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousRecreationServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_recreation_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousRepairShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_repair_shops"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousSpecialtyRetail) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_specialty_retail"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMobileHomeDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mobile_home_dealers"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMotionPictureTheaters) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motion_picture_theaters"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMotorFreightCarriersAndTrucking) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_freight_carriers_and_trucking"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMotorHomesDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_homes_dealers"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMotorVehicleSuppliesAndNewParts) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_vehicle_supplies_and_new_parts"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMotorcycleShopsAndDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motorcycle_shops_and_dealers"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMotorcycleShopsDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motorcycle_shops_dealers"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringMusicStoresMusicalInstrumentsPianosAndSheetMusic) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "music_stores_musical_instruments_pianos_and_sheet_music"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringNewsDealersAndNewsstands) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "news_dealers_and_newsstands"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringNonFiMoneyOrders) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "non_fi_money_orders"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringNonFiStoredValueCardPurchaseLoad) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "non_fi_stored_value_card_purchase_load"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringNondurableGoods) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nondurable_goods"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringNurseriesLawnAndGardenSupplyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nurseries_lawn_and_garden_supply_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringNursingPersonalCare) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nursing_personal_care"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringOfficeAndCommercialFurniture) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "office_and_commercial_furniture"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringOpticiansEyeglasses) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "opticians_eyeglasses"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringOptometristsOphthalmologist) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "optometrists_ophthalmologist"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringOrthopedicGoodsProstheticDevices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "orthopedic_goods_prosthetic_devices"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringOsteopaths) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "osteopaths"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringPackageStoresBeerWineAndLiquor) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "package_stores_beer_wine_and_liquor"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringPaintsVarnishesAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "paints_varnishes_and_supplies"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringParkingLotsGarages) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "parking_lots_garages"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringPassengerRailways) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "passenger_railways"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringPawnShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "pawn_shops"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringPetShopsPetFoodAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "pet_shops_pet_food_and_supplies"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringPetroleumAndPetroleumProducts) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "petroleum_and_petroleum_products"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringPhotoDeveloping) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photo_developing"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringPhotographicPhotocopyMicrofilmEquipmentAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photographic_photocopy_microfilm_equipment_and_supplies"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringPhotographicStudios) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photographic_studios"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringPictureVideoProduction) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "picture_video_production"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringPieceGoodsNotionsAndOtherDryGoods) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "piece_goods_notions_and_other_dry_goods"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringPlumbingHeatingEquipmentAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "plumbing_heating_equipment_and_supplies"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringPoliticalOrganizations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "political_organizations"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringPostalServicesGovernmentOnly) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "postal_services_government_only"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringPreciousStonesAndMetalsWatchesAndJewelry) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "precious_stones_and_metals_watches_and_jewelry"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringProfessionalServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "professional_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringPublicWarehousingAndStorage) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "public_warehousing_and_storage"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringQuickCopyReproAndBlueprint) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "quick_copy_repro_and_blueprint"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringRailroads) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "railroads"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringRealEstateAgentsAndManagersRentals) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "real_estate_agents_and_managers_rentals"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringRecordStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "record_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringRecreationalVehicleRentals) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "recreational_vehicle_rentals"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringReligiousGoodsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "religious_goods_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringReligiousOrganizations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "religious_organizations"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringRoofingSidingSheetMetal) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "roofing_siding_sheet_metal"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringSecretarialSupportServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "secretarial_support_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringSecurityBrokersDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "security_brokers_dealers"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringServiceStations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "service_stations"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringSewingNeedleworkFabricAndPieceGoodsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sewing_needlework_fabric_and_piece_goods_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringShoeRepairHatCleaning) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "shoe_repair_hat_cleaning"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringShoeStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "shoe_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringSmallApplianceRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "small_appliance_repair"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringSnowmobileDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "snowmobile_dealers"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringSpecialTradeServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "special_trade_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringSpecialtyCleaning) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "specialty_cleaning"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringSportingGoodsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sporting_goods_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringSportingRecreationCamps) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sporting_recreation_camps"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringSportsAndRidingApparelStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sports_and_riding_apparel_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringSportsClubsFields) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sports_clubs_fields"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringStampAndCoinStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stamp_and_coin_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringStationaryOfficeSuppliesPrintingAndWritingPaper) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stationary_office_supplies_printing_and_writing_paper"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringStationeryStoresOfficeAndSchoolSupplyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stationery_stores_office_and_school_supply_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringSwimmingPoolsSales) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "swimming_pools_sales"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringTUiTravelGermany) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "t_ui_travel_germany"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringTailorsAlterations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tailors_alterations"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringTaxPaymentsGovernmentAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tax_payments_government_agencies"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringTaxPreparationServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tax_preparation_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringTaxicabsLimousines) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "taxicabs_limousines"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringTelecommunicationEquipmentAndTelephoneSales) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telecommunication_equipment_and_telephone_sales"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringTelecommunicationServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telecommunication_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringTelegraphServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telegraph_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringTentAndAwningShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tent_and_awning_shops"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringTestingLaboratories) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "testing_laboratories"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringTheatricalTicketAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "theatrical_ticket_agencies"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringTimeshares) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "timeshares"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringTireRetreadingAndRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tire_retreading_and_repair"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringTollsBridgeFees) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tolls_bridge_fees"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringTouristAttractionsAndExhibits) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tourist_attractions_and_exhibits"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringTowingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "towing_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringTrailerParksCampgrounds) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "trailer_parks_campgrounds"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringTransportationServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "transportation_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringTravelAgenciesTourOperators) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "travel_agencies_tour_operators"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringTruckStopIteration) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "truck_stop_iteration"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringTruckUtilityTrailerRentals) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "truck_utility_trailer_rentals"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringTypesettingPlateMakingAndRelatedServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "typesetting_plate_making_and_related_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringTypewriterStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "typewriter_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringUSFederalGovernmentAgenciesOrDepartments) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "u_s_federal_government_agencies_or_departments"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringUniformsCommercialClothing) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "uniforms_commercial_clothing"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringUsedMerchandiseAndSecondhandStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "used_merchandise_and_secondhand_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringUtilities) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "utilities"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringVarietyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "variety_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringVeterinaryServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "veterinary_services"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringVideoAmusementGameSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_amusement_game_supplies"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringVideoGameArcades) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_game_arcades"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringVideoTapeRentalStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_tape_rental_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringVocationalTradeSchools) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "vocational_trade_schools"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringWatchJewelryRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "watch_jewelry_repair"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringWeldingRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "welding_repair"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringWholesaleClubs) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wholesale_clubs"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringWigAndToupeeStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wig_and_toupee_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringWiresMoneyOrders) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wires_money_orders"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringWomensAccessoryAndSpecialtyShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "womens_accessory_and_specialty_shops"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringWomensReadyToWearStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "womens_ready_to_wear_stores"
          toJSON (IssuingCardAuthorizationControlsAllowedCategories'EnumStringWreckingAndSalvageYards) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wrecking_and_salvage_yards"
instance Data.Aeson.FromJSON IssuingCardAuthorizationControlsAllowedCategories'
    where parseJSON val = GHC.Base.pure (if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "ac_refrigeration_repair")
                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringAcRefrigerationRepair
                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "accounting_bookkeeping_services")
                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringAccountingBookkeepingServices
                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "advertising_services")
                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringAdvertisingServices
                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "agricultural_cooperative")
                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringAgriculturalCooperative
                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "airlines_air_carriers")
                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringAirlinesAirCarriers
                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "airports_flying_fields")
                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringAirportsFlyingFields
                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "ambulance_services")
                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringAmbulanceServices
                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "amusement_parks_carnivals")
                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringAmusementParksCarnivals
                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "antique_reproductions")
                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringAntiqueReproductions
                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "antique_shops")
                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringAntiqueShops
                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "aquariums")
                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringAquariums
                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "architectural_surveying_services")
                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringArchitecturalSurveyingServices
                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "art_dealers_and_galleries")
                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringArtDealersAndGalleries
                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "artists_supply_and_craft_shops")
                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringArtistsSupplyAndCraftShops
                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_and_home_supply_stores")
                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutoAndHomeSupplyStores
                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_body_repair_shops")
                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutoBodyRepairShops
                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_paint_shops")
                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutoPaintShops
                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_service_shops")
                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutoServiceShops
                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automated_cash_disburse")
                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutomatedCashDisburse
                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automated_fuel_dispensers")
                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutomatedFuelDispensers
                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automobile_associations")
                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutomobileAssociations
                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automotive_parts_and_accessories_stores")
                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutomotivePartsAndAccessoriesStores
                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automotive_tire_stores")
                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringAutomotiveTireStores
                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bail_and_bond_payments")
                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringBailAndBondPayments
                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bakeries")
                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringBakeries
                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bands_orchestras")
                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringBandsOrchestras
                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "barber_and_beauty_shops")
                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringBarberAndBeautyShops
                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "betting_casino_gambling")
                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringBettingCasinoGambling
                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bicycle_shops")
                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringBicycleShops
                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "billiard_pool_establishments")
                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringBilliardPoolEstablishments
                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "boat_dealers")
                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringBoatDealers
                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "boat_rentals_and_leases")
                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringBoatRentalsAndLeases
                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "book_stores")
                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringBookStores
                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "books_periodicals_and_newspapers")
                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringBooksPeriodicalsAndNewspapers
                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bowling_alleys")
                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringBowlingAlleys
                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bus_lines")
                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringBusLines
                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "business_secretarial_schools")
                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringBusinessSecretarialSchools
                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "buying_shopping_services")
                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringBuyingShoppingServices
                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cable_satellite_and_other_pay_television_and_radio")
                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCableSatelliteAndOtherPayTelevisionAndRadio
                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "camera_and_photographic_supply_stores")
                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCameraAndPhotographicSupplyStores
                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "candy_nut_and_confectionery_stores")
                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCandyNutAndConfectioneryStores
                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_and_truck_dealers_new_used")
                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCarAndTruckDealersNewUsed
                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_and_truck_dealers_used_only")
                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCarAndTruckDealersUsedOnly
                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_rental_agencies")
                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCarRentalAgencies
                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_washes")
                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCarWashes
                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "carpentry_services")
                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCarpentryServices
                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "carpet_upholstery_cleaning")
                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCarpetUpholsteryCleaning
                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "caterers")
                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCaterers
                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charitable_and_social_service_organizations_fundraising")
                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCharitableAndSocialServiceOrganizationsFundraising
                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chemicals_and_allied_products")
                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringChemicalsAndAlliedProducts
                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "child_care_services")
                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringChildCareServices
                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "childrens_and_infants_wear_stores")
                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringChildrensAndInfantsWearStores
                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chiropodists_podiatrists")
                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringChiropodistsPodiatrists
                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chiropractors")
                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringChiropractors
                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cigar_stores_and_stands")
                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCigarStoresAndStands
                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "civic_social_fraternal_associations")
                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCivicSocialFraternalAssociations
                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cleaning_and_maintenance")
                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCleaningAndMaintenance
                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "clothing_rental")
                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringClothingRental
                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "colleges_universities")
                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCollegesUniversities
                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_equipment")
                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCommercialEquipment
                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_footwear")
                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCommercialFootwear
                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_photography_art_and_graphics")
                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCommercialPhotographyArtAndGraphics
                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commuter_transport_and_ferries")
                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCommuterTransportAndFerries
                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_network_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringComputerNetworkServices
                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_programming")
                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringComputerProgramming
                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_repair")
                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringComputerRepair
                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_software_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringComputerSoftwareStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computers_peripherals_and_software")
                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringComputersPeripheralsAndSoftware
                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "concrete_work_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringConcreteWorkServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "construction_materials")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringConstructionMaterials
                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "consulting_public_relations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringConsultingPublicRelations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "correspondence_schools")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCorrespondenceSchools
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cosmetic_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCosmeticStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "counseling_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCounselingServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "country_clubs")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCountryClubs
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "courier_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCourierServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "court_costs")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCourtCosts
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "credit_reporting_agencies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCreditReportingAgencies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cruise_lines")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringCruiseLines
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dairy_products_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDairyProductsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dance_hall_studios_schools")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDanceHallStudiosSchools
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dating_escort_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDatingEscortServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dentists_orthodontists")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDentistsOrthodontists
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "department_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDepartmentStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "detective_agencies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDetectiveAgencies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_applications")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsApplications
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_games")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsGames
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_large_volume")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsLargeVolume
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_media")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsMedia
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_catalog_merchant")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingCatalogMerchant
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_combination_catalog_and_retail_merchant")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingCombinationCatalogAndRetailMerchant
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_inbound_telemarketing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingInboundTelemarketing
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_insurance_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingInsuranceServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_other")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingOther
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_outbound_telemarketing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingOutboundTelemarketing
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_subscription")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingSubscription
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_travel")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDirectMarketingTravel
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "discount_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDiscountStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "doctors")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDoctors
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "door_to_door_sales")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDoorToDoorSales
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drapery_window_covering_and_upholstery_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDraperyWindowCoveringAndUpholsteryStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drinking_places")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDrinkingPlaces
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drug_stores_and_pharmacies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDrugStoresAndPharmacies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drugs_drug_proprietaries_and_druggist_sundries")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDrugsDrugProprietariesAndDruggistSundries
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dry_cleaners")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDryCleaners
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "durable_goods")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDurableGoods
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "duty_free_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringDutyFreeStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "eating_places_restaurants")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringEatingPlacesRestaurants
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "educational_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringEducationalServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electric_razor_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringElectricRazorStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electrical_parts_and_equipment")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringElectricalPartsAndEquipment
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electrical_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringElectricalServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electronics_repair_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringElectronicsRepairShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electronics_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringElectronicsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "elementary_secondary_schools")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringElementarySecondarySchools
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "employment_temp_agencies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringEmploymentTempAgencies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "equipment_rental")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringEquipmentRental
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "exterminating_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringExterminatingServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "family_clothing_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringFamilyClothingStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fast_food_restaurants")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringFastFoodRestaurants
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "financial_institutions")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringFinancialInstitutions
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fines_government_administrative_entities")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringFinesGovernmentAdministrativeEntities
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fireplace_fireplace_screens_and_accessories_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringFireplaceFireplaceScreensAndAccessoriesStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "floor_covering_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringFloorCoveringStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "florists")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringFlorists
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "florists_supplies_nursery_stock_and_flowers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringFloristsSuppliesNurseryStockAndFlowers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "freezer_and_locker_meat_provisioners")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringFreezerAndLockerMeatProvisioners
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fuel_dealers_non_automotive")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringFuelDealersNonAutomotive
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "funeral_services_crematories")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringFuneralServicesCrematories
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furniture_home_furnishings_and_equipment_stores_except_appliances")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringFurnitureHomeFurnishingsAndEquipmentStoresExceptAppliances
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furniture_repair_refinishing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringFurnitureRepairRefinishing
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furriers_and_fur_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringFurriersAndFurShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "general_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringGeneralServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "gift_card_novelty_and_souvenir_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringGiftCardNoveltyAndSouvenirShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "glass_paint_and_wallpaper_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringGlassPaintAndWallpaperStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "glassware_crystal_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringGlasswareCrystalStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "golf_courses_public")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringGolfCoursesPublic
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "government_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringGovernmentServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "grocery_stores_supermarkets")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringGroceryStoresSupermarkets
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hardware_equipment_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringHardwareEquipmentAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hardware_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringHardwareStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "health_and_beauty_spas")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringHealthAndBeautySpas
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hearing_aids_sales_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringHearingAidsSalesAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "heating_plumbing_a_c")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringHeatingPlumbingAC
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hobby_toy_and_game_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringHobbyToyAndGameShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "home_supply_warehouse_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringHomeSupplyWarehouseStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hospitals")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringHospitals
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hotels_motels_and_resorts")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringHotelsMotelsAndResorts
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "household_appliance_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringHouseholdApplianceStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "industrial_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringIndustrialSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "information_retrieval_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringInformationRetrievalServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "insurance_default")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringInsuranceDefault
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "insurance_underwriting_premiums")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringInsuranceUnderwritingPremiums
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "intra_company_purchases")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringIntraCompanyPurchases
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "jewelry_stores_watches_clocks_and_silverware_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringJewelryStoresWatchesClocksAndSilverwareStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "landscaping_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringLandscapingServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "laundries")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringLaundries
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "laundry_cleaning_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringLaundryCleaningServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "legal_services_attorneys")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringLegalServicesAttorneys
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "luggage_and_leather_goods_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringLuggageAndLeatherGoodsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "lumber_building_materials_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringLumberBuildingMaterialsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "manual_cash_disburse")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringManualCashDisburse
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "marinas_service_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMarinasServiceAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "masonry_stonework_and_plaster")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMasonryStoneworkAndPlaster
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "massage_parlors")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMassageParlors
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_and_dental_labs")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMedicalAndDentalLabs
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_dental_ophthalmic_and_hospital_equipment_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMedicalDentalOphthalmicAndHospitalEquipmentAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMedicalServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "membership_organizations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMembershipOrganizations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mens_and_boys_clothing_and_accessories_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMensAndBoysClothingAndAccessoriesStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mens_womens_clothing_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMensWomensClothingStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "metal_service_centers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMetalServiceCenters
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneous
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_apparel_and_accessory_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousApparelAndAccessoryShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_auto_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousAutoDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_business_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousBusinessServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_food_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousFoodStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_general_merchandise")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousGeneralMerchandise
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_general_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousGeneralServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_home_furnishing_specialty_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousHomeFurnishingSpecialtyStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_publishing_and_printing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousPublishingAndPrinting
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_recreation_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousRecreationServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_repair_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousRepairShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_specialty_retail")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMiscellaneousSpecialtyRetail
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mobile_home_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMobileHomeDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motion_picture_theaters")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMotionPictureTheaters
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_freight_carriers_and_trucking")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMotorFreightCarriersAndTrucking
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_homes_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMotorHomesDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_vehicle_supplies_and_new_parts")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMotorVehicleSuppliesAndNewParts
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motorcycle_shops_and_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMotorcycleShopsAndDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motorcycle_shops_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMotorcycleShopsDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "music_stores_musical_instruments_pianos_and_sheet_music")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringMusicStoresMusicalInstrumentsPianosAndSheetMusic
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "news_dealers_and_newsstands")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringNewsDealersAndNewsstands
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "non_fi_money_orders")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringNonFiMoneyOrders
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "non_fi_stored_value_card_purchase_load")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringNonFiStoredValueCardPurchaseLoad
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nondurable_goods")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringNondurableGoods
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nurseries_lawn_and_garden_supply_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringNurseriesLawnAndGardenSupplyStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nursing_personal_care")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringNursingPersonalCare
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "office_and_commercial_furniture")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringOfficeAndCommercialFurniture
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "opticians_eyeglasses")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringOpticiansEyeglasses
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "optometrists_ophthalmologist")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringOptometristsOphthalmologist
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "orthopedic_goods_prosthetic_devices")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringOrthopedicGoodsProstheticDevices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "osteopaths")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringOsteopaths
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "package_stores_beer_wine_and_liquor")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringPackageStoresBeerWineAndLiquor
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "paints_varnishes_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringPaintsVarnishesAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "parking_lots_garages")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringParkingLotsGarages
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "passenger_railways")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringPassengerRailways
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "pawn_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringPawnShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "pet_shops_pet_food_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringPetShopsPetFoodAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "petroleum_and_petroleum_products")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringPetroleumAndPetroleumProducts
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photo_developing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringPhotoDeveloping
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photographic_photocopy_microfilm_equipment_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringPhotographicPhotocopyMicrofilmEquipmentAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photographic_studios")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringPhotographicStudios
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "picture_video_production")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringPictureVideoProduction
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "piece_goods_notions_and_other_dry_goods")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringPieceGoodsNotionsAndOtherDryGoods
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "plumbing_heating_equipment_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringPlumbingHeatingEquipmentAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "political_organizations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringPoliticalOrganizations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "postal_services_government_only")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringPostalServicesGovernmentOnly
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "precious_stones_and_metals_watches_and_jewelry")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringPreciousStonesAndMetalsWatchesAndJewelry
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "professional_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringProfessionalServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "public_warehousing_and_storage")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringPublicWarehousingAndStorage
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "quick_copy_repro_and_blueprint")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringQuickCopyReproAndBlueprint
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "railroads")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringRailroads
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "real_estate_agents_and_managers_rentals")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringRealEstateAgentsAndManagersRentals
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "record_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringRecordStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "recreational_vehicle_rentals")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringRecreationalVehicleRentals
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "religious_goods_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringReligiousGoodsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "religious_organizations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringReligiousOrganizations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "roofing_siding_sheet_metal")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringRoofingSidingSheetMetal
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "secretarial_support_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringSecretarialSupportServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "security_brokers_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringSecurityBrokersDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "service_stations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringServiceStations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sewing_needlework_fabric_and_piece_goods_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringSewingNeedleworkFabricAndPieceGoodsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "shoe_repair_hat_cleaning")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringShoeRepairHatCleaning
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "shoe_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringShoeStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "small_appliance_repair")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringSmallApplianceRepair
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "snowmobile_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringSnowmobileDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "special_trade_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringSpecialTradeServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "specialty_cleaning")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringSpecialtyCleaning
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sporting_goods_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringSportingGoodsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sporting_recreation_camps")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringSportingRecreationCamps
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sports_and_riding_apparel_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringSportsAndRidingApparelStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sports_clubs_fields")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringSportsClubsFields
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stamp_and_coin_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringStampAndCoinStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stationary_office_supplies_printing_and_writing_paper")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringStationaryOfficeSuppliesPrintingAndWritingPaper
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stationery_stores_office_and_school_supply_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringStationeryStoresOfficeAndSchoolSupplyStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "swimming_pools_sales")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringSwimmingPoolsSales
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "t_ui_travel_germany")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringTUiTravelGermany
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tailors_alterations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringTailorsAlterations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tax_payments_government_agencies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringTaxPaymentsGovernmentAgencies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tax_preparation_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringTaxPreparationServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "taxicabs_limousines")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringTaxicabsLimousines
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telecommunication_equipment_and_telephone_sales")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringTelecommunicationEquipmentAndTelephoneSales
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telecommunication_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringTelecommunicationServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telegraph_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringTelegraphServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tent_and_awning_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringTentAndAwningShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "testing_laboratories")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringTestingLaboratories
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "theatrical_ticket_agencies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringTheatricalTicketAgencies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "timeshares")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringTimeshares
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tire_retreading_and_repair")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringTireRetreadingAndRepair
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tolls_bridge_fees")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringTollsBridgeFees
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tourist_attractions_and_exhibits")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringTouristAttractionsAndExhibits
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "towing_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringTowingServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "trailer_parks_campgrounds")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringTrailerParksCampgrounds
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "transportation_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringTransportationServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "travel_agencies_tour_operators")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringTravelAgenciesTourOperators
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "truck_stop_iteration")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringTruckStopIteration
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "truck_utility_trailer_rentals")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringTruckUtilityTrailerRentals
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "typesetting_plate_making_and_related_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringTypesettingPlateMakingAndRelatedServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "typewriter_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringTypewriterStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "u_s_federal_government_agencies_or_departments")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringUSFederalGovernmentAgenciesOrDepartments
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "uniforms_commercial_clothing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringUniformsCommercialClothing
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "used_merchandise_and_secondhand_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringUsedMerchandiseAndSecondhandStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "utilities")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringUtilities
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "variety_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringVarietyStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "veterinary_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringVeterinaryServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_amusement_game_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringVideoAmusementGameSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_game_arcades")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringVideoGameArcades
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_tape_rental_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringVideoTapeRentalStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "vocational_trade_schools")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringVocationalTradeSchools
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "watch_jewelry_repair")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsAllowedCategories'EnumStringWatchJewelryRepair
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "welding_repair")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsAllowedCategories'EnumStringWeldingRepair
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wholesale_clubs")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsAllowedCategories'EnumStringWholesaleClubs
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wig_and_toupee_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsAllowedCategories'EnumStringWigAndToupeeStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wires_money_orders")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsAllowedCategories'EnumStringWiresMoneyOrders
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "womens_accessory_and_specialty_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsAllowedCategories'EnumStringWomensAccessoryAndSpecialtyShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "womens_ready_to_wear_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsAllowedCategories'EnumStringWomensReadyToWearStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wrecking_and_salvage_yards")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsAllowedCategories'EnumStringWreckingAndSalvageYards
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else IssuingCardAuthorizationControlsAllowedCategories'EnumOther val)
-- | Defines the enum schema issuing_card_authorization_controlsBlocked_categories\'
-- 
-- 
data IssuingCardAuthorizationControlsBlockedCategories'
    = IssuingCardAuthorizationControlsBlockedCategories'EnumOther Data.Aeson.Types.Internal.Value
    | IssuingCardAuthorizationControlsBlockedCategories'EnumTyped GHC.Base.String
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringAcRefrigerationRepair
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringAccountingBookkeepingServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringAdvertisingServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringAgriculturalCooperative
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringAirlinesAirCarriers
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringAirportsFlyingFields
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringAmbulanceServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringAmusementParksCarnivals
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringAntiqueReproductions
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringAntiqueShops
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringAquariums
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringArchitecturalSurveyingServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringArtDealersAndGalleries
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringArtistsSupplyAndCraftShops
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutoAndHomeSupplyStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutoBodyRepairShops
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutoPaintShops
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutoServiceShops
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutomatedCashDisburse
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutomatedFuelDispensers
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutomobileAssociations
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutomotivePartsAndAccessoriesStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutomotiveTireStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringBailAndBondPayments
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringBakeries
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringBandsOrchestras
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringBarberAndBeautyShops
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringBettingCasinoGambling
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringBicycleShops
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringBilliardPoolEstablishments
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringBoatDealers
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringBoatRentalsAndLeases
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringBookStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringBooksPeriodicalsAndNewspapers
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringBowlingAlleys
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringBusLines
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringBusinessSecretarialSchools
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringBuyingShoppingServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCableSatelliteAndOtherPayTelevisionAndRadio
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCameraAndPhotographicSupplyStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCandyNutAndConfectioneryStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCarAndTruckDealersNewUsed
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCarAndTruckDealersUsedOnly
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCarRentalAgencies
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCarWashes
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCarpentryServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCarpetUpholsteryCleaning
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCaterers
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCharitableAndSocialServiceOrganizationsFundraising
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringChemicalsAndAlliedProducts
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringChildCareServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringChildrensAndInfantsWearStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringChiropodistsPodiatrists
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringChiropractors
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCigarStoresAndStands
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCivicSocialFraternalAssociations
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCleaningAndMaintenance
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringClothingRental
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCollegesUniversities
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCommercialEquipment
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCommercialFootwear
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCommercialPhotographyArtAndGraphics
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCommuterTransportAndFerries
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringComputerNetworkServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringComputerProgramming
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringComputerRepair
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringComputerSoftwareStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringComputersPeripheralsAndSoftware
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringConcreteWorkServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringConstructionMaterials
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringConsultingPublicRelations
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCorrespondenceSchools
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCosmeticStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCounselingServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCountryClubs
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCourierServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCourtCosts
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCreditReportingAgencies
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringCruiseLines
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDairyProductsStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDanceHallStudiosSchools
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDatingEscortServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDentistsOrthodontists
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDepartmentStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDetectiveAgencies
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsApplications
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsGames
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsLargeVolume
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsMedia
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingCatalogMerchant
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingCombinationCatalogAndRetailMerchant
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingInboundTelemarketing
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingInsuranceServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingOther
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingOutboundTelemarketing
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingSubscription
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingTravel
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDiscountStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDoctors
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDoorToDoorSales
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDraperyWindowCoveringAndUpholsteryStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDrinkingPlaces
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDrugStoresAndPharmacies
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDrugsDrugProprietariesAndDruggistSundries
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDryCleaners
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDurableGoods
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringDutyFreeStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringEatingPlacesRestaurants
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringEducationalServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringElectricRazorStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringElectricalPartsAndEquipment
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringElectricalServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringElectronicsRepairShops
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringElectronicsStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringElementarySecondarySchools
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringEmploymentTempAgencies
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringEquipmentRental
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringExterminatingServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringFamilyClothingStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringFastFoodRestaurants
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringFinancialInstitutions
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringFinesGovernmentAdministrativeEntities
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringFireplaceFireplaceScreensAndAccessoriesStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringFloorCoveringStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringFlorists
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringFloristsSuppliesNurseryStockAndFlowers
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringFreezerAndLockerMeatProvisioners
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringFuelDealersNonAutomotive
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringFuneralServicesCrematories
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringFurnitureHomeFurnishingsAndEquipmentStoresExceptAppliances
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringFurnitureRepairRefinishing
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringFurriersAndFurShops
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringGeneralServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringGiftCardNoveltyAndSouvenirShops
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringGlassPaintAndWallpaperStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringGlasswareCrystalStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringGolfCoursesPublic
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringGovernmentServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringGroceryStoresSupermarkets
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringHardwareEquipmentAndSupplies
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringHardwareStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringHealthAndBeautySpas
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringHearingAidsSalesAndSupplies
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringHeatingPlumbingAC
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringHobbyToyAndGameShops
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringHomeSupplyWarehouseStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringHospitals
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringHotelsMotelsAndResorts
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringHouseholdApplianceStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringIndustrialSupplies
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringInformationRetrievalServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringInsuranceDefault
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringInsuranceUnderwritingPremiums
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringIntraCompanyPurchases
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringJewelryStoresWatchesClocksAndSilverwareStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringLandscapingServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringLaundries
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringLaundryCleaningServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringLegalServicesAttorneys
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringLuggageAndLeatherGoodsStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringLumberBuildingMaterialsStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringManualCashDisburse
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMarinasServiceAndSupplies
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMasonryStoneworkAndPlaster
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMassageParlors
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMedicalAndDentalLabs
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMedicalDentalOphthalmicAndHospitalEquipmentAndSupplies
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMedicalServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMembershipOrganizations
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMensAndBoysClothingAndAccessoriesStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMensWomensClothingStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMetalServiceCenters
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneous
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousApparelAndAccessoryShops
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousAutoDealers
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousBusinessServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousFoodStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousGeneralMerchandise
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousGeneralServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousHomeFurnishingSpecialtyStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousPublishingAndPrinting
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousRecreationServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousRepairShops
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousSpecialtyRetail
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMobileHomeDealers
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMotionPictureTheaters
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMotorFreightCarriersAndTrucking
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMotorHomesDealers
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMotorVehicleSuppliesAndNewParts
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMotorcycleShopsAndDealers
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMotorcycleShopsDealers
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringMusicStoresMusicalInstrumentsPianosAndSheetMusic
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringNewsDealersAndNewsstands
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringNonFiMoneyOrders
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringNonFiStoredValueCardPurchaseLoad
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringNondurableGoods
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringNurseriesLawnAndGardenSupplyStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringNursingPersonalCare
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringOfficeAndCommercialFurniture
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringOpticiansEyeglasses
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringOptometristsOphthalmologist
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringOrthopedicGoodsProstheticDevices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringOsteopaths
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringPackageStoresBeerWineAndLiquor
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringPaintsVarnishesAndSupplies
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringParkingLotsGarages
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringPassengerRailways
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringPawnShops
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringPetShopsPetFoodAndSupplies
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringPetroleumAndPetroleumProducts
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringPhotoDeveloping
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringPhotographicPhotocopyMicrofilmEquipmentAndSupplies
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringPhotographicStudios
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringPictureVideoProduction
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringPieceGoodsNotionsAndOtherDryGoods
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringPlumbingHeatingEquipmentAndSupplies
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringPoliticalOrganizations
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringPostalServicesGovernmentOnly
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringPreciousStonesAndMetalsWatchesAndJewelry
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringProfessionalServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringPublicWarehousingAndStorage
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringQuickCopyReproAndBlueprint
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringRailroads
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringRealEstateAgentsAndManagersRentals
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringRecordStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringRecreationalVehicleRentals
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringReligiousGoodsStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringReligiousOrganizations
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringRoofingSidingSheetMetal
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringSecretarialSupportServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringSecurityBrokersDealers
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringServiceStations
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringSewingNeedleworkFabricAndPieceGoodsStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringShoeRepairHatCleaning
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringShoeStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringSmallApplianceRepair
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringSnowmobileDealers
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringSpecialTradeServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringSpecialtyCleaning
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringSportingGoodsStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringSportingRecreationCamps
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringSportsAndRidingApparelStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringSportsClubsFields
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringStampAndCoinStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringStationaryOfficeSuppliesPrintingAndWritingPaper
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringStationeryStoresOfficeAndSchoolSupplyStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringSwimmingPoolsSales
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringTUiTravelGermany
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringTailorsAlterations
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringTaxPaymentsGovernmentAgencies
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringTaxPreparationServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringTaxicabsLimousines
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringTelecommunicationEquipmentAndTelephoneSales
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringTelecommunicationServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringTelegraphServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringTentAndAwningShops
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringTestingLaboratories
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringTheatricalTicketAgencies
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringTimeshares
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringTireRetreadingAndRepair
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringTollsBridgeFees
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringTouristAttractionsAndExhibits
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringTowingServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringTrailerParksCampgrounds
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringTransportationServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringTravelAgenciesTourOperators
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringTruckStopIteration
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringTruckUtilityTrailerRentals
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringTypesettingPlateMakingAndRelatedServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringTypewriterStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringUSFederalGovernmentAgenciesOrDepartments
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringUniformsCommercialClothing
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringUsedMerchandiseAndSecondhandStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringUtilities
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringVarietyStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringVeterinaryServices
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringVideoAmusementGameSupplies
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringVideoGameArcades
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringVideoTapeRentalStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringVocationalTradeSchools
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringWatchJewelryRepair
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringWeldingRepair
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringWholesaleClubs
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringWigAndToupeeStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringWiresMoneyOrders
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringWomensAccessoryAndSpecialtyShops
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringWomensReadyToWearStores
    | IssuingCardAuthorizationControlsBlockedCategories'EnumStringWreckingAndSalvageYards
    deriving (GHC.Show.Show, GHC.Classes.Eq)
instance Data.Aeson.ToJSON IssuingCardAuthorizationControlsBlockedCategories'
    where toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumOther patternName) = Data.Aeson.Types.ToJSON.toJSON patternName
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumTyped patternName) = Data.Aeson.Types.ToJSON.toJSON patternName
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringAcRefrigerationRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "ac_refrigeration_repair"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringAccountingBookkeepingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "accounting_bookkeeping_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringAdvertisingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "advertising_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringAgriculturalCooperative) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "agricultural_cooperative"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringAirlinesAirCarriers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "airlines_air_carriers"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringAirportsFlyingFields) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "airports_flying_fields"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringAmbulanceServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "ambulance_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringAmusementParksCarnivals) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "amusement_parks_carnivals"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringAntiqueReproductions) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "antique_reproductions"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringAntiqueShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "antique_shops"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringAquariums) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "aquariums"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringArchitecturalSurveyingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "architectural_surveying_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringArtDealersAndGalleries) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "art_dealers_and_galleries"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringArtistsSupplyAndCraftShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "artists_supply_and_craft_shops"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutoAndHomeSupplyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_and_home_supply_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutoBodyRepairShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_body_repair_shops"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutoPaintShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_paint_shops"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutoServiceShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_service_shops"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutomatedCashDisburse) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automated_cash_disburse"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutomatedFuelDispensers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automated_fuel_dispensers"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutomobileAssociations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automobile_associations"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutomotivePartsAndAccessoriesStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automotive_parts_and_accessories_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutomotiveTireStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automotive_tire_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringBailAndBondPayments) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bail_and_bond_payments"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringBakeries) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bakeries"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringBandsOrchestras) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bands_orchestras"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringBarberAndBeautyShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "barber_and_beauty_shops"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringBettingCasinoGambling) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "betting_casino_gambling"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringBicycleShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bicycle_shops"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringBilliardPoolEstablishments) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "billiard_pool_establishments"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringBoatDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "boat_dealers"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringBoatRentalsAndLeases) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "boat_rentals_and_leases"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringBookStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "book_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringBooksPeriodicalsAndNewspapers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "books_periodicals_and_newspapers"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringBowlingAlleys) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bowling_alleys"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringBusLines) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bus_lines"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringBusinessSecretarialSchools) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "business_secretarial_schools"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringBuyingShoppingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "buying_shopping_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCableSatelliteAndOtherPayTelevisionAndRadio) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cable_satellite_and_other_pay_television_and_radio"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCameraAndPhotographicSupplyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "camera_and_photographic_supply_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCandyNutAndConfectioneryStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "candy_nut_and_confectionery_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCarAndTruckDealersNewUsed) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_and_truck_dealers_new_used"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCarAndTruckDealersUsedOnly) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_and_truck_dealers_used_only"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCarRentalAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_rental_agencies"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCarWashes) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_washes"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCarpentryServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "carpentry_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCarpetUpholsteryCleaning) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "carpet_upholstery_cleaning"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCaterers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "caterers"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCharitableAndSocialServiceOrganizationsFundraising) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charitable_and_social_service_organizations_fundraising"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringChemicalsAndAlliedProducts) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chemicals_and_allied_products"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringChildCareServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "child_care_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringChildrensAndInfantsWearStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "childrens_and_infants_wear_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringChiropodistsPodiatrists) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chiropodists_podiatrists"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringChiropractors) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chiropractors"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCigarStoresAndStands) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cigar_stores_and_stands"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCivicSocialFraternalAssociations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "civic_social_fraternal_associations"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCleaningAndMaintenance) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cleaning_and_maintenance"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringClothingRental) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "clothing_rental"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCollegesUniversities) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "colleges_universities"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCommercialEquipment) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_equipment"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCommercialFootwear) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_footwear"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCommercialPhotographyArtAndGraphics) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_photography_art_and_graphics"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCommuterTransportAndFerries) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commuter_transport_and_ferries"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringComputerNetworkServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_network_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringComputerProgramming) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_programming"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringComputerRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_repair"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringComputerSoftwareStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_software_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringComputersPeripheralsAndSoftware) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computers_peripherals_and_software"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringConcreteWorkServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "concrete_work_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringConstructionMaterials) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "construction_materials"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringConsultingPublicRelations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "consulting_public_relations"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCorrespondenceSchools) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "correspondence_schools"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCosmeticStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cosmetic_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCounselingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "counseling_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCountryClubs) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "country_clubs"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCourierServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "courier_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCourtCosts) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "court_costs"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCreditReportingAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "credit_reporting_agencies"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringCruiseLines) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cruise_lines"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDairyProductsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dairy_products_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDanceHallStudiosSchools) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dance_hall_studios_schools"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDatingEscortServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dating_escort_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDentistsOrthodontists) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dentists_orthodontists"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDepartmentStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "department_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDetectiveAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "detective_agencies"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsApplications) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_applications"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsGames) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_games"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsLargeVolume) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_large_volume"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsMedia) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_media"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingCatalogMerchant) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_catalog_merchant"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingCombinationCatalogAndRetailMerchant) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_combination_catalog_and_retail_merchant"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingInboundTelemarketing) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_inbound_telemarketing"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingInsuranceServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_insurance_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingOther) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_other"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingOutboundTelemarketing) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_outbound_telemarketing"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingSubscription) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_subscription"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingTravel) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_travel"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDiscountStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "discount_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDoctors) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "doctors"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDoorToDoorSales) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "door_to_door_sales"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDraperyWindowCoveringAndUpholsteryStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drapery_window_covering_and_upholstery_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDrinkingPlaces) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drinking_places"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDrugStoresAndPharmacies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drug_stores_and_pharmacies"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDrugsDrugProprietariesAndDruggistSundries) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drugs_drug_proprietaries_and_druggist_sundries"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDryCleaners) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dry_cleaners"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDurableGoods) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "durable_goods"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringDutyFreeStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "duty_free_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringEatingPlacesRestaurants) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "eating_places_restaurants"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringEducationalServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "educational_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringElectricRazorStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electric_razor_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringElectricalPartsAndEquipment) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electrical_parts_and_equipment"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringElectricalServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electrical_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringElectronicsRepairShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electronics_repair_shops"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringElectronicsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electronics_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringElementarySecondarySchools) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "elementary_secondary_schools"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringEmploymentTempAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "employment_temp_agencies"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringEquipmentRental) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "equipment_rental"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringExterminatingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "exterminating_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringFamilyClothingStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "family_clothing_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringFastFoodRestaurants) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fast_food_restaurants"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringFinancialInstitutions) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "financial_institutions"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringFinesGovernmentAdministrativeEntities) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fines_government_administrative_entities"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringFireplaceFireplaceScreensAndAccessoriesStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fireplace_fireplace_screens_and_accessories_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringFloorCoveringStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "floor_covering_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringFlorists) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "florists"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringFloristsSuppliesNurseryStockAndFlowers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "florists_supplies_nursery_stock_and_flowers"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringFreezerAndLockerMeatProvisioners) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "freezer_and_locker_meat_provisioners"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringFuelDealersNonAutomotive) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fuel_dealers_non_automotive"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringFuneralServicesCrematories) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "funeral_services_crematories"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringFurnitureHomeFurnishingsAndEquipmentStoresExceptAppliances) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furniture_home_furnishings_and_equipment_stores_except_appliances"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringFurnitureRepairRefinishing) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furniture_repair_refinishing"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringFurriersAndFurShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furriers_and_fur_shops"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringGeneralServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "general_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringGiftCardNoveltyAndSouvenirShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "gift_card_novelty_and_souvenir_shops"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringGlassPaintAndWallpaperStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "glass_paint_and_wallpaper_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringGlasswareCrystalStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "glassware_crystal_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringGolfCoursesPublic) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "golf_courses_public"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringGovernmentServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "government_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringGroceryStoresSupermarkets) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "grocery_stores_supermarkets"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringHardwareEquipmentAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hardware_equipment_and_supplies"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringHardwareStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hardware_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringHealthAndBeautySpas) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "health_and_beauty_spas"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringHearingAidsSalesAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hearing_aids_sales_and_supplies"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringHeatingPlumbingAC) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "heating_plumbing_a_c"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringHobbyToyAndGameShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hobby_toy_and_game_shops"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringHomeSupplyWarehouseStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "home_supply_warehouse_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringHospitals) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hospitals"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringHotelsMotelsAndResorts) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hotels_motels_and_resorts"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringHouseholdApplianceStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "household_appliance_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringIndustrialSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "industrial_supplies"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringInformationRetrievalServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "information_retrieval_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringInsuranceDefault) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "insurance_default"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringInsuranceUnderwritingPremiums) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "insurance_underwriting_premiums"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringIntraCompanyPurchases) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "intra_company_purchases"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringJewelryStoresWatchesClocksAndSilverwareStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "jewelry_stores_watches_clocks_and_silverware_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringLandscapingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "landscaping_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringLaundries) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "laundries"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringLaundryCleaningServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "laundry_cleaning_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringLegalServicesAttorneys) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "legal_services_attorneys"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringLuggageAndLeatherGoodsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "luggage_and_leather_goods_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringLumberBuildingMaterialsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "lumber_building_materials_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringManualCashDisburse) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "manual_cash_disburse"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMarinasServiceAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "marinas_service_and_supplies"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMasonryStoneworkAndPlaster) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "masonry_stonework_and_plaster"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMassageParlors) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "massage_parlors"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMedicalAndDentalLabs) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_and_dental_labs"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMedicalDentalOphthalmicAndHospitalEquipmentAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_dental_ophthalmic_and_hospital_equipment_and_supplies"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMedicalServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMembershipOrganizations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "membership_organizations"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMensAndBoysClothingAndAccessoriesStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mens_and_boys_clothing_and_accessories_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMensWomensClothingStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mens_womens_clothing_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMetalServiceCenters) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "metal_service_centers"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneous) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousApparelAndAccessoryShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_apparel_and_accessory_shops"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousAutoDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_auto_dealers"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousBusinessServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_business_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousFoodStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_food_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousGeneralMerchandise) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_general_merchandise"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousGeneralServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_general_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousHomeFurnishingSpecialtyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_home_furnishing_specialty_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousPublishingAndPrinting) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_publishing_and_printing"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousRecreationServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_recreation_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousRepairShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_repair_shops"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousSpecialtyRetail) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_specialty_retail"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMobileHomeDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mobile_home_dealers"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMotionPictureTheaters) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motion_picture_theaters"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMotorFreightCarriersAndTrucking) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_freight_carriers_and_trucking"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMotorHomesDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_homes_dealers"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMotorVehicleSuppliesAndNewParts) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_vehicle_supplies_and_new_parts"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMotorcycleShopsAndDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motorcycle_shops_and_dealers"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMotorcycleShopsDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motorcycle_shops_dealers"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringMusicStoresMusicalInstrumentsPianosAndSheetMusic) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "music_stores_musical_instruments_pianos_and_sheet_music"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringNewsDealersAndNewsstands) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "news_dealers_and_newsstands"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringNonFiMoneyOrders) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "non_fi_money_orders"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringNonFiStoredValueCardPurchaseLoad) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "non_fi_stored_value_card_purchase_load"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringNondurableGoods) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nondurable_goods"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringNurseriesLawnAndGardenSupplyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nurseries_lawn_and_garden_supply_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringNursingPersonalCare) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nursing_personal_care"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringOfficeAndCommercialFurniture) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "office_and_commercial_furniture"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringOpticiansEyeglasses) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "opticians_eyeglasses"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringOptometristsOphthalmologist) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "optometrists_ophthalmologist"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringOrthopedicGoodsProstheticDevices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "orthopedic_goods_prosthetic_devices"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringOsteopaths) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "osteopaths"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringPackageStoresBeerWineAndLiquor) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "package_stores_beer_wine_and_liquor"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringPaintsVarnishesAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "paints_varnishes_and_supplies"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringParkingLotsGarages) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "parking_lots_garages"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringPassengerRailways) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "passenger_railways"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringPawnShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "pawn_shops"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringPetShopsPetFoodAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "pet_shops_pet_food_and_supplies"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringPetroleumAndPetroleumProducts) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "petroleum_and_petroleum_products"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringPhotoDeveloping) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photo_developing"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringPhotographicPhotocopyMicrofilmEquipmentAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photographic_photocopy_microfilm_equipment_and_supplies"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringPhotographicStudios) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photographic_studios"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringPictureVideoProduction) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "picture_video_production"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringPieceGoodsNotionsAndOtherDryGoods) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "piece_goods_notions_and_other_dry_goods"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringPlumbingHeatingEquipmentAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "plumbing_heating_equipment_and_supplies"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringPoliticalOrganizations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "political_organizations"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringPostalServicesGovernmentOnly) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "postal_services_government_only"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringPreciousStonesAndMetalsWatchesAndJewelry) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "precious_stones_and_metals_watches_and_jewelry"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringProfessionalServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "professional_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringPublicWarehousingAndStorage) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "public_warehousing_and_storage"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringQuickCopyReproAndBlueprint) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "quick_copy_repro_and_blueprint"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringRailroads) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "railroads"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringRealEstateAgentsAndManagersRentals) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "real_estate_agents_and_managers_rentals"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringRecordStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "record_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringRecreationalVehicleRentals) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "recreational_vehicle_rentals"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringReligiousGoodsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "religious_goods_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringReligiousOrganizations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "religious_organizations"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringRoofingSidingSheetMetal) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "roofing_siding_sheet_metal"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringSecretarialSupportServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "secretarial_support_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringSecurityBrokersDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "security_brokers_dealers"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringServiceStations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "service_stations"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringSewingNeedleworkFabricAndPieceGoodsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sewing_needlework_fabric_and_piece_goods_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringShoeRepairHatCleaning) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "shoe_repair_hat_cleaning"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringShoeStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "shoe_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringSmallApplianceRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "small_appliance_repair"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringSnowmobileDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "snowmobile_dealers"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringSpecialTradeServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "special_trade_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringSpecialtyCleaning) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "specialty_cleaning"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringSportingGoodsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sporting_goods_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringSportingRecreationCamps) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sporting_recreation_camps"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringSportsAndRidingApparelStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sports_and_riding_apparel_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringSportsClubsFields) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sports_clubs_fields"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringStampAndCoinStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stamp_and_coin_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringStationaryOfficeSuppliesPrintingAndWritingPaper) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stationary_office_supplies_printing_and_writing_paper"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringStationeryStoresOfficeAndSchoolSupplyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stationery_stores_office_and_school_supply_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringSwimmingPoolsSales) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "swimming_pools_sales"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringTUiTravelGermany) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "t_ui_travel_germany"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringTailorsAlterations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tailors_alterations"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringTaxPaymentsGovernmentAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tax_payments_government_agencies"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringTaxPreparationServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tax_preparation_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringTaxicabsLimousines) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "taxicabs_limousines"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringTelecommunicationEquipmentAndTelephoneSales) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telecommunication_equipment_and_telephone_sales"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringTelecommunicationServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telecommunication_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringTelegraphServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telegraph_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringTentAndAwningShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tent_and_awning_shops"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringTestingLaboratories) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "testing_laboratories"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringTheatricalTicketAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "theatrical_ticket_agencies"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringTimeshares) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "timeshares"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringTireRetreadingAndRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tire_retreading_and_repair"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringTollsBridgeFees) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tolls_bridge_fees"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringTouristAttractionsAndExhibits) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tourist_attractions_and_exhibits"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringTowingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "towing_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringTrailerParksCampgrounds) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "trailer_parks_campgrounds"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringTransportationServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "transportation_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringTravelAgenciesTourOperators) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "travel_agencies_tour_operators"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringTruckStopIteration) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "truck_stop_iteration"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringTruckUtilityTrailerRentals) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "truck_utility_trailer_rentals"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringTypesettingPlateMakingAndRelatedServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "typesetting_plate_making_and_related_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringTypewriterStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "typewriter_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringUSFederalGovernmentAgenciesOrDepartments) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "u_s_federal_government_agencies_or_departments"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringUniformsCommercialClothing) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "uniforms_commercial_clothing"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringUsedMerchandiseAndSecondhandStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "used_merchandise_and_secondhand_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringUtilities) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "utilities"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringVarietyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "variety_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringVeterinaryServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "veterinary_services"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringVideoAmusementGameSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_amusement_game_supplies"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringVideoGameArcades) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_game_arcades"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringVideoTapeRentalStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_tape_rental_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringVocationalTradeSchools) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "vocational_trade_schools"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringWatchJewelryRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "watch_jewelry_repair"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringWeldingRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "welding_repair"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringWholesaleClubs) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wholesale_clubs"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringWigAndToupeeStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wig_and_toupee_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringWiresMoneyOrders) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wires_money_orders"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringWomensAccessoryAndSpecialtyShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "womens_accessory_and_specialty_shops"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringWomensReadyToWearStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "womens_ready_to_wear_stores"
          toJSON (IssuingCardAuthorizationControlsBlockedCategories'EnumStringWreckingAndSalvageYards) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wrecking_and_salvage_yards"
instance Data.Aeson.FromJSON IssuingCardAuthorizationControlsBlockedCategories'
    where parseJSON val = GHC.Base.pure (if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "ac_refrigeration_repair")
                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringAcRefrigerationRepair
                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "accounting_bookkeeping_services")
                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringAccountingBookkeepingServices
                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "advertising_services")
                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringAdvertisingServices
                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "agricultural_cooperative")
                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringAgriculturalCooperative
                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "airlines_air_carriers")
                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringAirlinesAirCarriers
                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "airports_flying_fields")
                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringAirportsFlyingFields
                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "ambulance_services")
                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringAmbulanceServices
                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "amusement_parks_carnivals")
                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringAmusementParksCarnivals
                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "antique_reproductions")
                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringAntiqueReproductions
                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "antique_shops")
                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringAntiqueShops
                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "aquariums")
                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringAquariums
                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "architectural_surveying_services")
                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringArchitecturalSurveyingServices
                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "art_dealers_and_galleries")
                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringArtDealersAndGalleries
                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "artists_supply_and_craft_shops")
                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringArtistsSupplyAndCraftShops
                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_and_home_supply_stores")
                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutoAndHomeSupplyStores
                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_body_repair_shops")
                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutoBodyRepairShops
                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_paint_shops")
                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutoPaintShops
                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_service_shops")
                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutoServiceShops
                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automated_cash_disburse")
                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutomatedCashDisburse
                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automated_fuel_dispensers")
                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutomatedFuelDispensers
                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automobile_associations")
                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutomobileAssociations
                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automotive_parts_and_accessories_stores")
                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutomotivePartsAndAccessoriesStores
                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automotive_tire_stores")
                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringAutomotiveTireStores
                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bail_and_bond_payments")
                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringBailAndBondPayments
                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bakeries")
                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringBakeries
                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bands_orchestras")
                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringBandsOrchestras
                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "barber_and_beauty_shops")
                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringBarberAndBeautyShops
                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "betting_casino_gambling")
                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringBettingCasinoGambling
                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bicycle_shops")
                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringBicycleShops
                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "billiard_pool_establishments")
                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringBilliardPoolEstablishments
                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "boat_dealers")
                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringBoatDealers
                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "boat_rentals_and_leases")
                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringBoatRentalsAndLeases
                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "book_stores")
                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringBookStores
                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "books_periodicals_and_newspapers")
                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringBooksPeriodicalsAndNewspapers
                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bowling_alleys")
                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringBowlingAlleys
                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bus_lines")
                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringBusLines
                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "business_secretarial_schools")
                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringBusinessSecretarialSchools
                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "buying_shopping_services")
                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringBuyingShoppingServices
                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cable_satellite_and_other_pay_television_and_radio")
                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCableSatelliteAndOtherPayTelevisionAndRadio
                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "camera_and_photographic_supply_stores")
                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCameraAndPhotographicSupplyStores
                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "candy_nut_and_confectionery_stores")
                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCandyNutAndConfectioneryStores
                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_and_truck_dealers_new_used")
                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCarAndTruckDealersNewUsed
                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_and_truck_dealers_used_only")
                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCarAndTruckDealersUsedOnly
                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_rental_agencies")
                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCarRentalAgencies
                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_washes")
                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCarWashes
                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "carpentry_services")
                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCarpentryServices
                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "carpet_upholstery_cleaning")
                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCarpetUpholsteryCleaning
                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "caterers")
                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCaterers
                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charitable_and_social_service_organizations_fundraising")
                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCharitableAndSocialServiceOrganizationsFundraising
                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chemicals_and_allied_products")
                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringChemicalsAndAlliedProducts
                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "child_care_services")
                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringChildCareServices
                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "childrens_and_infants_wear_stores")
                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringChildrensAndInfantsWearStores
                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chiropodists_podiatrists")
                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringChiropodistsPodiatrists
                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chiropractors")
                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringChiropractors
                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cigar_stores_and_stands")
                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCigarStoresAndStands
                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "civic_social_fraternal_associations")
                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCivicSocialFraternalAssociations
                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cleaning_and_maintenance")
                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCleaningAndMaintenance
                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "clothing_rental")
                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringClothingRental
                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "colleges_universities")
                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCollegesUniversities
                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_equipment")
                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCommercialEquipment
                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_footwear")
                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCommercialFootwear
                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_photography_art_and_graphics")
                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCommercialPhotographyArtAndGraphics
                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commuter_transport_and_ferries")
                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCommuterTransportAndFerries
                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_network_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringComputerNetworkServices
                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_programming")
                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringComputerProgramming
                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_repair")
                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringComputerRepair
                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_software_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringComputerSoftwareStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computers_peripherals_and_software")
                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringComputersPeripheralsAndSoftware
                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "concrete_work_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringConcreteWorkServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "construction_materials")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringConstructionMaterials
                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "consulting_public_relations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringConsultingPublicRelations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "correspondence_schools")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCorrespondenceSchools
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cosmetic_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCosmeticStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "counseling_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCounselingServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "country_clubs")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCountryClubs
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "courier_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCourierServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "court_costs")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCourtCosts
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "credit_reporting_agencies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCreditReportingAgencies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cruise_lines")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringCruiseLines
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dairy_products_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDairyProductsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dance_hall_studios_schools")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDanceHallStudiosSchools
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dating_escort_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDatingEscortServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dentists_orthodontists")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDentistsOrthodontists
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "department_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDepartmentStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "detective_agencies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDetectiveAgencies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_applications")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsApplications
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_games")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsGames
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_large_volume")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsLargeVolume
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_media")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsMedia
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_catalog_merchant")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingCatalogMerchant
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_combination_catalog_and_retail_merchant")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingCombinationCatalogAndRetailMerchant
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_inbound_telemarketing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingInboundTelemarketing
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_insurance_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingInsuranceServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_other")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingOther
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_outbound_telemarketing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingOutboundTelemarketing
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_subscription")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingSubscription
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_travel")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDirectMarketingTravel
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "discount_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDiscountStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "doctors")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDoctors
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "door_to_door_sales")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDoorToDoorSales
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drapery_window_covering_and_upholstery_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDraperyWindowCoveringAndUpholsteryStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drinking_places")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDrinkingPlaces
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drug_stores_and_pharmacies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDrugStoresAndPharmacies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drugs_drug_proprietaries_and_druggist_sundries")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDrugsDrugProprietariesAndDruggistSundries
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dry_cleaners")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDryCleaners
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "durable_goods")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDurableGoods
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "duty_free_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringDutyFreeStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "eating_places_restaurants")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringEatingPlacesRestaurants
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "educational_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringEducationalServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electric_razor_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringElectricRazorStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electrical_parts_and_equipment")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringElectricalPartsAndEquipment
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electrical_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringElectricalServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electronics_repair_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringElectronicsRepairShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electronics_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringElectronicsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "elementary_secondary_schools")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringElementarySecondarySchools
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "employment_temp_agencies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringEmploymentTempAgencies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "equipment_rental")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringEquipmentRental
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "exterminating_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringExterminatingServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "family_clothing_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringFamilyClothingStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fast_food_restaurants")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringFastFoodRestaurants
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "financial_institutions")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringFinancialInstitutions
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fines_government_administrative_entities")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringFinesGovernmentAdministrativeEntities
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fireplace_fireplace_screens_and_accessories_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringFireplaceFireplaceScreensAndAccessoriesStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "floor_covering_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringFloorCoveringStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "florists")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringFlorists
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "florists_supplies_nursery_stock_and_flowers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringFloristsSuppliesNurseryStockAndFlowers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "freezer_and_locker_meat_provisioners")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringFreezerAndLockerMeatProvisioners
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fuel_dealers_non_automotive")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringFuelDealersNonAutomotive
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "funeral_services_crematories")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringFuneralServicesCrematories
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furniture_home_furnishings_and_equipment_stores_except_appliances")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringFurnitureHomeFurnishingsAndEquipmentStoresExceptAppliances
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furniture_repair_refinishing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringFurnitureRepairRefinishing
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furriers_and_fur_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringFurriersAndFurShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "general_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringGeneralServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "gift_card_novelty_and_souvenir_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringGiftCardNoveltyAndSouvenirShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "glass_paint_and_wallpaper_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringGlassPaintAndWallpaperStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "glassware_crystal_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringGlasswareCrystalStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "golf_courses_public")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringGolfCoursesPublic
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "government_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringGovernmentServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "grocery_stores_supermarkets")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringGroceryStoresSupermarkets
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hardware_equipment_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringHardwareEquipmentAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hardware_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringHardwareStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "health_and_beauty_spas")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringHealthAndBeautySpas
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hearing_aids_sales_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringHearingAidsSalesAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "heating_plumbing_a_c")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringHeatingPlumbingAC
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hobby_toy_and_game_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringHobbyToyAndGameShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "home_supply_warehouse_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringHomeSupplyWarehouseStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hospitals")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringHospitals
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hotels_motels_and_resorts")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringHotelsMotelsAndResorts
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "household_appliance_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringHouseholdApplianceStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "industrial_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringIndustrialSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "information_retrieval_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringInformationRetrievalServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "insurance_default")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringInsuranceDefault
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "insurance_underwriting_premiums")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringInsuranceUnderwritingPremiums
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "intra_company_purchases")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringIntraCompanyPurchases
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "jewelry_stores_watches_clocks_and_silverware_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringJewelryStoresWatchesClocksAndSilverwareStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "landscaping_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringLandscapingServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "laundries")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringLaundries
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "laundry_cleaning_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringLaundryCleaningServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "legal_services_attorneys")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringLegalServicesAttorneys
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "luggage_and_leather_goods_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringLuggageAndLeatherGoodsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "lumber_building_materials_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringLumberBuildingMaterialsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "manual_cash_disburse")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringManualCashDisburse
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "marinas_service_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMarinasServiceAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "masonry_stonework_and_plaster")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMasonryStoneworkAndPlaster
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "massage_parlors")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMassageParlors
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_and_dental_labs")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMedicalAndDentalLabs
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_dental_ophthalmic_and_hospital_equipment_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMedicalDentalOphthalmicAndHospitalEquipmentAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMedicalServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "membership_organizations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMembershipOrganizations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mens_and_boys_clothing_and_accessories_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMensAndBoysClothingAndAccessoriesStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mens_womens_clothing_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMensWomensClothingStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "metal_service_centers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMetalServiceCenters
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneous
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_apparel_and_accessory_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousApparelAndAccessoryShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_auto_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousAutoDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_business_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousBusinessServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_food_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousFoodStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_general_merchandise")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousGeneralMerchandise
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_general_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousGeneralServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_home_furnishing_specialty_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousHomeFurnishingSpecialtyStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_publishing_and_printing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousPublishingAndPrinting
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_recreation_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousRecreationServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_repair_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousRepairShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_specialty_retail")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMiscellaneousSpecialtyRetail
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mobile_home_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMobileHomeDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motion_picture_theaters")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMotionPictureTheaters
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_freight_carriers_and_trucking")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMotorFreightCarriersAndTrucking
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_homes_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMotorHomesDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_vehicle_supplies_and_new_parts")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMotorVehicleSuppliesAndNewParts
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motorcycle_shops_and_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMotorcycleShopsAndDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motorcycle_shops_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMotorcycleShopsDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "music_stores_musical_instruments_pianos_and_sheet_music")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringMusicStoresMusicalInstrumentsPianosAndSheetMusic
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "news_dealers_and_newsstands")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringNewsDealersAndNewsstands
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "non_fi_money_orders")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringNonFiMoneyOrders
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "non_fi_stored_value_card_purchase_load")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringNonFiStoredValueCardPurchaseLoad
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nondurable_goods")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringNondurableGoods
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nurseries_lawn_and_garden_supply_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringNurseriesLawnAndGardenSupplyStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nursing_personal_care")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringNursingPersonalCare
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "office_and_commercial_furniture")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringOfficeAndCommercialFurniture
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "opticians_eyeglasses")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringOpticiansEyeglasses
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "optometrists_ophthalmologist")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringOptometristsOphthalmologist
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "orthopedic_goods_prosthetic_devices")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringOrthopedicGoodsProstheticDevices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "osteopaths")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringOsteopaths
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "package_stores_beer_wine_and_liquor")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringPackageStoresBeerWineAndLiquor
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "paints_varnishes_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringPaintsVarnishesAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "parking_lots_garages")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringParkingLotsGarages
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "passenger_railways")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringPassengerRailways
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "pawn_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringPawnShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "pet_shops_pet_food_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringPetShopsPetFoodAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "petroleum_and_petroleum_products")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringPetroleumAndPetroleumProducts
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photo_developing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringPhotoDeveloping
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photographic_photocopy_microfilm_equipment_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringPhotographicPhotocopyMicrofilmEquipmentAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photographic_studios")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringPhotographicStudios
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "picture_video_production")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringPictureVideoProduction
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "piece_goods_notions_and_other_dry_goods")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringPieceGoodsNotionsAndOtherDryGoods
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "plumbing_heating_equipment_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringPlumbingHeatingEquipmentAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "political_organizations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringPoliticalOrganizations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "postal_services_government_only")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringPostalServicesGovernmentOnly
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "precious_stones_and_metals_watches_and_jewelry")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringPreciousStonesAndMetalsWatchesAndJewelry
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "professional_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringProfessionalServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "public_warehousing_and_storage")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringPublicWarehousingAndStorage
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "quick_copy_repro_and_blueprint")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringQuickCopyReproAndBlueprint
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "railroads")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringRailroads
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "real_estate_agents_and_managers_rentals")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringRealEstateAgentsAndManagersRentals
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "record_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringRecordStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "recreational_vehicle_rentals")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringRecreationalVehicleRentals
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "religious_goods_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringReligiousGoodsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "religious_organizations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringReligiousOrganizations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "roofing_siding_sheet_metal")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringRoofingSidingSheetMetal
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "secretarial_support_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringSecretarialSupportServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "security_brokers_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringSecurityBrokersDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "service_stations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringServiceStations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sewing_needlework_fabric_and_piece_goods_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringSewingNeedleworkFabricAndPieceGoodsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "shoe_repair_hat_cleaning")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringShoeRepairHatCleaning
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "shoe_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringShoeStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "small_appliance_repair")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringSmallApplianceRepair
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "snowmobile_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringSnowmobileDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "special_trade_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringSpecialTradeServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "specialty_cleaning")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringSpecialtyCleaning
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sporting_goods_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringSportingGoodsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sporting_recreation_camps")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringSportingRecreationCamps
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sports_and_riding_apparel_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringSportsAndRidingApparelStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sports_clubs_fields")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringSportsClubsFields
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stamp_and_coin_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringStampAndCoinStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stationary_office_supplies_printing_and_writing_paper")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringStationaryOfficeSuppliesPrintingAndWritingPaper
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stationery_stores_office_and_school_supply_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringStationeryStoresOfficeAndSchoolSupplyStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "swimming_pools_sales")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringSwimmingPoolsSales
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "t_ui_travel_germany")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringTUiTravelGermany
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tailors_alterations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringTailorsAlterations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tax_payments_government_agencies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringTaxPaymentsGovernmentAgencies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tax_preparation_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringTaxPreparationServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "taxicabs_limousines")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringTaxicabsLimousines
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telecommunication_equipment_and_telephone_sales")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringTelecommunicationEquipmentAndTelephoneSales
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telecommunication_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringTelecommunicationServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telegraph_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringTelegraphServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tent_and_awning_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringTentAndAwningShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "testing_laboratories")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringTestingLaboratories
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "theatrical_ticket_agencies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringTheatricalTicketAgencies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "timeshares")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringTimeshares
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tire_retreading_and_repair")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringTireRetreadingAndRepair
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tolls_bridge_fees")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringTollsBridgeFees
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tourist_attractions_and_exhibits")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringTouristAttractionsAndExhibits
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "towing_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringTowingServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "trailer_parks_campgrounds")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringTrailerParksCampgrounds
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "transportation_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringTransportationServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "travel_agencies_tour_operators")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringTravelAgenciesTourOperators
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "truck_stop_iteration")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringTruckStopIteration
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "truck_utility_trailer_rentals")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringTruckUtilityTrailerRentals
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "typesetting_plate_making_and_related_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringTypesettingPlateMakingAndRelatedServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "typewriter_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringTypewriterStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "u_s_federal_government_agencies_or_departments")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringUSFederalGovernmentAgenciesOrDepartments
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "uniforms_commercial_clothing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringUniformsCommercialClothing
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "used_merchandise_and_secondhand_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringUsedMerchandiseAndSecondhandStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "utilities")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringUtilities
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "variety_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringVarietyStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "veterinary_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringVeterinaryServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_amusement_game_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringVideoAmusementGameSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_game_arcades")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringVideoGameArcades
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_tape_rental_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringVideoTapeRentalStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "vocational_trade_schools")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringVocationalTradeSchools
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "watch_jewelry_repair")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardAuthorizationControlsBlockedCategories'EnumStringWatchJewelryRepair
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "welding_repair")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardAuthorizationControlsBlockedCategories'EnumStringWeldingRepair
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wholesale_clubs")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardAuthorizationControlsBlockedCategories'EnumStringWholesaleClubs
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wig_and_toupee_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardAuthorizationControlsBlockedCategories'EnumStringWigAndToupeeStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wires_money_orders")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardAuthorizationControlsBlockedCategories'EnumStringWiresMoneyOrders
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "womens_accessory_and_specialty_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardAuthorizationControlsBlockedCategories'EnumStringWomensAccessoryAndSpecialtyShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "womens_ready_to_wear_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardAuthorizationControlsBlockedCategories'EnumStringWomensReadyToWearStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wrecking_and_salvage_yards")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardAuthorizationControlsBlockedCategories'EnumStringWreckingAndSalvageYards
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else IssuingCardAuthorizationControlsBlockedCategories'EnumOther val)