{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveGeneric #-}

-- | Contains the types generated from the schema IssuingCardholderAuthorizationControls
module StripeAPI.Types.IssuingCardholderAuthorizationControls where

import qualified Prelude as GHC.Integer.Type
import qualified Prelude as GHC.Maybe
import qualified Data.Aeson
import qualified Data.Aeson as Data.Aeson.Types
import qualified Data.Aeson as Data.Aeson.Types.FromJSON
import qualified Data.Aeson as Data.Aeson.Types.ToJSON
import qualified Data.Aeson as Data.Aeson.Types.Internal
import qualified Data.ByteString.Char8
import qualified Data.ByteString.Char8 as Data.ByteString.Internal
import qualified Data.Functor
import qualified Data.Scientific
import qualified Data.Text
import qualified Data.Text.Internal
import qualified Data.Time.Calendar as Data.Time.Calendar.Days
import qualified Data.Time.LocalTime as Data.Time.LocalTime.Internal.ZonedTime
import qualified GHC.Base
import qualified GHC.Classes
import qualified GHC.Generics
import qualified GHC.Int
import qualified GHC.Show
import qualified GHC.Types
import qualified StripeAPI.Common
import StripeAPI.Types.IssuingCardholderSpendingLimit

-- | Defines the data type for the schema issuing_cardholder_authorization_controls
-- 
-- 
data IssuingCardholderAuthorizationControls = IssuingCardholderAuthorizationControls {
  -- | allowed_categories: Array of strings containing [categories](https:\/\/stripe.com\/docs\/api\#issuing_authorization_object-merchant_data-category) of authorizations permitted on this cardholder\'s cards.
  issuingCardholderAuthorizationControlsAllowedCategories :: (GHC.Maybe.Maybe ([] IssuingCardholderAuthorizationControlsAllowedCategories'))
  -- | blocked_categories: Array of strings containing [categories](https:\/\/stripe.com\/docs\/api\#issuing_authorization_object-merchant_data-category) of authorizations to always decline on this cardholder\'s cards.
  , issuingCardholderAuthorizationControlsBlockedCategories :: (GHC.Maybe.Maybe ([] IssuingCardholderAuthorizationControlsBlockedCategories'))
  -- | spending_limits: Limit the spending with rules based on time intervals and categories.
  , issuingCardholderAuthorizationControlsSpendingLimits :: (GHC.Maybe.Maybe ([] IssuingCardholderSpendingLimit))
  -- | spending_limits_currency: Currency for the amounts within spending_limits.
  , issuingCardholderAuthorizationControlsSpendingLimitsCurrency :: (GHC.Maybe.Maybe GHC.Base.String)
  } deriving (GHC.Show.Show
  , GHC.Classes.Eq)
instance Data.Aeson.ToJSON IssuingCardholderAuthorizationControls
    where toJSON obj = Data.Aeson.object ((Data.Aeson..=) "allowed_categories" (issuingCardholderAuthorizationControlsAllowedCategories obj) : (Data.Aeson..=) "blocked_categories" (issuingCardholderAuthorizationControlsBlockedCategories obj) : (Data.Aeson..=) "spending_limits" (issuingCardholderAuthorizationControlsSpendingLimits obj) : (Data.Aeson..=) "spending_limits_currency" (issuingCardholderAuthorizationControlsSpendingLimitsCurrency obj) : [])
          toEncoding obj = Data.Aeson.pairs ((Data.Aeson..=) "allowed_categories" (issuingCardholderAuthorizationControlsAllowedCategories obj) GHC.Base.<> ((Data.Aeson..=) "blocked_categories" (issuingCardholderAuthorizationControlsBlockedCategories obj) GHC.Base.<> ((Data.Aeson..=) "spending_limits" (issuingCardholderAuthorizationControlsSpendingLimits obj) GHC.Base.<> (Data.Aeson..=) "spending_limits_currency" (issuingCardholderAuthorizationControlsSpendingLimitsCurrency obj))))
instance Data.Aeson.Types.FromJSON.FromJSON IssuingCardholderAuthorizationControls
    where parseJSON = Data.Aeson.Types.FromJSON.withObject "IssuingCardholderAuthorizationControls" (\obj -> (((GHC.Base.pure IssuingCardholderAuthorizationControls GHC.Base.<*> (obj Data.Aeson.Types.FromJSON..:? "allowed_categories")) GHC.Base.<*> (obj Data.Aeson.Types.FromJSON..:? "blocked_categories")) GHC.Base.<*> (obj Data.Aeson.Types.FromJSON..:? "spending_limits")) GHC.Base.<*> (obj Data.Aeson.Types.FromJSON..:? "spending_limits_currency"))
-- | Defines the enum schema issuing_cardholder_authorization_controlsAllowed_categories\'
-- 
-- 
data IssuingCardholderAuthorizationControlsAllowedCategories'
    = IssuingCardholderAuthorizationControlsAllowedCategories'EnumOther Data.Aeson.Types.Internal.Value
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumTyped GHC.Base.String
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAcRefrigerationRepair
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAccountingBookkeepingServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAdvertisingServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAgriculturalCooperative
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAirlinesAirCarriers
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAirportsFlyingFields
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAmbulanceServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAmusementParksCarnivals
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAntiqueReproductions
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAntiqueShops
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAquariums
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringArchitecturalSurveyingServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringArtDealersAndGalleries
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringArtistsSupplyAndCraftShops
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutoAndHomeSupplyStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutoBodyRepairShops
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutoPaintShops
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutoServiceShops
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutomatedCashDisburse
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutomatedFuelDispensers
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutomobileAssociations
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutomotivePartsAndAccessoriesStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutomotiveTireStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBailAndBondPayments
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBakeries
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBandsOrchestras
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBarberAndBeautyShops
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBettingCasinoGambling
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBicycleShops
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBilliardPoolEstablishments
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBoatDealers
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBoatRentalsAndLeases
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBookStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBooksPeriodicalsAndNewspapers
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBowlingAlleys
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBusLines
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBusinessSecretarialSchools
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBuyingShoppingServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCableSatelliteAndOtherPayTelevisionAndRadio
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCameraAndPhotographicSupplyStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCandyNutAndConfectioneryStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCarAndTruckDealersNewUsed
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCarAndTruckDealersUsedOnly
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCarRentalAgencies
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCarWashes
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCarpentryServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCarpetUpholsteryCleaning
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCaterers
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCharitableAndSocialServiceOrganizationsFundraising
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringChemicalsAndAlliedProducts
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringChildCareServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringChildrensAndInfantsWearStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringChiropodistsPodiatrists
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringChiropractors
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCigarStoresAndStands
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCivicSocialFraternalAssociations
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCleaningAndMaintenance
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringClothingRental
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCollegesUniversities
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCommercialEquipment
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCommercialFootwear
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCommercialPhotographyArtAndGraphics
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCommuterTransportAndFerries
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringComputerNetworkServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringComputerProgramming
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringComputerRepair
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringComputerSoftwareStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringComputersPeripheralsAndSoftware
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringConcreteWorkServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringConstructionMaterials
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringConsultingPublicRelations
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCorrespondenceSchools
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCosmeticStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCounselingServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCountryClubs
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCourierServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCourtCosts
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCreditReportingAgencies
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCruiseLines
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDairyProductsStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDanceHallStudiosSchools
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDatingEscortServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDentistsOrthodontists
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDepartmentStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDetectiveAgencies
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsApplications
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsGames
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsLargeVolume
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsMedia
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingCatalogMerchant
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingCombinationCatalogAndRetailMerchant
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingInboundTelemarketing
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingInsuranceServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingOther
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingOutboundTelemarketing
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingSubscription
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingTravel
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDiscountStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDoctors
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDoorToDoorSales
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDraperyWindowCoveringAndUpholsteryStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDrinkingPlaces
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDrugStoresAndPharmacies
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDrugsDrugProprietariesAndDruggistSundries
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDryCleaners
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDurableGoods
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDutyFreeStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringEatingPlacesRestaurants
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringEducationalServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringElectricRazorStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringElectricalPartsAndEquipment
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringElectricalServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringElectronicsRepairShops
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringElectronicsStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringElementarySecondarySchools
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringEmploymentTempAgencies
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringEquipmentRental
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringExterminatingServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFamilyClothingStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFastFoodRestaurants
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFinancialInstitutions
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFinesGovernmentAdministrativeEntities
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFireplaceFireplaceScreensAndAccessoriesStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFloorCoveringStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFlorists
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFloristsSuppliesNurseryStockAndFlowers
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFreezerAndLockerMeatProvisioners
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFuelDealersNonAutomotive
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFuneralServicesCrematories
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFurnitureHomeFurnishingsAndEquipmentStoresExceptAppliances
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFurnitureRepairRefinishing
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFurriersAndFurShops
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringGeneralServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringGiftCardNoveltyAndSouvenirShops
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringGlassPaintAndWallpaperStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringGlasswareCrystalStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringGolfCoursesPublic
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringGovernmentServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringGroceryStoresSupermarkets
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHardwareEquipmentAndSupplies
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHardwareStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHealthAndBeautySpas
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHearingAidsSalesAndSupplies
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHeatingPlumbingAC
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHobbyToyAndGameShops
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHomeSupplyWarehouseStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHospitals
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHotelsMotelsAndResorts
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHouseholdApplianceStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringIndustrialSupplies
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringInformationRetrievalServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringInsuranceDefault
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringInsuranceUnderwritingPremiums
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringIntraCompanyPurchases
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringJewelryStoresWatchesClocksAndSilverwareStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringLandscapingServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringLaundries
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringLaundryCleaningServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringLegalServicesAttorneys
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringLuggageAndLeatherGoodsStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringLumberBuildingMaterialsStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringManualCashDisburse
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMarinasServiceAndSupplies
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMasonryStoneworkAndPlaster
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMassageParlors
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMedicalAndDentalLabs
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMedicalDentalOphthalmicAndHospitalEquipmentAndSupplies
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMedicalServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMembershipOrganizations
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMensAndBoysClothingAndAccessoriesStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMensWomensClothingStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMetalServiceCenters
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneous
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousApparelAndAccessoryShops
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousAutoDealers
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousBusinessServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousFoodStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousGeneralMerchandise
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousGeneralServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousHomeFurnishingSpecialtyStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousPublishingAndPrinting
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousRecreationServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousRepairShops
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousSpecialtyRetail
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMobileHomeDealers
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMotionPictureTheaters
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMotorFreightCarriersAndTrucking
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMotorHomesDealers
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMotorVehicleSuppliesAndNewParts
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMotorcycleShopsAndDealers
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMotorcycleShopsDealers
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMusicStoresMusicalInstrumentsPianosAndSheetMusic
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringNewsDealersAndNewsstands
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringNonFiMoneyOrders
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringNonFiStoredValueCardPurchaseLoad
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringNondurableGoods
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringNurseriesLawnAndGardenSupplyStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringNursingPersonalCare
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringOfficeAndCommercialFurniture
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringOpticiansEyeglasses
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringOptometristsOphthalmologist
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringOrthopedicGoodsProstheticDevices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringOsteopaths
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPackageStoresBeerWineAndLiquor
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPaintsVarnishesAndSupplies
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringParkingLotsGarages
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPassengerRailways
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPawnShops
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPetShopsPetFoodAndSupplies
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPetroleumAndPetroleumProducts
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPhotoDeveloping
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPhotographicPhotocopyMicrofilmEquipmentAndSupplies
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPhotographicStudios
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPictureVideoProduction
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPieceGoodsNotionsAndOtherDryGoods
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPlumbingHeatingEquipmentAndSupplies
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPoliticalOrganizations
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPostalServicesGovernmentOnly
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPreciousStonesAndMetalsWatchesAndJewelry
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringProfessionalServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPublicWarehousingAndStorage
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringQuickCopyReproAndBlueprint
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringRailroads
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringRealEstateAgentsAndManagersRentals
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringRecordStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringRecreationalVehicleRentals
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringReligiousGoodsStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringReligiousOrganizations
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringRoofingSidingSheetMetal
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSecretarialSupportServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSecurityBrokersDealers
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringServiceStations
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSewingNeedleworkFabricAndPieceGoodsStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringShoeRepairHatCleaning
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringShoeStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSmallApplianceRepair
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSnowmobileDealers
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSpecialTradeServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSpecialtyCleaning
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSportingGoodsStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSportingRecreationCamps
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSportsAndRidingApparelStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSportsClubsFields
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringStampAndCoinStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringStationaryOfficeSuppliesPrintingAndWritingPaper
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringStationeryStoresOfficeAndSchoolSupplyStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSwimmingPoolsSales
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTUiTravelGermany
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTailorsAlterations
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTaxPaymentsGovernmentAgencies
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTaxPreparationServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTaxicabsLimousines
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTelecommunicationEquipmentAndTelephoneSales
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTelecommunicationServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTelegraphServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTentAndAwningShops
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTestingLaboratories
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTheatricalTicketAgencies
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTimeshares
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTireRetreadingAndRepair
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTollsBridgeFees
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTouristAttractionsAndExhibits
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTowingServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTrailerParksCampgrounds
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTransportationServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTravelAgenciesTourOperators
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTruckStopIteration
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTruckUtilityTrailerRentals
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTypesettingPlateMakingAndRelatedServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTypewriterStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringUSFederalGovernmentAgenciesOrDepartments
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringUniformsCommercialClothing
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringUsedMerchandiseAndSecondhandStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringUtilities
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringVarietyStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringVeterinaryServices
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringVideoAmusementGameSupplies
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringVideoGameArcades
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringVideoTapeRentalStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringVocationalTradeSchools
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWatchJewelryRepair
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWeldingRepair
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWholesaleClubs
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWigAndToupeeStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWiresMoneyOrders
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWomensAccessoryAndSpecialtyShops
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWomensReadyToWearStores
    | IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWreckingAndSalvageYards
    deriving (GHC.Show.Show, GHC.Classes.Eq)
instance Data.Aeson.ToJSON IssuingCardholderAuthorizationControlsAllowedCategories'
    where toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumOther patternName) = Data.Aeson.Types.ToJSON.toJSON patternName
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumTyped patternName) = Data.Aeson.Types.ToJSON.toJSON patternName
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAcRefrigerationRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "ac_refrigeration_repair"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAccountingBookkeepingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "accounting_bookkeeping_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAdvertisingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "advertising_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAgriculturalCooperative) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "agricultural_cooperative"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAirlinesAirCarriers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "airlines_air_carriers"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAirportsFlyingFields) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "airports_flying_fields"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAmbulanceServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "ambulance_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAmusementParksCarnivals) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "amusement_parks_carnivals"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAntiqueReproductions) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "antique_reproductions"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAntiqueShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "antique_shops"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAquariums) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "aquariums"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringArchitecturalSurveyingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "architectural_surveying_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringArtDealersAndGalleries) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "art_dealers_and_galleries"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringArtistsSupplyAndCraftShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "artists_supply_and_craft_shops"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutoAndHomeSupplyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_and_home_supply_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutoBodyRepairShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_body_repair_shops"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutoPaintShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_paint_shops"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutoServiceShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_service_shops"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutomatedCashDisburse) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automated_cash_disburse"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutomatedFuelDispensers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automated_fuel_dispensers"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutomobileAssociations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automobile_associations"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutomotivePartsAndAccessoriesStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automotive_parts_and_accessories_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutomotiveTireStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automotive_tire_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBailAndBondPayments) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bail_and_bond_payments"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBakeries) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bakeries"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBandsOrchestras) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bands_orchestras"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBarberAndBeautyShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "barber_and_beauty_shops"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBettingCasinoGambling) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "betting_casino_gambling"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBicycleShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bicycle_shops"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBilliardPoolEstablishments) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "billiard_pool_establishments"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBoatDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "boat_dealers"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBoatRentalsAndLeases) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "boat_rentals_and_leases"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBookStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "book_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBooksPeriodicalsAndNewspapers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "books_periodicals_and_newspapers"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBowlingAlleys) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bowling_alleys"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBusLines) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bus_lines"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBusinessSecretarialSchools) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "business_secretarial_schools"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBuyingShoppingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "buying_shopping_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCableSatelliteAndOtherPayTelevisionAndRadio) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cable_satellite_and_other_pay_television_and_radio"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCameraAndPhotographicSupplyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "camera_and_photographic_supply_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCandyNutAndConfectioneryStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "candy_nut_and_confectionery_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCarAndTruckDealersNewUsed) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_and_truck_dealers_new_used"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCarAndTruckDealersUsedOnly) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_and_truck_dealers_used_only"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCarRentalAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_rental_agencies"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCarWashes) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_washes"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCarpentryServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "carpentry_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCarpetUpholsteryCleaning) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "carpet_upholstery_cleaning"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCaterers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "caterers"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCharitableAndSocialServiceOrganizationsFundraising) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charitable_and_social_service_organizations_fundraising"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringChemicalsAndAlliedProducts) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chemicals_and_allied_products"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringChildCareServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "child_care_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringChildrensAndInfantsWearStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "childrens_and_infants_wear_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringChiropodistsPodiatrists) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chiropodists_podiatrists"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringChiropractors) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chiropractors"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCigarStoresAndStands) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cigar_stores_and_stands"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCivicSocialFraternalAssociations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "civic_social_fraternal_associations"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCleaningAndMaintenance) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cleaning_and_maintenance"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringClothingRental) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "clothing_rental"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCollegesUniversities) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "colleges_universities"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCommercialEquipment) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_equipment"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCommercialFootwear) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_footwear"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCommercialPhotographyArtAndGraphics) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_photography_art_and_graphics"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCommuterTransportAndFerries) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commuter_transport_and_ferries"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringComputerNetworkServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_network_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringComputerProgramming) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_programming"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringComputerRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_repair"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringComputerSoftwareStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_software_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringComputersPeripheralsAndSoftware) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computers_peripherals_and_software"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringConcreteWorkServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "concrete_work_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringConstructionMaterials) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "construction_materials"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringConsultingPublicRelations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "consulting_public_relations"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCorrespondenceSchools) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "correspondence_schools"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCosmeticStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cosmetic_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCounselingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "counseling_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCountryClubs) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "country_clubs"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCourierServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "courier_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCourtCosts) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "court_costs"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCreditReportingAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "credit_reporting_agencies"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCruiseLines) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cruise_lines"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDairyProductsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dairy_products_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDanceHallStudiosSchools) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dance_hall_studios_schools"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDatingEscortServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dating_escort_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDentistsOrthodontists) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dentists_orthodontists"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDepartmentStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "department_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDetectiveAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "detective_agencies"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsApplications) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_applications"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsGames) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_games"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsLargeVolume) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_large_volume"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsMedia) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_media"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingCatalogMerchant) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_catalog_merchant"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingCombinationCatalogAndRetailMerchant) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_combination_catalog_and_retail_merchant"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingInboundTelemarketing) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_inbound_telemarketing"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingInsuranceServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_insurance_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingOther) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_other"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingOutboundTelemarketing) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_outbound_telemarketing"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingSubscription) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_subscription"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingTravel) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_travel"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDiscountStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "discount_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDoctors) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "doctors"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDoorToDoorSales) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "door_to_door_sales"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDraperyWindowCoveringAndUpholsteryStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drapery_window_covering_and_upholstery_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDrinkingPlaces) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drinking_places"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDrugStoresAndPharmacies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drug_stores_and_pharmacies"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDrugsDrugProprietariesAndDruggistSundries) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drugs_drug_proprietaries_and_druggist_sundries"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDryCleaners) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dry_cleaners"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDurableGoods) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "durable_goods"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDutyFreeStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "duty_free_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringEatingPlacesRestaurants) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "eating_places_restaurants"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringEducationalServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "educational_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringElectricRazorStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electric_razor_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringElectricalPartsAndEquipment) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electrical_parts_and_equipment"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringElectricalServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electrical_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringElectronicsRepairShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electronics_repair_shops"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringElectronicsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electronics_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringElementarySecondarySchools) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "elementary_secondary_schools"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringEmploymentTempAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "employment_temp_agencies"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringEquipmentRental) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "equipment_rental"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringExterminatingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "exterminating_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFamilyClothingStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "family_clothing_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFastFoodRestaurants) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fast_food_restaurants"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFinancialInstitutions) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "financial_institutions"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFinesGovernmentAdministrativeEntities) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fines_government_administrative_entities"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFireplaceFireplaceScreensAndAccessoriesStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fireplace_fireplace_screens_and_accessories_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFloorCoveringStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "floor_covering_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFlorists) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "florists"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFloristsSuppliesNurseryStockAndFlowers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "florists_supplies_nursery_stock_and_flowers"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFreezerAndLockerMeatProvisioners) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "freezer_and_locker_meat_provisioners"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFuelDealersNonAutomotive) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fuel_dealers_non_automotive"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFuneralServicesCrematories) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "funeral_services_crematories"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFurnitureHomeFurnishingsAndEquipmentStoresExceptAppliances) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furniture_home_furnishings_and_equipment_stores_except_appliances"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFurnitureRepairRefinishing) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furniture_repair_refinishing"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFurriersAndFurShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furriers_and_fur_shops"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringGeneralServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "general_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringGiftCardNoveltyAndSouvenirShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "gift_card_novelty_and_souvenir_shops"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringGlassPaintAndWallpaperStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "glass_paint_and_wallpaper_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringGlasswareCrystalStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "glassware_crystal_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringGolfCoursesPublic) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "golf_courses_public"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringGovernmentServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "government_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringGroceryStoresSupermarkets) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "grocery_stores_supermarkets"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHardwareEquipmentAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hardware_equipment_and_supplies"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHardwareStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hardware_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHealthAndBeautySpas) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "health_and_beauty_spas"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHearingAidsSalesAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hearing_aids_sales_and_supplies"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHeatingPlumbingAC) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "heating_plumbing_a_c"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHobbyToyAndGameShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hobby_toy_and_game_shops"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHomeSupplyWarehouseStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "home_supply_warehouse_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHospitals) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hospitals"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHotelsMotelsAndResorts) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hotels_motels_and_resorts"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHouseholdApplianceStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "household_appliance_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringIndustrialSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "industrial_supplies"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringInformationRetrievalServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "information_retrieval_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringInsuranceDefault) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "insurance_default"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringInsuranceUnderwritingPremiums) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "insurance_underwriting_premiums"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringIntraCompanyPurchases) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "intra_company_purchases"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringJewelryStoresWatchesClocksAndSilverwareStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "jewelry_stores_watches_clocks_and_silverware_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringLandscapingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "landscaping_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringLaundries) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "laundries"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringLaundryCleaningServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "laundry_cleaning_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringLegalServicesAttorneys) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "legal_services_attorneys"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringLuggageAndLeatherGoodsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "luggage_and_leather_goods_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringLumberBuildingMaterialsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "lumber_building_materials_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringManualCashDisburse) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "manual_cash_disburse"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMarinasServiceAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "marinas_service_and_supplies"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMasonryStoneworkAndPlaster) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "masonry_stonework_and_plaster"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMassageParlors) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "massage_parlors"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMedicalAndDentalLabs) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_and_dental_labs"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMedicalDentalOphthalmicAndHospitalEquipmentAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_dental_ophthalmic_and_hospital_equipment_and_supplies"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMedicalServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMembershipOrganizations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "membership_organizations"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMensAndBoysClothingAndAccessoriesStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mens_and_boys_clothing_and_accessories_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMensWomensClothingStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mens_womens_clothing_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMetalServiceCenters) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "metal_service_centers"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneous) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousApparelAndAccessoryShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_apparel_and_accessory_shops"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousAutoDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_auto_dealers"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousBusinessServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_business_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousFoodStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_food_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousGeneralMerchandise) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_general_merchandise"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousGeneralServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_general_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousHomeFurnishingSpecialtyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_home_furnishing_specialty_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousPublishingAndPrinting) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_publishing_and_printing"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousRecreationServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_recreation_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousRepairShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_repair_shops"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousSpecialtyRetail) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_specialty_retail"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMobileHomeDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mobile_home_dealers"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMotionPictureTheaters) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motion_picture_theaters"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMotorFreightCarriersAndTrucking) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_freight_carriers_and_trucking"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMotorHomesDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_homes_dealers"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMotorVehicleSuppliesAndNewParts) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_vehicle_supplies_and_new_parts"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMotorcycleShopsAndDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motorcycle_shops_and_dealers"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMotorcycleShopsDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motorcycle_shops_dealers"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMusicStoresMusicalInstrumentsPianosAndSheetMusic) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "music_stores_musical_instruments_pianos_and_sheet_music"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringNewsDealersAndNewsstands) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "news_dealers_and_newsstands"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringNonFiMoneyOrders) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "non_fi_money_orders"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringNonFiStoredValueCardPurchaseLoad) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "non_fi_stored_value_card_purchase_load"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringNondurableGoods) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nondurable_goods"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringNurseriesLawnAndGardenSupplyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nurseries_lawn_and_garden_supply_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringNursingPersonalCare) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nursing_personal_care"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringOfficeAndCommercialFurniture) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "office_and_commercial_furniture"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringOpticiansEyeglasses) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "opticians_eyeglasses"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringOptometristsOphthalmologist) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "optometrists_ophthalmologist"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringOrthopedicGoodsProstheticDevices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "orthopedic_goods_prosthetic_devices"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringOsteopaths) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "osteopaths"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPackageStoresBeerWineAndLiquor) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "package_stores_beer_wine_and_liquor"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPaintsVarnishesAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "paints_varnishes_and_supplies"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringParkingLotsGarages) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "parking_lots_garages"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPassengerRailways) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "passenger_railways"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPawnShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "pawn_shops"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPetShopsPetFoodAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "pet_shops_pet_food_and_supplies"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPetroleumAndPetroleumProducts) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "petroleum_and_petroleum_products"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPhotoDeveloping) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photo_developing"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPhotographicPhotocopyMicrofilmEquipmentAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photographic_photocopy_microfilm_equipment_and_supplies"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPhotographicStudios) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photographic_studios"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPictureVideoProduction) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "picture_video_production"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPieceGoodsNotionsAndOtherDryGoods) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "piece_goods_notions_and_other_dry_goods"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPlumbingHeatingEquipmentAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "plumbing_heating_equipment_and_supplies"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPoliticalOrganizations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "political_organizations"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPostalServicesGovernmentOnly) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "postal_services_government_only"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPreciousStonesAndMetalsWatchesAndJewelry) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "precious_stones_and_metals_watches_and_jewelry"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringProfessionalServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "professional_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPublicWarehousingAndStorage) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "public_warehousing_and_storage"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringQuickCopyReproAndBlueprint) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "quick_copy_repro_and_blueprint"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringRailroads) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "railroads"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringRealEstateAgentsAndManagersRentals) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "real_estate_agents_and_managers_rentals"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringRecordStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "record_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringRecreationalVehicleRentals) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "recreational_vehicle_rentals"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringReligiousGoodsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "religious_goods_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringReligiousOrganizations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "religious_organizations"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringRoofingSidingSheetMetal) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "roofing_siding_sheet_metal"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSecretarialSupportServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "secretarial_support_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSecurityBrokersDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "security_brokers_dealers"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringServiceStations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "service_stations"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSewingNeedleworkFabricAndPieceGoodsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sewing_needlework_fabric_and_piece_goods_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringShoeRepairHatCleaning) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "shoe_repair_hat_cleaning"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringShoeStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "shoe_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSmallApplianceRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "small_appliance_repair"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSnowmobileDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "snowmobile_dealers"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSpecialTradeServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "special_trade_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSpecialtyCleaning) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "specialty_cleaning"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSportingGoodsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sporting_goods_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSportingRecreationCamps) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sporting_recreation_camps"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSportsAndRidingApparelStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sports_and_riding_apparel_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSportsClubsFields) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sports_clubs_fields"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringStampAndCoinStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stamp_and_coin_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringStationaryOfficeSuppliesPrintingAndWritingPaper) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stationary_office_supplies_printing_and_writing_paper"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringStationeryStoresOfficeAndSchoolSupplyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stationery_stores_office_and_school_supply_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSwimmingPoolsSales) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "swimming_pools_sales"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTUiTravelGermany) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "t_ui_travel_germany"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTailorsAlterations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tailors_alterations"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTaxPaymentsGovernmentAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tax_payments_government_agencies"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTaxPreparationServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tax_preparation_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTaxicabsLimousines) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "taxicabs_limousines"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTelecommunicationEquipmentAndTelephoneSales) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telecommunication_equipment_and_telephone_sales"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTelecommunicationServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telecommunication_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTelegraphServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telegraph_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTentAndAwningShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tent_and_awning_shops"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTestingLaboratories) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "testing_laboratories"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTheatricalTicketAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "theatrical_ticket_agencies"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTimeshares) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "timeshares"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTireRetreadingAndRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tire_retreading_and_repair"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTollsBridgeFees) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tolls_bridge_fees"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTouristAttractionsAndExhibits) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tourist_attractions_and_exhibits"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTowingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "towing_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTrailerParksCampgrounds) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "trailer_parks_campgrounds"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTransportationServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "transportation_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTravelAgenciesTourOperators) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "travel_agencies_tour_operators"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTruckStopIteration) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "truck_stop_iteration"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTruckUtilityTrailerRentals) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "truck_utility_trailer_rentals"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTypesettingPlateMakingAndRelatedServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "typesetting_plate_making_and_related_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTypewriterStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "typewriter_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringUSFederalGovernmentAgenciesOrDepartments) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "u_s_federal_government_agencies_or_departments"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringUniformsCommercialClothing) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "uniforms_commercial_clothing"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringUsedMerchandiseAndSecondhandStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "used_merchandise_and_secondhand_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringUtilities) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "utilities"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringVarietyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "variety_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringVeterinaryServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "veterinary_services"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringVideoAmusementGameSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_amusement_game_supplies"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringVideoGameArcades) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_game_arcades"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringVideoTapeRentalStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_tape_rental_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringVocationalTradeSchools) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "vocational_trade_schools"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWatchJewelryRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "watch_jewelry_repair"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWeldingRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "welding_repair"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWholesaleClubs) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wholesale_clubs"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWigAndToupeeStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wig_and_toupee_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWiresMoneyOrders) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wires_money_orders"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWomensAccessoryAndSpecialtyShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "womens_accessory_and_specialty_shops"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWomensReadyToWearStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "womens_ready_to_wear_stores"
          toJSON (IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWreckingAndSalvageYards) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wrecking_and_salvage_yards"
instance Data.Aeson.FromJSON IssuingCardholderAuthorizationControlsAllowedCategories'
    where parseJSON val = GHC.Base.pure (if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "ac_refrigeration_repair")
                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAcRefrigerationRepair
                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "accounting_bookkeeping_services")
                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAccountingBookkeepingServices
                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "advertising_services")
                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAdvertisingServices
                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "agricultural_cooperative")
                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAgriculturalCooperative
                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "airlines_air_carriers")
                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAirlinesAirCarriers
                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "airports_flying_fields")
                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAirportsFlyingFields
                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "ambulance_services")
                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAmbulanceServices
                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "amusement_parks_carnivals")
                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAmusementParksCarnivals
                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "antique_reproductions")
                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAntiqueReproductions
                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "antique_shops")
                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAntiqueShops
                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "aquariums")
                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAquariums
                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "architectural_surveying_services")
                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringArchitecturalSurveyingServices
                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "art_dealers_and_galleries")
                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringArtDealersAndGalleries
                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "artists_supply_and_craft_shops")
                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringArtistsSupplyAndCraftShops
                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_and_home_supply_stores")
                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutoAndHomeSupplyStores
                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_body_repair_shops")
                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutoBodyRepairShops
                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_paint_shops")
                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutoPaintShops
                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_service_shops")
                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutoServiceShops
                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automated_cash_disburse")
                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutomatedCashDisburse
                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automated_fuel_dispensers")
                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutomatedFuelDispensers
                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automobile_associations")
                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutomobileAssociations
                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automotive_parts_and_accessories_stores")
                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutomotivePartsAndAccessoriesStores
                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automotive_tire_stores")
                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringAutomotiveTireStores
                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bail_and_bond_payments")
                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBailAndBondPayments
                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bakeries")
                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBakeries
                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bands_orchestras")
                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBandsOrchestras
                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "barber_and_beauty_shops")
                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBarberAndBeautyShops
                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "betting_casino_gambling")
                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBettingCasinoGambling
                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bicycle_shops")
                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBicycleShops
                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "billiard_pool_establishments")
                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBilliardPoolEstablishments
                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "boat_dealers")
                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBoatDealers
                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "boat_rentals_and_leases")
                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBoatRentalsAndLeases
                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "book_stores")
                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBookStores
                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "books_periodicals_and_newspapers")
                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBooksPeriodicalsAndNewspapers
                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bowling_alleys")
                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBowlingAlleys
                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bus_lines")
                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBusLines
                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "business_secretarial_schools")
                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBusinessSecretarialSchools
                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "buying_shopping_services")
                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringBuyingShoppingServices
                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cable_satellite_and_other_pay_television_and_radio")
                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCableSatelliteAndOtherPayTelevisionAndRadio
                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "camera_and_photographic_supply_stores")
                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCameraAndPhotographicSupplyStores
                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "candy_nut_and_confectionery_stores")
                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCandyNutAndConfectioneryStores
                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_and_truck_dealers_new_used")
                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCarAndTruckDealersNewUsed
                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_and_truck_dealers_used_only")
                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCarAndTruckDealersUsedOnly
                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_rental_agencies")
                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCarRentalAgencies
                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_washes")
                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCarWashes
                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "carpentry_services")
                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCarpentryServices
                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "carpet_upholstery_cleaning")
                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCarpetUpholsteryCleaning
                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "caterers")
                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCaterers
                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charitable_and_social_service_organizations_fundraising")
                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCharitableAndSocialServiceOrganizationsFundraising
                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chemicals_and_allied_products")
                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringChemicalsAndAlliedProducts
                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "child_care_services")
                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringChildCareServices
                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "childrens_and_infants_wear_stores")
                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringChildrensAndInfantsWearStores
                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chiropodists_podiatrists")
                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringChiropodistsPodiatrists
                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chiropractors")
                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringChiropractors
                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cigar_stores_and_stands")
                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCigarStoresAndStands
                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "civic_social_fraternal_associations")
                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCivicSocialFraternalAssociations
                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cleaning_and_maintenance")
                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCleaningAndMaintenance
                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "clothing_rental")
                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringClothingRental
                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "colleges_universities")
                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCollegesUniversities
                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_equipment")
                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCommercialEquipment
                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_footwear")
                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCommercialFootwear
                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_photography_art_and_graphics")
                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCommercialPhotographyArtAndGraphics
                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commuter_transport_and_ferries")
                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCommuterTransportAndFerries
                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_network_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringComputerNetworkServices
                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_programming")
                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringComputerProgramming
                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_repair")
                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringComputerRepair
                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_software_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringComputerSoftwareStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computers_peripherals_and_software")
                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringComputersPeripheralsAndSoftware
                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "concrete_work_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringConcreteWorkServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "construction_materials")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringConstructionMaterials
                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "consulting_public_relations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringConsultingPublicRelations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "correspondence_schools")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCorrespondenceSchools
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cosmetic_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCosmeticStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "counseling_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCounselingServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "country_clubs")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCountryClubs
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "courier_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCourierServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "court_costs")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCourtCosts
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "credit_reporting_agencies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCreditReportingAgencies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cruise_lines")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringCruiseLines
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dairy_products_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDairyProductsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dance_hall_studios_schools")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDanceHallStudiosSchools
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dating_escort_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDatingEscortServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dentists_orthodontists")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDentistsOrthodontists
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "department_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDepartmentStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "detective_agencies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDetectiveAgencies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_applications")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsApplications
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_games")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsGames
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_large_volume")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsLargeVolume
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_media")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDigitalGoodsMedia
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_catalog_merchant")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingCatalogMerchant
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_combination_catalog_and_retail_merchant")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingCombinationCatalogAndRetailMerchant
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_inbound_telemarketing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingInboundTelemarketing
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_insurance_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingInsuranceServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_other")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingOther
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_outbound_telemarketing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingOutboundTelemarketing
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_subscription")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingSubscription
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_travel")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDirectMarketingTravel
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "discount_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDiscountStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "doctors")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDoctors
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "door_to_door_sales")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDoorToDoorSales
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drapery_window_covering_and_upholstery_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDraperyWindowCoveringAndUpholsteryStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drinking_places")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDrinkingPlaces
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drug_stores_and_pharmacies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDrugStoresAndPharmacies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drugs_drug_proprietaries_and_druggist_sundries")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDrugsDrugProprietariesAndDruggistSundries
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dry_cleaners")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDryCleaners
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "durable_goods")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDurableGoods
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "duty_free_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringDutyFreeStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "eating_places_restaurants")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringEatingPlacesRestaurants
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "educational_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringEducationalServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electric_razor_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringElectricRazorStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electrical_parts_and_equipment")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringElectricalPartsAndEquipment
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electrical_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringElectricalServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electronics_repair_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringElectronicsRepairShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electronics_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringElectronicsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "elementary_secondary_schools")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringElementarySecondarySchools
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "employment_temp_agencies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringEmploymentTempAgencies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "equipment_rental")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringEquipmentRental
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "exterminating_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringExterminatingServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "family_clothing_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFamilyClothingStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fast_food_restaurants")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFastFoodRestaurants
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "financial_institutions")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFinancialInstitutions
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fines_government_administrative_entities")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFinesGovernmentAdministrativeEntities
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fireplace_fireplace_screens_and_accessories_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFireplaceFireplaceScreensAndAccessoriesStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "floor_covering_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFloorCoveringStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "florists")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFlorists
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "florists_supplies_nursery_stock_and_flowers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFloristsSuppliesNurseryStockAndFlowers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "freezer_and_locker_meat_provisioners")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFreezerAndLockerMeatProvisioners
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fuel_dealers_non_automotive")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFuelDealersNonAutomotive
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "funeral_services_crematories")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFuneralServicesCrematories
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furniture_home_furnishings_and_equipment_stores_except_appliances")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFurnitureHomeFurnishingsAndEquipmentStoresExceptAppliances
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furniture_repair_refinishing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFurnitureRepairRefinishing
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furriers_and_fur_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringFurriersAndFurShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "general_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringGeneralServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "gift_card_novelty_and_souvenir_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringGiftCardNoveltyAndSouvenirShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "glass_paint_and_wallpaper_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringGlassPaintAndWallpaperStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "glassware_crystal_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringGlasswareCrystalStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "golf_courses_public")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringGolfCoursesPublic
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "government_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringGovernmentServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "grocery_stores_supermarkets")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringGroceryStoresSupermarkets
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hardware_equipment_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHardwareEquipmentAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hardware_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHardwareStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "health_and_beauty_spas")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHealthAndBeautySpas
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hearing_aids_sales_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHearingAidsSalesAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "heating_plumbing_a_c")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHeatingPlumbingAC
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hobby_toy_and_game_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHobbyToyAndGameShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "home_supply_warehouse_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHomeSupplyWarehouseStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hospitals")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHospitals
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hotels_motels_and_resorts")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHotelsMotelsAndResorts
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "household_appliance_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringHouseholdApplianceStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "industrial_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringIndustrialSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "information_retrieval_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringInformationRetrievalServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "insurance_default")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringInsuranceDefault
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "insurance_underwriting_premiums")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringInsuranceUnderwritingPremiums
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "intra_company_purchases")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringIntraCompanyPurchases
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "jewelry_stores_watches_clocks_and_silverware_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringJewelryStoresWatchesClocksAndSilverwareStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "landscaping_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringLandscapingServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "laundries")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringLaundries
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "laundry_cleaning_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringLaundryCleaningServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "legal_services_attorneys")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringLegalServicesAttorneys
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "luggage_and_leather_goods_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringLuggageAndLeatherGoodsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "lumber_building_materials_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringLumberBuildingMaterialsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "manual_cash_disburse")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringManualCashDisburse
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "marinas_service_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMarinasServiceAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "masonry_stonework_and_plaster")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMasonryStoneworkAndPlaster
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "massage_parlors")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMassageParlors
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_and_dental_labs")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMedicalAndDentalLabs
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_dental_ophthalmic_and_hospital_equipment_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMedicalDentalOphthalmicAndHospitalEquipmentAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMedicalServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "membership_organizations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMembershipOrganizations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mens_and_boys_clothing_and_accessories_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMensAndBoysClothingAndAccessoriesStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mens_womens_clothing_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMensWomensClothingStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "metal_service_centers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMetalServiceCenters
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneous
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_apparel_and_accessory_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousApparelAndAccessoryShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_auto_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousAutoDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_business_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousBusinessServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_food_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousFoodStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_general_merchandise")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousGeneralMerchandise
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_general_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousGeneralServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_home_furnishing_specialty_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousHomeFurnishingSpecialtyStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_publishing_and_printing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousPublishingAndPrinting
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_recreation_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousRecreationServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_repair_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousRepairShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_specialty_retail")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMiscellaneousSpecialtyRetail
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mobile_home_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMobileHomeDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motion_picture_theaters")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMotionPictureTheaters
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_freight_carriers_and_trucking")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMotorFreightCarriersAndTrucking
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_homes_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMotorHomesDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_vehicle_supplies_and_new_parts")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMotorVehicleSuppliesAndNewParts
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motorcycle_shops_and_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMotorcycleShopsAndDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motorcycle_shops_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMotorcycleShopsDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "music_stores_musical_instruments_pianos_and_sheet_music")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringMusicStoresMusicalInstrumentsPianosAndSheetMusic
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "news_dealers_and_newsstands")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringNewsDealersAndNewsstands
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "non_fi_money_orders")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringNonFiMoneyOrders
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "non_fi_stored_value_card_purchase_load")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringNonFiStoredValueCardPurchaseLoad
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nondurable_goods")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringNondurableGoods
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nurseries_lawn_and_garden_supply_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringNurseriesLawnAndGardenSupplyStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nursing_personal_care")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringNursingPersonalCare
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "office_and_commercial_furniture")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringOfficeAndCommercialFurniture
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "opticians_eyeglasses")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringOpticiansEyeglasses
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "optometrists_ophthalmologist")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringOptometristsOphthalmologist
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "orthopedic_goods_prosthetic_devices")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringOrthopedicGoodsProstheticDevices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "osteopaths")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringOsteopaths
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "package_stores_beer_wine_and_liquor")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPackageStoresBeerWineAndLiquor
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "paints_varnishes_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPaintsVarnishesAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "parking_lots_garages")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringParkingLotsGarages
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "passenger_railways")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPassengerRailways
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "pawn_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPawnShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "pet_shops_pet_food_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPetShopsPetFoodAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "petroleum_and_petroleum_products")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPetroleumAndPetroleumProducts
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photo_developing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPhotoDeveloping
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photographic_photocopy_microfilm_equipment_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPhotographicPhotocopyMicrofilmEquipmentAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photographic_studios")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPhotographicStudios
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "picture_video_production")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPictureVideoProduction
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "piece_goods_notions_and_other_dry_goods")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPieceGoodsNotionsAndOtherDryGoods
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "plumbing_heating_equipment_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPlumbingHeatingEquipmentAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "political_organizations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPoliticalOrganizations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "postal_services_government_only")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPostalServicesGovernmentOnly
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "precious_stones_and_metals_watches_and_jewelry")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPreciousStonesAndMetalsWatchesAndJewelry
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "professional_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringProfessionalServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "public_warehousing_and_storage")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringPublicWarehousingAndStorage
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "quick_copy_repro_and_blueprint")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringQuickCopyReproAndBlueprint
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "railroads")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringRailroads
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "real_estate_agents_and_managers_rentals")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringRealEstateAgentsAndManagersRentals
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "record_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringRecordStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "recreational_vehicle_rentals")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringRecreationalVehicleRentals
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "religious_goods_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringReligiousGoodsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "religious_organizations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringReligiousOrganizations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "roofing_siding_sheet_metal")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringRoofingSidingSheetMetal
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "secretarial_support_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSecretarialSupportServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "security_brokers_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSecurityBrokersDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "service_stations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringServiceStations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sewing_needlework_fabric_and_piece_goods_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSewingNeedleworkFabricAndPieceGoodsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "shoe_repair_hat_cleaning")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringShoeRepairHatCleaning
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "shoe_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringShoeStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "small_appliance_repair")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSmallApplianceRepair
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "snowmobile_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSnowmobileDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "special_trade_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSpecialTradeServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "specialty_cleaning")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSpecialtyCleaning
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sporting_goods_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSportingGoodsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sporting_recreation_camps")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSportingRecreationCamps
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sports_and_riding_apparel_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSportsAndRidingApparelStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sports_clubs_fields")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSportsClubsFields
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stamp_and_coin_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringStampAndCoinStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stationary_office_supplies_printing_and_writing_paper")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringStationaryOfficeSuppliesPrintingAndWritingPaper
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stationery_stores_office_and_school_supply_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringStationeryStoresOfficeAndSchoolSupplyStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "swimming_pools_sales")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringSwimmingPoolsSales
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "t_ui_travel_germany")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTUiTravelGermany
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tailors_alterations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTailorsAlterations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tax_payments_government_agencies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTaxPaymentsGovernmentAgencies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tax_preparation_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTaxPreparationServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "taxicabs_limousines")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTaxicabsLimousines
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telecommunication_equipment_and_telephone_sales")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTelecommunicationEquipmentAndTelephoneSales
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telecommunication_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTelecommunicationServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telegraph_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTelegraphServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tent_and_awning_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTentAndAwningShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "testing_laboratories")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTestingLaboratories
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "theatrical_ticket_agencies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTheatricalTicketAgencies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "timeshares")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTimeshares
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tire_retreading_and_repair")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTireRetreadingAndRepair
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tolls_bridge_fees")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTollsBridgeFees
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tourist_attractions_and_exhibits")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTouristAttractionsAndExhibits
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "towing_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTowingServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "trailer_parks_campgrounds")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTrailerParksCampgrounds
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "transportation_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTransportationServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "travel_agencies_tour_operators")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTravelAgenciesTourOperators
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "truck_stop_iteration")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTruckStopIteration
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "truck_utility_trailer_rentals")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTruckUtilityTrailerRentals
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "typesetting_plate_making_and_related_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTypesettingPlateMakingAndRelatedServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "typewriter_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringTypewriterStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "u_s_federal_government_agencies_or_departments")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringUSFederalGovernmentAgenciesOrDepartments
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "uniforms_commercial_clothing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringUniformsCommercialClothing
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "used_merchandise_and_secondhand_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringUsedMerchandiseAndSecondhandStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "utilities")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringUtilities
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "variety_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringVarietyStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "veterinary_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringVeterinaryServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_amusement_game_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringVideoAmusementGameSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_game_arcades")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringVideoGameArcades
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_tape_rental_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringVideoTapeRentalStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "vocational_trade_schools")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringVocationalTradeSchools
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "watch_jewelry_repair")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWatchJewelryRepair
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "welding_repair")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWeldingRepair
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wholesale_clubs")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWholesaleClubs
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wig_and_toupee_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWigAndToupeeStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wires_money_orders")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWiresMoneyOrders
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "womens_accessory_and_specialty_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWomensAccessoryAndSpecialtyShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "womens_ready_to_wear_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWomensReadyToWearStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wrecking_and_salvage_yards")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsAllowedCategories'EnumStringWreckingAndSalvageYards
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else IssuingCardholderAuthorizationControlsAllowedCategories'EnumOther val)
-- | Defines the enum schema issuing_cardholder_authorization_controlsBlocked_categories\'
-- 
-- 
data IssuingCardholderAuthorizationControlsBlockedCategories'
    = IssuingCardholderAuthorizationControlsBlockedCategories'EnumOther Data.Aeson.Types.Internal.Value
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumTyped GHC.Base.String
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAcRefrigerationRepair
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAccountingBookkeepingServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAdvertisingServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAgriculturalCooperative
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAirlinesAirCarriers
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAirportsFlyingFields
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAmbulanceServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAmusementParksCarnivals
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAntiqueReproductions
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAntiqueShops
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAquariums
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringArchitecturalSurveyingServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringArtDealersAndGalleries
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringArtistsSupplyAndCraftShops
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutoAndHomeSupplyStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutoBodyRepairShops
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutoPaintShops
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutoServiceShops
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutomatedCashDisburse
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutomatedFuelDispensers
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutomobileAssociations
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutomotivePartsAndAccessoriesStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutomotiveTireStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBailAndBondPayments
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBakeries
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBandsOrchestras
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBarberAndBeautyShops
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBettingCasinoGambling
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBicycleShops
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBilliardPoolEstablishments
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBoatDealers
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBoatRentalsAndLeases
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBookStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBooksPeriodicalsAndNewspapers
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBowlingAlleys
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBusLines
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBusinessSecretarialSchools
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBuyingShoppingServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCableSatelliteAndOtherPayTelevisionAndRadio
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCameraAndPhotographicSupplyStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCandyNutAndConfectioneryStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCarAndTruckDealersNewUsed
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCarAndTruckDealersUsedOnly
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCarRentalAgencies
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCarWashes
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCarpentryServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCarpetUpholsteryCleaning
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCaterers
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCharitableAndSocialServiceOrganizationsFundraising
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringChemicalsAndAlliedProducts
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringChildCareServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringChildrensAndInfantsWearStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringChiropodistsPodiatrists
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringChiropractors
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCigarStoresAndStands
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCivicSocialFraternalAssociations
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCleaningAndMaintenance
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringClothingRental
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCollegesUniversities
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCommercialEquipment
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCommercialFootwear
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCommercialPhotographyArtAndGraphics
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCommuterTransportAndFerries
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringComputerNetworkServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringComputerProgramming
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringComputerRepair
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringComputerSoftwareStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringComputersPeripheralsAndSoftware
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringConcreteWorkServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringConstructionMaterials
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringConsultingPublicRelations
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCorrespondenceSchools
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCosmeticStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCounselingServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCountryClubs
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCourierServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCourtCosts
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCreditReportingAgencies
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCruiseLines
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDairyProductsStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDanceHallStudiosSchools
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDatingEscortServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDentistsOrthodontists
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDepartmentStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDetectiveAgencies
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsApplications
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsGames
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsLargeVolume
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsMedia
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingCatalogMerchant
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingCombinationCatalogAndRetailMerchant
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingInboundTelemarketing
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingInsuranceServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingOther
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingOutboundTelemarketing
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingSubscription
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingTravel
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDiscountStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDoctors
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDoorToDoorSales
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDraperyWindowCoveringAndUpholsteryStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDrinkingPlaces
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDrugStoresAndPharmacies
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDrugsDrugProprietariesAndDruggistSundries
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDryCleaners
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDurableGoods
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDutyFreeStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringEatingPlacesRestaurants
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringEducationalServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringElectricRazorStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringElectricalPartsAndEquipment
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringElectricalServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringElectronicsRepairShops
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringElectronicsStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringElementarySecondarySchools
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringEmploymentTempAgencies
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringEquipmentRental
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringExterminatingServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFamilyClothingStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFastFoodRestaurants
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFinancialInstitutions
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFinesGovernmentAdministrativeEntities
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFireplaceFireplaceScreensAndAccessoriesStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFloorCoveringStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFlorists
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFloristsSuppliesNurseryStockAndFlowers
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFreezerAndLockerMeatProvisioners
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFuelDealersNonAutomotive
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFuneralServicesCrematories
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFurnitureHomeFurnishingsAndEquipmentStoresExceptAppliances
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFurnitureRepairRefinishing
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFurriersAndFurShops
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringGeneralServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringGiftCardNoveltyAndSouvenirShops
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringGlassPaintAndWallpaperStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringGlasswareCrystalStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringGolfCoursesPublic
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringGovernmentServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringGroceryStoresSupermarkets
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHardwareEquipmentAndSupplies
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHardwareStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHealthAndBeautySpas
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHearingAidsSalesAndSupplies
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHeatingPlumbingAC
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHobbyToyAndGameShops
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHomeSupplyWarehouseStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHospitals
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHotelsMotelsAndResorts
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHouseholdApplianceStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringIndustrialSupplies
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringInformationRetrievalServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringInsuranceDefault
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringInsuranceUnderwritingPremiums
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringIntraCompanyPurchases
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringJewelryStoresWatchesClocksAndSilverwareStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringLandscapingServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringLaundries
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringLaundryCleaningServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringLegalServicesAttorneys
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringLuggageAndLeatherGoodsStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringLumberBuildingMaterialsStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringManualCashDisburse
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMarinasServiceAndSupplies
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMasonryStoneworkAndPlaster
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMassageParlors
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMedicalAndDentalLabs
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMedicalDentalOphthalmicAndHospitalEquipmentAndSupplies
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMedicalServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMembershipOrganizations
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMensAndBoysClothingAndAccessoriesStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMensWomensClothingStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMetalServiceCenters
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneous
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousApparelAndAccessoryShops
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousAutoDealers
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousBusinessServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousFoodStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousGeneralMerchandise
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousGeneralServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousHomeFurnishingSpecialtyStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousPublishingAndPrinting
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousRecreationServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousRepairShops
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousSpecialtyRetail
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMobileHomeDealers
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMotionPictureTheaters
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMotorFreightCarriersAndTrucking
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMotorHomesDealers
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMotorVehicleSuppliesAndNewParts
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMotorcycleShopsAndDealers
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMotorcycleShopsDealers
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMusicStoresMusicalInstrumentsPianosAndSheetMusic
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringNewsDealersAndNewsstands
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringNonFiMoneyOrders
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringNonFiStoredValueCardPurchaseLoad
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringNondurableGoods
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringNurseriesLawnAndGardenSupplyStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringNursingPersonalCare
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringOfficeAndCommercialFurniture
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringOpticiansEyeglasses
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringOptometristsOphthalmologist
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringOrthopedicGoodsProstheticDevices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringOsteopaths
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPackageStoresBeerWineAndLiquor
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPaintsVarnishesAndSupplies
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringParkingLotsGarages
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPassengerRailways
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPawnShops
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPetShopsPetFoodAndSupplies
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPetroleumAndPetroleumProducts
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPhotoDeveloping
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPhotographicPhotocopyMicrofilmEquipmentAndSupplies
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPhotographicStudios
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPictureVideoProduction
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPieceGoodsNotionsAndOtherDryGoods
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPlumbingHeatingEquipmentAndSupplies
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPoliticalOrganizations
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPostalServicesGovernmentOnly
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPreciousStonesAndMetalsWatchesAndJewelry
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringProfessionalServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPublicWarehousingAndStorage
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringQuickCopyReproAndBlueprint
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringRailroads
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringRealEstateAgentsAndManagersRentals
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringRecordStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringRecreationalVehicleRentals
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringReligiousGoodsStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringReligiousOrganizations
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringRoofingSidingSheetMetal
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSecretarialSupportServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSecurityBrokersDealers
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringServiceStations
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSewingNeedleworkFabricAndPieceGoodsStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringShoeRepairHatCleaning
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringShoeStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSmallApplianceRepair
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSnowmobileDealers
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSpecialTradeServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSpecialtyCleaning
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSportingGoodsStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSportingRecreationCamps
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSportsAndRidingApparelStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSportsClubsFields
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringStampAndCoinStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringStationaryOfficeSuppliesPrintingAndWritingPaper
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringStationeryStoresOfficeAndSchoolSupplyStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSwimmingPoolsSales
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTUiTravelGermany
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTailorsAlterations
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTaxPaymentsGovernmentAgencies
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTaxPreparationServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTaxicabsLimousines
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTelecommunicationEquipmentAndTelephoneSales
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTelecommunicationServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTelegraphServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTentAndAwningShops
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTestingLaboratories
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTheatricalTicketAgencies
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTimeshares
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTireRetreadingAndRepair
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTollsBridgeFees
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTouristAttractionsAndExhibits
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTowingServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTrailerParksCampgrounds
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTransportationServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTravelAgenciesTourOperators
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTruckStopIteration
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTruckUtilityTrailerRentals
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTypesettingPlateMakingAndRelatedServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTypewriterStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringUSFederalGovernmentAgenciesOrDepartments
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringUniformsCommercialClothing
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringUsedMerchandiseAndSecondhandStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringUtilities
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringVarietyStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringVeterinaryServices
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringVideoAmusementGameSupplies
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringVideoGameArcades
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringVideoTapeRentalStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringVocationalTradeSchools
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWatchJewelryRepair
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWeldingRepair
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWholesaleClubs
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWigAndToupeeStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWiresMoneyOrders
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWomensAccessoryAndSpecialtyShops
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWomensReadyToWearStores
    | IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWreckingAndSalvageYards
    deriving (GHC.Show.Show, GHC.Classes.Eq)
instance Data.Aeson.ToJSON IssuingCardholderAuthorizationControlsBlockedCategories'
    where toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumOther patternName) = Data.Aeson.Types.ToJSON.toJSON patternName
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumTyped patternName) = Data.Aeson.Types.ToJSON.toJSON patternName
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAcRefrigerationRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "ac_refrigeration_repair"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAccountingBookkeepingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "accounting_bookkeeping_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAdvertisingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "advertising_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAgriculturalCooperative) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "agricultural_cooperative"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAirlinesAirCarriers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "airlines_air_carriers"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAirportsFlyingFields) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "airports_flying_fields"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAmbulanceServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "ambulance_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAmusementParksCarnivals) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "amusement_parks_carnivals"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAntiqueReproductions) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "antique_reproductions"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAntiqueShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "antique_shops"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAquariums) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "aquariums"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringArchitecturalSurveyingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "architectural_surveying_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringArtDealersAndGalleries) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "art_dealers_and_galleries"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringArtistsSupplyAndCraftShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "artists_supply_and_craft_shops"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutoAndHomeSupplyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_and_home_supply_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutoBodyRepairShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_body_repair_shops"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutoPaintShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_paint_shops"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutoServiceShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_service_shops"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutomatedCashDisburse) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automated_cash_disburse"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutomatedFuelDispensers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automated_fuel_dispensers"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutomobileAssociations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automobile_associations"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutomotivePartsAndAccessoriesStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automotive_parts_and_accessories_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutomotiveTireStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automotive_tire_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBailAndBondPayments) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bail_and_bond_payments"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBakeries) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bakeries"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBandsOrchestras) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bands_orchestras"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBarberAndBeautyShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "barber_and_beauty_shops"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBettingCasinoGambling) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "betting_casino_gambling"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBicycleShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bicycle_shops"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBilliardPoolEstablishments) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "billiard_pool_establishments"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBoatDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "boat_dealers"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBoatRentalsAndLeases) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "boat_rentals_and_leases"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBookStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "book_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBooksPeriodicalsAndNewspapers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "books_periodicals_and_newspapers"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBowlingAlleys) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bowling_alleys"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBusLines) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bus_lines"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBusinessSecretarialSchools) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "business_secretarial_schools"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBuyingShoppingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "buying_shopping_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCableSatelliteAndOtherPayTelevisionAndRadio) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cable_satellite_and_other_pay_television_and_radio"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCameraAndPhotographicSupplyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "camera_and_photographic_supply_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCandyNutAndConfectioneryStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "candy_nut_and_confectionery_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCarAndTruckDealersNewUsed) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_and_truck_dealers_new_used"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCarAndTruckDealersUsedOnly) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_and_truck_dealers_used_only"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCarRentalAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_rental_agencies"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCarWashes) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_washes"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCarpentryServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "carpentry_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCarpetUpholsteryCleaning) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "carpet_upholstery_cleaning"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCaterers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "caterers"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCharitableAndSocialServiceOrganizationsFundraising) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charitable_and_social_service_organizations_fundraising"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringChemicalsAndAlliedProducts) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chemicals_and_allied_products"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringChildCareServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "child_care_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringChildrensAndInfantsWearStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "childrens_and_infants_wear_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringChiropodistsPodiatrists) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chiropodists_podiatrists"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringChiropractors) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chiropractors"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCigarStoresAndStands) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cigar_stores_and_stands"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCivicSocialFraternalAssociations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "civic_social_fraternal_associations"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCleaningAndMaintenance) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cleaning_and_maintenance"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringClothingRental) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "clothing_rental"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCollegesUniversities) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "colleges_universities"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCommercialEquipment) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_equipment"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCommercialFootwear) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_footwear"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCommercialPhotographyArtAndGraphics) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_photography_art_and_graphics"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCommuterTransportAndFerries) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commuter_transport_and_ferries"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringComputerNetworkServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_network_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringComputerProgramming) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_programming"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringComputerRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_repair"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringComputerSoftwareStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_software_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringComputersPeripheralsAndSoftware) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computers_peripherals_and_software"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringConcreteWorkServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "concrete_work_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringConstructionMaterials) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "construction_materials"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringConsultingPublicRelations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "consulting_public_relations"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCorrespondenceSchools) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "correspondence_schools"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCosmeticStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cosmetic_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCounselingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "counseling_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCountryClubs) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "country_clubs"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCourierServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "courier_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCourtCosts) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "court_costs"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCreditReportingAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "credit_reporting_agencies"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCruiseLines) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cruise_lines"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDairyProductsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dairy_products_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDanceHallStudiosSchools) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dance_hall_studios_schools"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDatingEscortServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dating_escort_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDentistsOrthodontists) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dentists_orthodontists"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDepartmentStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "department_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDetectiveAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "detective_agencies"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsApplications) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_applications"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsGames) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_games"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsLargeVolume) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_large_volume"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsMedia) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_media"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingCatalogMerchant) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_catalog_merchant"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingCombinationCatalogAndRetailMerchant) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_combination_catalog_and_retail_merchant"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingInboundTelemarketing) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_inbound_telemarketing"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingInsuranceServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_insurance_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingOther) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_other"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingOutboundTelemarketing) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_outbound_telemarketing"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingSubscription) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_subscription"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingTravel) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_travel"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDiscountStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "discount_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDoctors) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "doctors"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDoorToDoorSales) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "door_to_door_sales"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDraperyWindowCoveringAndUpholsteryStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drapery_window_covering_and_upholstery_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDrinkingPlaces) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drinking_places"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDrugStoresAndPharmacies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drug_stores_and_pharmacies"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDrugsDrugProprietariesAndDruggistSundries) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drugs_drug_proprietaries_and_druggist_sundries"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDryCleaners) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dry_cleaners"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDurableGoods) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "durable_goods"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDutyFreeStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "duty_free_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringEatingPlacesRestaurants) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "eating_places_restaurants"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringEducationalServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "educational_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringElectricRazorStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electric_razor_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringElectricalPartsAndEquipment) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electrical_parts_and_equipment"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringElectricalServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electrical_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringElectronicsRepairShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electronics_repair_shops"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringElectronicsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electronics_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringElementarySecondarySchools) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "elementary_secondary_schools"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringEmploymentTempAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "employment_temp_agencies"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringEquipmentRental) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "equipment_rental"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringExterminatingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "exterminating_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFamilyClothingStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "family_clothing_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFastFoodRestaurants) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fast_food_restaurants"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFinancialInstitutions) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "financial_institutions"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFinesGovernmentAdministrativeEntities) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fines_government_administrative_entities"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFireplaceFireplaceScreensAndAccessoriesStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fireplace_fireplace_screens_and_accessories_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFloorCoveringStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "floor_covering_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFlorists) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "florists"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFloristsSuppliesNurseryStockAndFlowers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "florists_supplies_nursery_stock_and_flowers"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFreezerAndLockerMeatProvisioners) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "freezer_and_locker_meat_provisioners"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFuelDealersNonAutomotive) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fuel_dealers_non_automotive"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFuneralServicesCrematories) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "funeral_services_crematories"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFurnitureHomeFurnishingsAndEquipmentStoresExceptAppliances) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furniture_home_furnishings_and_equipment_stores_except_appliances"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFurnitureRepairRefinishing) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furniture_repair_refinishing"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFurriersAndFurShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furriers_and_fur_shops"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringGeneralServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "general_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringGiftCardNoveltyAndSouvenirShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "gift_card_novelty_and_souvenir_shops"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringGlassPaintAndWallpaperStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "glass_paint_and_wallpaper_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringGlasswareCrystalStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "glassware_crystal_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringGolfCoursesPublic) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "golf_courses_public"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringGovernmentServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "government_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringGroceryStoresSupermarkets) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "grocery_stores_supermarkets"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHardwareEquipmentAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hardware_equipment_and_supplies"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHardwareStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hardware_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHealthAndBeautySpas) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "health_and_beauty_spas"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHearingAidsSalesAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hearing_aids_sales_and_supplies"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHeatingPlumbingAC) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "heating_plumbing_a_c"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHobbyToyAndGameShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hobby_toy_and_game_shops"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHomeSupplyWarehouseStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "home_supply_warehouse_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHospitals) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hospitals"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHotelsMotelsAndResorts) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hotels_motels_and_resorts"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHouseholdApplianceStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "household_appliance_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringIndustrialSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "industrial_supplies"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringInformationRetrievalServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "information_retrieval_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringInsuranceDefault) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "insurance_default"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringInsuranceUnderwritingPremiums) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "insurance_underwriting_premiums"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringIntraCompanyPurchases) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "intra_company_purchases"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringJewelryStoresWatchesClocksAndSilverwareStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "jewelry_stores_watches_clocks_and_silverware_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringLandscapingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "landscaping_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringLaundries) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "laundries"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringLaundryCleaningServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "laundry_cleaning_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringLegalServicesAttorneys) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "legal_services_attorneys"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringLuggageAndLeatherGoodsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "luggage_and_leather_goods_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringLumberBuildingMaterialsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "lumber_building_materials_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringManualCashDisburse) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "manual_cash_disburse"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMarinasServiceAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "marinas_service_and_supplies"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMasonryStoneworkAndPlaster) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "masonry_stonework_and_plaster"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMassageParlors) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "massage_parlors"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMedicalAndDentalLabs) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_and_dental_labs"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMedicalDentalOphthalmicAndHospitalEquipmentAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_dental_ophthalmic_and_hospital_equipment_and_supplies"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMedicalServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMembershipOrganizations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "membership_organizations"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMensAndBoysClothingAndAccessoriesStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mens_and_boys_clothing_and_accessories_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMensWomensClothingStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mens_womens_clothing_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMetalServiceCenters) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "metal_service_centers"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneous) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousApparelAndAccessoryShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_apparel_and_accessory_shops"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousAutoDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_auto_dealers"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousBusinessServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_business_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousFoodStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_food_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousGeneralMerchandise) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_general_merchandise"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousGeneralServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_general_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousHomeFurnishingSpecialtyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_home_furnishing_specialty_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousPublishingAndPrinting) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_publishing_and_printing"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousRecreationServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_recreation_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousRepairShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_repair_shops"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousSpecialtyRetail) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_specialty_retail"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMobileHomeDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mobile_home_dealers"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMotionPictureTheaters) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motion_picture_theaters"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMotorFreightCarriersAndTrucking) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_freight_carriers_and_trucking"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMotorHomesDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_homes_dealers"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMotorVehicleSuppliesAndNewParts) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_vehicle_supplies_and_new_parts"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMotorcycleShopsAndDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motorcycle_shops_and_dealers"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMotorcycleShopsDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motorcycle_shops_dealers"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMusicStoresMusicalInstrumentsPianosAndSheetMusic) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "music_stores_musical_instruments_pianos_and_sheet_music"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringNewsDealersAndNewsstands) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "news_dealers_and_newsstands"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringNonFiMoneyOrders) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "non_fi_money_orders"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringNonFiStoredValueCardPurchaseLoad) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "non_fi_stored_value_card_purchase_load"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringNondurableGoods) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nondurable_goods"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringNurseriesLawnAndGardenSupplyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nurseries_lawn_and_garden_supply_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringNursingPersonalCare) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nursing_personal_care"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringOfficeAndCommercialFurniture) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "office_and_commercial_furniture"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringOpticiansEyeglasses) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "opticians_eyeglasses"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringOptometristsOphthalmologist) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "optometrists_ophthalmologist"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringOrthopedicGoodsProstheticDevices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "orthopedic_goods_prosthetic_devices"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringOsteopaths) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "osteopaths"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPackageStoresBeerWineAndLiquor) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "package_stores_beer_wine_and_liquor"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPaintsVarnishesAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "paints_varnishes_and_supplies"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringParkingLotsGarages) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "parking_lots_garages"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPassengerRailways) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "passenger_railways"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPawnShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "pawn_shops"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPetShopsPetFoodAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "pet_shops_pet_food_and_supplies"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPetroleumAndPetroleumProducts) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "petroleum_and_petroleum_products"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPhotoDeveloping) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photo_developing"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPhotographicPhotocopyMicrofilmEquipmentAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photographic_photocopy_microfilm_equipment_and_supplies"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPhotographicStudios) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photographic_studios"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPictureVideoProduction) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "picture_video_production"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPieceGoodsNotionsAndOtherDryGoods) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "piece_goods_notions_and_other_dry_goods"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPlumbingHeatingEquipmentAndSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "plumbing_heating_equipment_and_supplies"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPoliticalOrganizations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "political_organizations"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPostalServicesGovernmentOnly) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "postal_services_government_only"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPreciousStonesAndMetalsWatchesAndJewelry) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "precious_stones_and_metals_watches_and_jewelry"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringProfessionalServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "professional_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPublicWarehousingAndStorage) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "public_warehousing_and_storage"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringQuickCopyReproAndBlueprint) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "quick_copy_repro_and_blueprint"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringRailroads) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "railroads"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringRealEstateAgentsAndManagersRentals) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "real_estate_agents_and_managers_rentals"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringRecordStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "record_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringRecreationalVehicleRentals) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "recreational_vehicle_rentals"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringReligiousGoodsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "religious_goods_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringReligiousOrganizations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "religious_organizations"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringRoofingSidingSheetMetal) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "roofing_siding_sheet_metal"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSecretarialSupportServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "secretarial_support_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSecurityBrokersDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "security_brokers_dealers"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringServiceStations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "service_stations"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSewingNeedleworkFabricAndPieceGoodsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sewing_needlework_fabric_and_piece_goods_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringShoeRepairHatCleaning) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "shoe_repair_hat_cleaning"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringShoeStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "shoe_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSmallApplianceRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "small_appliance_repair"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSnowmobileDealers) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "snowmobile_dealers"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSpecialTradeServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "special_trade_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSpecialtyCleaning) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "specialty_cleaning"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSportingGoodsStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sporting_goods_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSportingRecreationCamps) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sporting_recreation_camps"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSportsAndRidingApparelStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sports_and_riding_apparel_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSportsClubsFields) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sports_clubs_fields"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringStampAndCoinStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stamp_and_coin_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringStationaryOfficeSuppliesPrintingAndWritingPaper) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stationary_office_supplies_printing_and_writing_paper"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringStationeryStoresOfficeAndSchoolSupplyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stationery_stores_office_and_school_supply_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSwimmingPoolsSales) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "swimming_pools_sales"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTUiTravelGermany) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "t_ui_travel_germany"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTailorsAlterations) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tailors_alterations"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTaxPaymentsGovernmentAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tax_payments_government_agencies"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTaxPreparationServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tax_preparation_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTaxicabsLimousines) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "taxicabs_limousines"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTelecommunicationEquipmentAndTelephoneSales) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telecommunication_equipment_and_telephone_sales"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTelecommunicationServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telecommunication_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTelegraphServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telegraph_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTentAndAwningShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tent_and_awning_shops"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTestingLaboratories) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "testing_laboratories"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTheatricalTicketAgencies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "theatrical_ticket_agencies"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTimeshares) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "timeshares"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTireRetreadingAndRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tire_retreading_and_repair"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTollsBridgeFees) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tolls_bridge_fees"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTouristAttractionsAndExhibits) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tourist_attractions_and_exhibits"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTowingServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "towing_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTrailerParksCampgrounds) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "trailer_parks_campgrounds"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTransportationServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "transportation_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTravelAgenciesTourOperators) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "travel_agencies_tour_operators"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTruckStopIteration) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "truck_stop_iteration"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTruckUtilityTrailerRentals) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "truck_utility_trailer_rentals"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTypesettingPlateMakingAndRelatedServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "typesetting_plate_making_and_related_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTypewriterStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "typewriter_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringUSFederalGovernmentAgenciesOrDepartments) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "u_s_federal_government_agencies_or_departments"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringUniformsCommercialClothing) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "uniforms_commercial_clothing"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringUsedMerchandiseAndSecondhandStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "used_merchandise_and_secondhand_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringUtilities) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "utilities"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringVarietyStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "variety_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringVeterinaryServices) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "veterinary_services"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringVideoAmusementGameSupplies) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_amusement_game_supplies"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringVideoGameArcades) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_game_arcades"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringVideoTapeRentalStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_tape_rental_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringVocationalTradeSchools) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "vocational_trade_schools"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWatchJewelryRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "watch_jewelry_repair"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWeldingRepair) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "welding_repair"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWholesaleClubs) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wholesale_clubs"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWigAndToupeeStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wig_and_toupee_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWiresMoneyOrders) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wires_money_orders"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWomensAccessoryAndSpecialtyShops) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "womens_accessory_and_specialty_shops"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWomensReadyToWearStores) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "womens_ready_to_wear_stores"
          toJSON (IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWreckingAndSalvageYards) = Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wrecking_and_salvage_yards"
instance Data.Aeson.FromJSON IssuingCardholderAuthorizationControlsBlockedCategories'
    where parseJSON val = GHC.Base.pure (if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "ac_refrigeration_repair")
                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAcRefrigerationRepair
                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "accounting_bookkeeping_services")
                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAccountingBookkeepingServices
                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "advertising_services")
                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAdvertisingServices
                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "agricultural_cooperative")
                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAgriculturalCooperative
                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "airlines_air_carriers")
                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAirlinesAirCarriers
                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "airports_flying_fields")
                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAirportsFlyingFields
                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "ambulance_services")
                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAmbulanceServices
                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "amusement_parks_carnivals")
                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAmusementParksCarnivals
                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "antique_reproductions")
                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAntiqueReproductions
                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "antique_shops")
                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAntiqueShops
                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "aquariums")
                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAquariums
                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "architectural_surveying_services")
                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringArchitecturalSurveyingServices
                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "art_dealers_and_galleries")
                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringArtDealersAndGalleries
                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "artists_supply_and_craft_shops")
                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringArtistsSupplyAndCraftShops
                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_and_home_supply_stores")
                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutoAndHomeSupplyStores
                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_body_repair_shops")
                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutoBodyRepairShops
                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_paint_shops")
                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutoPaintShops
                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "auto_service_shops")
                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutoServiceShops
                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automated_cash_disburse")
                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutomatedCashDisburse
                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automated_fuel_dispensers")
                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutomatedFuelDispensers
                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automobile_associations")
                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutomobileAssociations
                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automotive_parts_and_accessories_stores")
                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutomotivePartsAndAccessoriesStores
                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "automotive_tire_stores")
                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringAutomotiveTireStores
                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bail_and_bond_payments")
                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBailAndBondPayments
                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bakeries")
                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBakeries
                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bands_orchestras")
                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBandsOrchestras
                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "barber_and_beauty_shops")
                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBarberAndBeautyShops
                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "betting_casino_gambling")
                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBettingCasinoGambling
                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bicycle_shops")
                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBicycleShops
                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "billiard_pool_establishments")
                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBilliardPoolEstablishments
                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "boat_dealers")
                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBoatDealers
                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "boat_rentals_and_leases")
                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBoatRentalsAndLeases
                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "book_stores")
                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBookStores
                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "books_periodicals_and_newspapers")
                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBooksPeriodicalsAndNewspapers
                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bowling_alleys")
                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBowlingAlleys
                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "bus_lines")
                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBusLines
                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "business_secretarial_schools")
                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBusinessSecretarialSchools
                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "buying_shopping_services")
                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringBuyingShoppingServices
                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cable_satellite_and_other_pay_television_and_radio")
                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCableSatelliteAndOtherPayTelevisionAndRadio
                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "camera_and_photographic_supply_stores")
                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCameraAndPhotographicSupplyStores
                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "candy_nut_and_confectionery_stores")
                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCandyNutAndConfectioneryStores
                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_and_truck_dealers_new_used")
                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCarAndTruckDealersNewUsed
                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_and_truck_dealers_used_only")
                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCarAndTruckDealersUsedOnly
                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_rental_agencies")
                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCarRentalAgencies
                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "car_washes")
                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCarWashes
                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "carpentry_services")
                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCarpentryServices
                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "carpet_upholstery_cleaning")
                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCarpetUpholsteryCleaning
                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "caterers")
                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCaterers
                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "charitable_and_social_service_organizations_fundraising")
                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCharitableAndSocialServiceOrganizationsFundraising
                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chemicals_and_allied_products")
                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringChemicalsAndAlliedProducts
                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "child_care_services")
                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringChildCareServices
                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "childrens_and_infants_wear_stores")
                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringChildrensAndInfantsWearStores
                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chiropodists_podiatrists")
                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringChiropodistsPodiatrists
                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "chiropractors")
                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringChiropractors
                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cigar_stores_and_stands")
                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCigarStoresAndStands
                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "civic_social_fraternal_associations")
                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCivicSocialFraternalAssociations
                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cleaning_and_maintenance")
                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCleaningAndMaintenance
                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "clothing_rental")
                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringClothingRental
                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "colleges_universities")
                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCollegesUniversities
                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_equipment")
                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCommercialEquipment
                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_footwear")
                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCommercialFootwear
                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commercial_photography_art_and_graphics")
                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCommercialPhotographyArtAndGraphics
                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "commuter_transport_and_ferries")
                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCommuterTransportAndFerries
                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_network_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringComputerNetworkServices
                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_programming")
                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringComputerProgramming
                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_repair")
                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringComputerRepair
                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computer_software_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringComputerSoftwareStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "computers_peripherals_and_software")
                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringComputersPeripheralsAndSoftware
                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "concrete_work_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringConcreteWorkServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "construction_materials")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringConstructionMaterials
                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "consulting_public_relations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringConsultingPublicRelations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "correspondence_schools")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCorrespondenceSchools
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cosmetic_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCosmeticStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "counseling_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCounselingServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "country_clubs")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCountryClubs
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "courier_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCourierServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "court_costs")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCourtCosts
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "credit_reporting_agencies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCreditReportingAgencies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "cruise_lines")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringCruiseLines
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dairy_products_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDairyProductsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dance_hall_studios_schools")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDanceHallStudiosSchools
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dating_escort_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDatingEscortServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dentists_orthodontists")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDentistsOrthodontists
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "department_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDepartmentStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "detective_agencies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDetectiveAgencies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_applications")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsApplications
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_games")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsGames
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_large_volume")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsLargeVolume
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "digital_goods_media")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDigitalGoodsMedia
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_catalog_merchant")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingCatalogMerchant
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_combination_catalog_and_retail_merchant")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingCombinationCatalogAndRetailMerchant
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_inbound_telemarketing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingInboundTelemarketing
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_insurance_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingInsuranceServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_other")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingOther
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_outbound_telemarketing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingOutboundTelemarketing
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_subscription")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingSubscription
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "direct_marketing_travel")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDirectMarketingTravel
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "discount_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDiscountStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "doctors")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDoctors
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "door_to_door_sales")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDoorToDoorSales
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drapery_window_covering_and_upholstery_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDraperyWindowCoveringAndUpholsteryStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drinking_places")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDrinkingPlaces
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drug_stores_and_pharmacies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDrugStoresAndPharmacies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "drugs_drug_proprietaries_and_druggist_sundries")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDrugsDrugProprietariesAndDruggistSundries
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "dry_cleaners")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDryCleaners
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "durable_goods")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDurableGoods
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "duty_free_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringDutyFreeStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "eating_places_restaurants")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringEatingPlacesRestaurants
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "educational_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringEducationalServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electric_razor_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringElectricRazorStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electrical_parts_and_equipment")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringElectricalPartsAndEquipment
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electrical_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringElectricalServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electronics_repair_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringElectronicsRepairShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "electronics_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringElectronicsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "elementary_secondary_schools")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringElementarySecondarySchools
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "employment_temp_agencies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringEmploymentTempAgencies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "equipment_rental")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringEquipmentRental
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "exterminating_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringExterminatingServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "family_clothing_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFamilyClothingStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fast_food_restaurants")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFastFoodRestaurants
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "financial_institutions")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFinancialInstitutions
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fines_government_administrative_entities")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFinesGovernmentAdministrativeEntities
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fireplace_fireplace_screens_and_accessories_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFireplaceFireplaceScreensAndAccessoriesStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "floor_covering_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFloorCoveringStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "florists")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFlorists
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "florists_supplies_nursery_stock_and_flowers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFloristsSuppliesNurseryStockAndFlowers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "freezer_and_locker_meat_provisioners")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFreezerAndLockerMeatProvisioners
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "fuel_dealers_non_automotive")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFuelDealersNonAutomotive
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "funeral_services_crematories")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFuneralServicesCrematories
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furniture_home_furnishings_and_equipment_stores_except_appliances")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFurnitureHomeFurnishingsAndEquipmentStoresExceptAppliances
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furniture_repair_refinishing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFurnitureRepairRefinishing
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "furriers_and_fur_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringFurriersAndFurShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "general_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringGeneralServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "gift_card_novelty_and_souvenir_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringGiftCardNoveltyAndSouvenirShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "glass_paint_and_wallpaper_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringGlassPaintAndWallpaperStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "glassware_crystal_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringGlasswareCrystalStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "golf_courses_public")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringGolfCoursesPublic
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "government_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringGovernmentServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "grocery_stores_supermarkets")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringGroceryStoresSupermarkets
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hardware_equipment_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHardwareEquipmentAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hardware_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHardwareStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "health_and_beauty_spas")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHealthAndBeautySpas
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hearing_aids_sales_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHearingAidsSalesAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "heating_plumbing_a_c")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHeatingPlumbingAC
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hobby_toy_and_game_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHobbyToyAndGameShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "home_supply_warehouse_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHomeSupplyWarehouseStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hospitals")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHospitals
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "hotels_motels_and_resorts")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHotelsMotelsAndResorts
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "household_appliance_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringHouseholdApplianceStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "industrial_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringIndustrialSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "information_retrieval_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringInformationRetrievalServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "insurance_default")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringInsuranceDefault
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "insurance_underwriting_premiums")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringInsuranceUnderwritingPremiums
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "intra_company_purchases")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringIntraCompanyPurchases
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "jewelry_stores_watches_clocks_and_silverware_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringJewelryStoresWatchesClocksAndSilverwareStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "landscaping_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringLandscapingServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "laundries")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringLaundries
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "laundry_cleaning_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringLaundryCleaningServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "legal_services_attorneys")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringLegalServicesAttorneys
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "luggage_and_leather_goods_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringLuggageAndLeatherGoodsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "lumber_building_materials_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringLumberBuildingMaterialsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "manual_cash_disburse")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringManualCashDisburse
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "marinas_service_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMarinasServiceAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "masonry_stonework_and_plaster")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMasonryStoneworkAndPlaster
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "massage_parlors")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMassageParlors
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_and_dental_labs")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMedicalAndDentalLabs
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_dental_ophthalmic_and_hospital_equipment_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMedicalDentalOphthalmicAndHospitalEquipmentAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "medical_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMedicalServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "membership_organizations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMembershipOrganizations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mens_and_boys_clothing_and_accessories_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMensAndBoysClothingAndAccessoriesStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mens_womens_clothing_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMensWomensClothingStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "metal_service_centers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMetalServiceCenters
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneous
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_apparel_and_accessory_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousApparelAndAccessoryShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_auto_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousAutoDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_business_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousBusinessServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_food_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousFoodStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_general_merchandise")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousGeneralMerchandise
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_general_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousGeneralServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_home_furnishing_specialty_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousHomeFurnishingSpecialtyStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_publishing_and_printing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousPublishingAndPrinting
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_recreation_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousRecreationServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_repair_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousRepairShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "miscellaneous_specialty_retail")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMiscellaneousSpecialtyRetail
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "mobile_home_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMobileHomeDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motion_picture_theaters")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMotionPictureTheaters
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_freight_carriers_and_trucking")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMotorFreightCarriersAndTrucking
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_homes_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMotorHomesDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motor_vehicle_supplies_and_new_parts")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMotorVehicleSuppliesAndNewParts
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motorcycle_shops_and_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMotorcycleShopsAndDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "motorcycle_shops_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMotorcycleShopsDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "music_stores_musical_instruments_pianos_and_sheet_music")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringMusicStoresMusicalInstrumentsPianosAndSheetMusic
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "news_dealers_and_newsstands")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringNewsDealersAndNewsstands
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "non_fi_money_orders")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringNonFiMoneyOrders
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "non_fi_stored_value_card_purchase_load")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringNonFiStoredValueCardPurchaseLoad
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nondurable_goods")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringNondurableGoods
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nurseries_lawn_and_garden_supply_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringNurseriesLawnAndGardenSupplyStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "nursing_personal_care")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringNursingPersonalCare
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "office_and_commercial_furniture")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringOfficeAndCommercialFurniture
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "opticians_eyeglasses")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringOpticiansEyeglasses
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "optometrists_ophthalmologist")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringOptometristsOphthalmologist
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "orthopedic_goods_prosthetic_devices")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringOrthopedicGoodsProstheticDevices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "osteopaths")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringOsteopaths
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "package_stores_beer_wine_and_liquor")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPackageStoresBeerWineAndLiquor
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "paints_varnishes_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPaintsVarnishesAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "parking_lots_garages")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringParkingLotsGarages
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "passenger_railways")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPassengerRailways
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "pawn_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPawnShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "pet_shops_pet_food_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPetShopsPetFoodAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "petroleum_and_petroleum_products")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPetroleumAndPetroleumProducts
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photo_developing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPhotoDeveloping
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photographic_photocopy_microfilm_equipment_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPhotographicPhotocopyMicrofilmEquipmentAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "photographic_studios")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPhotographicStudios
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "picture_video_production")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPictureVideoProduction
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "piece_goods_notions_and_other_dry_goods")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPieceGoodsNotionsAndOtherDryGoods
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "plumbing_heating_equipment_and_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPlumbingHeatingEquipmentAndSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "political_organizations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPoliticalOrganizations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "postal_services_government_only")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPostalServicesGovernmentOnly
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "precious_stones_and_metals_watches_and_jewelry")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPreciousStonesAndMetalsWatchesAndJewelry
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "professional_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringProfessionalServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "public_warehousing_and_storage")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringPublicWarehousingAndStorage
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "quick_copy_repro_and_blueprint")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringQuickCopyReproAndBlueprint
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "railroads")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringRailroads
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "real_estate_agents_and_managers_rentals")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringRealEstateAgentsAndManagersRentals
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "record_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringRecordStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "recreational_vehicle_rentals")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringRecreationalVehicleRentals
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "religious_goods_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringReligiousGoodsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "religious_organizations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringReligiousOrganizations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "roofing_siding_sheet_metal")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringRoofingSidingSheetMetal
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "secretarial_support_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSecretarialSupportServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "security_brokers_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSecurityBrokersDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "service_stations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringServiceStations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sewing_needlework_fabric_and_piece_goods_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSewingNeedleworkFabricAndPieceGoodsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "shoe_repair_hat_cleaning")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringShoeRepairHatCleaning
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "shoe_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringShoeStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "small_appliance_repair")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSmallApplianceRepair
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "snowmobile_dealers")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSnowmobileDealers
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "special_trade_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSpecialTradeServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "specialty_cleaning")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSpecialtyCleaning
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sporting_goods_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSportingGoodsStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sporting_recreation_camps")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSportingRecreationCamps
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sports_and_riding_apparel_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSportsAndRidingApparelStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "sports_clubs_fields")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSportsClubsFields
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stamp_and_coin_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringStampAndCoinStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stationary_office_supplies_printing_and_writing_paper")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringStationaryOfficeSuppliesPrintingAndWritingPaper
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "stationery_stores_office_and_school_supply_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringStationeryStoresOfficeAndSchoolSupplyStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "swimming_pools_sales")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringSwimmingPoolsSales
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "t_ui_travel_germany")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTUiTravelGermany
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tailors_alterations")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTailorsAlterations
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tax_payments_government_agencies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTaxPaymentsGovernmentAgencies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tax_preparation_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTaxPreparationServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "taxicabs_limousines")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTaxicabsLimousines
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telecommunication_equipment_and_telephone_sales")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTelecommunicationEquipmentAndTelephoneSales
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telecommunication_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTelecommunicationServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "telegraph_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTelegraphServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tent_and_awning_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTentAndAwningShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "testing_laboratories")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTestingLaboratories
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "theatrical_ticket_agencies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTheatricalTicketAgencies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "timeshares")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTimeshares
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tire_retreading_and_repair")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTireRetreadingAndRepair
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tolls_bridge_fees")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTollsBridgeFees
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "tourist_attractions_and_exhibits")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTouristAttractionsAndExhibits
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "towing_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTowingServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "trailer_parks_campgrounds")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTrailerParksCampgrounds
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "transportation_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTransportationServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "travel_agencies_tour_operators")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTravelAgenciesTourOperators
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "truck_stop_iteration")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTruckStopIteration
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "truck_utility_trailer_rentals")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTruckUtilityTrailerRentals
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "typesetting_plate_making_and_related_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTypesettingPlateMakingAndRelatedServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "typewriter_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringTypewriterStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "u_s_federal_government_agencies_or_departments")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringUSFederalGovernmentAgenciesOrDepartments
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "uniforms_commercial_clothing")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringUniformsCommercialClothing
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "used_merchandise_and_secondhand_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringUsedMerchandiseAndSecondhandStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "utilities")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringUtilities
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "variety_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringVarietyStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "veterinary_services")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringVeterinaryServices
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_amusement_game_supplies")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringVideoAmusementGameSupplies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_game_arcades")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringVideoGameArcades
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "video_tape_rental_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringVideoTapeRentalStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "vocational_trade_schools")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringVocationalTradeSchools
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "watch_jewelry_repair")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWatchJewelryRepair
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "welding_repair")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWeldingRepair
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wholesale_clubs")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWholesaleClubs
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wig_and_toupee_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWigAndToupeeStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wires_money_orders")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWiresMoneyOrders
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "womens_accessory_and_specialty_shops")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWomensAccessoryAndSpecialtyShops
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "womens_ready_to_wear_stores")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWomensReadyToWearStores
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              else if val GHC.Classes.== (Data.Aeson.Types.Internal.String GHC.Base.$ Data.Text.pack "wrecking_and_salvage_yards")
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    then IssuingCardholderAuthorizationControlsBlockedCategories'EnumStringWreckingAndSalvageYards
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    else IssuingCardholderAuthorizationControlsBlockedCategories'EnumOther val)